# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ai/h2o/featurestore/api/v1/CoreService.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import empty_pb2 as google_dot_protobuf_dot_empty__pb2
from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from ai.h2o.featurestore.api.v1 import FeatureSetSearch_pb2 as ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_FeatureSetSearch__pb2
from ai.h2o.featurestore.api.v1 import OnlineApi_pb2 as ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_OnlineApi__pb2
from ai.h2o.featurestore.api.v1 import TimeToLiveApi_pb2 as ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_TimeToLiveApi__pb2
from ai.h2o.featurestore.api.v1 import FeatureSetProtoApi_pb2 as ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_FeatureSetProtoApi__pb2
from ai.h2o.featurestore.api.v1 import RecommendationProtoApi_pb2 as ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_RecommendationProtoApi__pb2
from ai.h2o.featurestore.api.v1 import DashboardApi_pb2 as ai_dot_h2o_dot_featurestore_dot_api_dot_v1_dot_DashboardApi__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n,ai/h2o/featurestore/api/v1/CoreService.proto\x12\x1a\x61i.h2o.featurestore.api.v1\x1a\x1bgoogle/protobuf/empty.proto\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x1cgoogle/protobuf/struct.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x31\x61i/h2o/featurestore/api/v1/FeatureSetSearch.proto\x1a*ai/h2o/featurestore/api/v1/OnlineApi.proto\x1a.ai/h2o/featurestore/api/v1/TimeToLiveApi.proto\x1a\x33\x61i/h2o/featurestore/api/v1/FeatureSetProtoApi.proto\x1a\x37\x61i/h2o/featurestore/api/v1/RecommendationProtoApi.proto\x1a-ai/h2o/featurestore/api/v1/DashboardApi.proto\"\x9e\x01\n\x19GetUserPermissionsRequest\x12\x13\n\x0bresource_id\x18\x01 \x01(\t\x12\x45\n\x11permission_filter\x18\x02 \x01(\x0e\x32*.ai.h2o.featurestore.api.v1.PermissionType\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\"t\n\x1aGetUserPermissionsResponse\x12=\n\x05users\x18\x01 \x03(\x0b\x32..ai.h2o.featurestore.api.v1.UserWithPermission\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x9a\x01\n\x12UserWithPermission\x12\x37\n\x04user\x18\x01 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\x12K\n\x13resource_permission\x18\x02 \x01(\x0b\x32..ai.h2o.featurestore.api.v1.ResourcePermission\"\x95\x01\n\x12ResourcePermission\x12>\n\npermission\x18\x01 \x01(\x0e\x32*.ai.h2o.featurestore.api.v1.PermissionType\x12?\n\rresource_type\x18\x02 \x01(\x0e\x32(.ai.h2o.featurestore.api.v1.ResourceType\"H\n\x1fListPersonalAccessTokensRequest\x12\x11\n\tpage_size\x18\x01 \x01(\x05\x12\x12\n\npage_token\x18\x02 \x01(\t\"\x8c\x01\n ListPersonalAccessTokensResponse\x12O\n\x16personal_access_tokens\x18\x01 \x03(\x0b\x32/.ai.h2o.featurestore.api.v1.PersonalAccessToken\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"R\n\x17IdentityProviderDetails\x12\x14\n\x0cidp_meta_url\x18\x01 \x01(\t\x12\x11\n\tclient_id\x18\x02 \x01(\t\x12\x0e\n\x06scopes\x18\x03 \x03(\t\"\x88\x01\n\x14GetWebConfigResponse\x12H\n\x0bipd_details\x18\x01 \x01(\x0b\x32\x33.ai.h2o.featurestore.api.v1.IdentityProviderDetails\x12\x15\n\rapp_store_url\x18\x02 \x01(\t\x12\x0f\n\x07web_url\x18\x03 \x01(\t\"d\n-GetFeatureSetsLastMinorForCurrentMajorRequest\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x1b\n\x13\x66\x65\x61ture_set_version\x18\x02 \x01(\t\"m\n\x17\x46\x65\x61tureSetExistsRequest\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x04 \x01(\t\x12\x17\n\x0f\x65xclude_deleted\x18\x05 \x01(\x08\x12!\n\x19\x66\x65\x61ture_set_major_version\x18\x06 \x01(\x05\"\x8f\x01\n\x17GetIngestHistoryRequest\x12?\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSetB\x02\x18\x01\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x02 \x01(\t\x12\x1b\n\x13\x66\x65\x61ture_set_version\x18\x03 \x01(\t\"C\n\x14ProjectExistsRequest\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x17\n\x0f\x65xclude_deleted\x18\x03 \x01(\x08\"L\n\x18\x46\x65\x61tureViewExistsRequest\x12\x17\n\x0f\x66\x65\x61ture_view_id\x18\x04 \x01(\t\x12\x17\n\x0f\x65xclude_deleted\x18\x05 \x01(\x08\"H\n\x16MLDatasetExistsRequest\x12\x15\n\rml_dataset_id\x18\x04 \x01(\t\x12\x17\n\x0f\x65xclude_deleted\x18\x05 \x01(\x08\" \n\x0e\x45xistsResponse\x12\x0e\n\x06\x65xists\x18\x01 \x01(\x08\")\n\x17ProjectsDefaultResponse\x12\x0e\n\x06locked\x18\x01 \x01(\x08\"P\n\x1eHasPermissionToRetrieveRequest\x12\x14\n\x0cproject_name\x18\x01 \x01(\t\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x02 \x01(\t\"B\n\x1fHasPermissionToRetrieveResponse\x12\x1f\n\x17has_retrieve_permission\x18\x01 \x01(\x08\"\xa6\x01\n\x1bStartRevertIngestJobRequest\x12?\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSetB\x02\x18\x01\x12\x11\n\tingest_id\x18\x02 \x01(\t\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x03 \x01(\t\x12\x1b\n\x13\x66\x65\x61ture_set_version\x18\x04 \x01(\t\"e\n\x12OnlineRetrieveMeta\x12\x17\n\x0f\x62\x61se_online_url\x18\x01 \x01(\t\x12\x10\n\x08username\x18\x02 \x01(\t\x12\x10\n\x08password\x18\x03 \x01(\t\x12\x12\n\nis_enabled\x18\x04 \x01(\x08\",\n\x13RefreshTokenRequest\x12\x15\n\rrefresh_token\x18\x01 \x01(\t\"%\n\x14GetUserByMailRequest\x12\r\n\x05\x65mail\x18\x01 \x01(\t\"P\n\x15GetUserByMailResponse\x12\x37\n\x04user\x18\x01 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\" \n\x0cTokenRequest\x12\x10\n\x08token_id\x18\x01 \x01(\t\"j\n\x14GenerateTokenRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12/\n\x0b\x65xpiry_date\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"O\n\rTokenResponse\x12>\n\x05token\x18\x01 \x01(\x0b\x32/.ai.h2o.featurestore.api.v1.PersonalAccessToken\"U\n\x12ListTokensResponse\x12?\n\x06tokens\x18\x01 \x03(\x0b\x32/.ai.h2o.featurestore.api.v1.PersonalAccessToken\"!\n\x10RawTokenResponse\x12\r\n\x05token\x18\x01 \x01(\t\"\xb1\x01\n\x0fListJobsRequest\x12\x0e\n\x06\x61\x63tive\x18\x01 \x01(\x08\x12?\n\x0b\x66\x65\x61ture_set\x18\x02 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSetB\x02\x18\x01\x12\x35\n\x08job_type\x18\x03 \x01(\x0e\x32#.ai.h2o.featurestore.api.v1.JobType\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x04 \x01(\t\"A\n\x10ListJobsResponse\x12-\n\x04jobs\x18\x01 \x03(\x0b\x32\x1f.ai.h2o.featurestore.api.v1.Job\"\xc5\x01\n$FeatureSetSchemaCompatibilityRequest\x12\x42\n\x0foriginal_schema\x18\x01 \x03(\x0b\x32).ai.h2o.featurestore.api.v1.FeatureSchema\x12=\n\nnew_schema\x18\x02 \x03(\x0b\x32).ai.h2o.featurestore.api.v1.FeatureSchema\x12\x1a\n\x12\x63ompare_data_types\x18\x03 \x01(\x08\">\n%FeatureSetSchemaCompatibilityResponse\x12\x15\n\ris_compatible\x18\x01 \x01(\x08\"\xbd\x01\n\x1c\x46\x65\x61tureSetSchemaPatchRequest\x12\x42\n\x0foriginal_schema\x18\x01 \x03(\x0b\x32).ai.h2o.featurestore.api.v1.FeatureSchema\x12=\n\nnew_schema\x18\x02 \x03(\x0b\x32).ai.h2o.featurestore.api.v1.FeatureSchema\x12\x1a\n\x12\x63ompare_data_types\x18\x03 \x01(\x08\"Z\n\x1d\x46\x65\x61tureSetSchemaPatchResponse\x12\x39\n\x06schema\x18\x01 \x03(\x0b\x32).ai.h2o.featurestore.api.v1.FeatureSchema\"\x17\n\x05JobId\x12\x0e\n\x06job_id\x18\x01 \x01(\t\"s\n\x18GetRecommendationRequest\x12?\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSetB\x02\x18\x01\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x02 \x01(\t\"\xaf\x02\n\x19GetRecommendationResponse\x12L\n\x07matches\x18\x01 \x03(\x0b\x32;.ai.h2o.featurestore.api.v1.GetRecommendationResponse.Match\x1a+\n\x04Join\x12\x12\n\nclassifier\x18\x01 \x01(\t\x12\x0f\n\x07\x63olumns\x18\x02 \x03(\t\x1a\x96\x01\n\x05Match\x12\x42\n\x12target_feature_set\x18\x01 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSet\x12I\n\x05joins\x18\x02 \x03(\x0b\x32:.ai.h2o.featurestore.api.v1.GetRecommendationResponse.Join\"\xac\x02\n\x03Job\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x35\n\x08job_type\x18\x02 \x01(\x0e\x32#.ai.h2o.featurestore.api.v1.JobType\x12\x0c\n\x04\x64one\x18\x03 \x01(\x08\x12\x13\n\x0b\x63hildJobIds\x18\x04 \x03(\t\x12\x11\n\tcancelled\x18\x05 \x01(\x08\x12\x39\n\njob_status\x18\x06 \x01(\x0e\x32%.ai.h2o.featurestore.api.v1.JobStatus\x12=\n\ncreated_by\x18\x07 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\x12.\n\ncreated_on\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"6\n\x10JobProgressInput\x12\x0e\n\x06job_id\x18\x01 \x01(\t\x12\x12\n\nnext_index\x18\x02 \x01(\x05\"\xc6\x01\n\x11JobProgressOutput\x12H\n\x08progress\x18\x01 \x03(\x0b\x32\x36.ai.h2o.featurestore.api.v1.JobProgressOutput.Progress\x1ag\n\x08Progress\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x1b\n\x13\x64uration_in_seconds\x18\x02 \x01(\r\x12-\n\ttimestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xcb\x01\n\x1b\x46\x65\x61tureSetPermissionRequest\x12?\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSetB\x02\x18\x01\x12\x13\n\x0buser_emails\x18\x02 \x03(\t\x12>\n\npermission\x18\x03 \x01(\x0e\x32*.ai.h2o.featurestore.api.v1.PermissionType\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x04 \x01(\t\"\xbd\x01\n\x18ProjectPermissionRequest\x12\x38\n\x07project\x18\x01 \x01(\x0b\x32#.ai.h2o.featurestore.api.v1.ProjectB\x02\x18\x01\x12\x13\n\x0buser_emails\x18\x02 \x03(\t\x12>\n\npermission\x18\x03 \x01(\x0e\x32*.ai.h2o.featurestore.api.v1.PermissionType\x12\x12\n\nproject_id\x18\x04 \x01(\t\"\xe8\x01\n\x1cStartExtractSchemaJobRequest\x12?\n\x08raw_data\x18\x01 \x01(\x0b\x32+.ai.h2o.featurestore.api.v1.RawDataLocationH\x00\x12\x46\n\x0c\x64\x65rived_from\x18\x03 \x01(\x0b\x32..ai.h2o.featurestore.api.v1.DerivedInformationH\x00\x12\x35\n\x04\x63red\x18\x02 \x01(\x0b\x32\'.ai.h2o.featurestore.api.v1.CredentialsB\x08\n\x06source\"\x98\x01\n\x15\x45xtractSchemaResponse\x12\x39\n\x06schema\x18\x01 \x03(\x0b\x32).ai.h2o.featurestore.api.v1.FeatureSchema\x12\x44\n\x0c\x64\x65rived_from\x18\x02 \x01(\x0b\x32..ai.h2o.featurestore.api.v1.DerivedInformation\"x\n\x1dListFeatureSetsVersionRequest\x12?\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSetB\x02\x18\x01\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x02 \x01(\t\"\x81\x01\n\x12\x46\x65\x61tureSetResponse\x12;\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSet\x12.\n\x03job\x18\x02 \x01(\x0b\x32!.ai.h2o.featurestore.api.v1.JobId\"_\n\x18UpdateFeatureSetResponse\x12\x43\n\x13updated_feature_set\x18\x01 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSet\"U\n\x15UpdateProjectResponse\x12<\n\x0fupdated_project\x18\x02 \x01(\x0b\x32#.ai.h2o.featurestore.api.v1.Project\"\x9a\x01\n\x15UpdateFeatureResponse\x12\x43\n\x13updated_feature_set\x18\x01 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSet\x12<\n\x0fupdated_feature\x18\x02 \x01(\x0b\x32#.ai.h2o.featurestore.api.v1.Feature\"G\n\x0fProjectResponse\x12\x34\n\x07project\x18\x01 \x01(\x0b\x32#.ai.h2o.featurestore.api.v1.Project\"I\n\rLoginResponse\x12\x13\n\tlogin_url\x18\x01 \x01(\tH\x00\x12\x17\n\rrefresh_token\x18\x02 \x01(\tH\x00\x42\n\n\x08response\"P\n\x15GetActiveUserResponse\x12\x37\n\x04user\x18\x01 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\")\n\x11GetProjectRequest\x12\x14\n\x0cproject_name\x18\x01 \x01(\t\"r\n\x17\x44\x65leteFeatureSetRequest\x12?\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSetB\x02\x18\x01\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x02 \x01(\t\"[\n\x1e\x44\x65leteFeatureSetVersionRequest\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12!\n\x19\x66\x65\x61ture_set_major_version\x18\x02 \x01(\x05\"&\n\rLogoutRequest\x12\x15\n\rrefresh_token\x18\x01 \x01(\t\"8\n\rUserBasicInfo\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05\x65mail\x18\x03 \x01(\t\"Y\n\x04User\x12\x42\n\x0fuser_basic_info\x18\x01 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\x12\r\n\x05\x61\x64min\x18\x02 \x01(\x08\"y\n\x13\x41\x63\x63\x65ssTokenResponse\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x15\n\rrefresh_token\x18\x02 \x01(\t\x12\x12\n\nexpires_in\x18\x03 \x01(\x03\x12\r\n\x05scope\x18\x04 \x01(\t\x12\x12\n\ntoken_type\x18\x05 \x01(\t\"d\n\x14\x44\x65leteProjectRequest\x12\x38\n\x07project\x18\x01 \x01(\x0b\x32#.ai.h2o.featurestore.api.v1.ProjectB\x02\x18\x01\x12\x12\n\nproject_id\x18\x02 \x01(\t\"\x8f\x01\n\x14\x43reateProjectRequest\x12\x14\n\x0cproject_name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0e\n\x06secret\x18\x03 \x01(\x08\x12\x0e\n\x06locked\x18\x04 \x01(\x08\x12,\n\x0b\x63ustom_data\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\"e\n\x15\x43reateProjectResponse\x12\x34\n\x07project\x18\x01 \x01(\x0b\x32#.ai.h2o.featurestore.api.v1.Project\x12\x16\n\x0e\x61lready_exists\x18\x02 \x01(\x08\"M\n\x14ListProjectsResponse\x12\x35\n\x08projects\x18\x01 \x03(\x0b\x32#.ai.h2o.featurestore.api.v1.Project\"Z\n\x1dListProjectHistoryPageRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\xc2\x01\n\x0eProjectHistory\x12\x39\n\x06\x61\x63tion\x18\x01 \x01(\x0e\x32).ai.h2o.featurestore.api.v1.ProjectAction\x12?\n\x0cperformed_by\x18\x02 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\x12\x34\n\x07project\x18\x03 \x01(\x0b\x32#.ai.h2o.featurestore.api.v1.Project\"v\n\x1eListProjectHistoryPageResponse\x12;\n\x07history\x18\x01 \x03(\x0b\x32*.ai.h2o.featurestore.api.v1.ProjectHistory\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"`\n\x18GetIngestHistoryResponse\x12\x44\n\x0eingest_history\x18\x01 \x03(\x0b\x32,.ai.h2o.featurestore.api.v1.FeatureSetIngest\"Z\n\x1aListFeatureSetsPageRequest\x12\x15\n\rproject_names\x18\x01 \x03(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"t\n\x1bListFeatureSetsPageResponse\x12<\n\x0c\x66\x65\x61ture_sets\x18\x01 \x03(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSet\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x89\x01\n\x0e\x41WSCredentials\x12\x14\n\x0c\x61\x63\x63\x65ss_token\x18\x01 \x01(\t\x12\x14\n\x0csecret_token\x18\x02 \x01(\t\x12\x0e\n\x06region\x18\x03 \x01(\t\x12\x17\n\x0b\x62ucket_name\x18\x04 \x01(\tB\x02\x18\x01\x12\x10\n\x08\x65ndpoint\x18\x05 \x01(\t\x12\x10\n\x08role_arn\x18\x06 \x01(\t\"\xa6\x01\n\x10\x41zureCredentials\x12\x14\n\x0c\x61\x63\x63ount_name\x18\x01 \x01(\t\x12\x13\n\x0b\x61\x63\x63ount_key\x18\x02 \x01(\t\x12\x11\n\tsas_token\x18\x03 \x01(\t\x12\x15\n\rsas_container\x18\x04 \x01(\t\x12\x14\n\x0csp_client_id\x18\x05 \x01(\t\x12\x14\n\x0csp_tenant_id\x18\x06 \x01(\t\x12\x11\n\tsp_secret\x18\x07 \x01(\t\"6\n\x14SnowflakeCredentials\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"1\n\x0fJDBCCredentials\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"4\n\x12MongoDbCredentials\x12\x0c\n\x04user\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\"\xd4\x02\n\x0b\x43redentials\x12\x37\n\x03\x61ws\x18\x01 \x01(\x0b\x32*.ai.h2o.featurestore.api.v1.AWSCredentials\x12;\n\x05\x61zure\x18\x02 \x01(\x0b\x32,.ai.h2o.featurestore.api.v1.AzureCredentials\x12\x43\n\tsnowflake\x18\x03 \x01(\x0b\x32\x30.ai.h2o.featurestore.api.v1.SnowflakeCredentials\x12\x42\n\rjdbc_database\x18\x04 \x01(\x0b\x32+.ai.h2o.featurestore.api.v1.JDBCCredentials\x12@\n\x08mongo_db\x18\x06 \x01(\x0b\x32..ai.h2o.featurestore.api.v1.MongoDbCredentialsJ\x04\x08\x05\x10\x06\"W\n\x17ListFeatureSetsResponse\x12<\n\x0c\x66\x65\x61ture_sets\x18\x01 \x03(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSet\"l\n\x1eListFeatureSetVersionsResponse\x12J\n\x08versions\x18\x01 \x03(\x0b\x32\x38.ai.h2o.featurestore.api.v1.FeatureSetVersionDescription\"~\n\x1c\x46\x65\x61tureSetVersionDescription\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x16\n\x0eversion_change\x18\x02 \x01(\t\x12\x35\n\x11\x63reated_date_time\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x8f\x01\n\x14GetFeatureSetRequest\x12\x38\n\x07project\x18\x01 \x01(\x0b\x32#.ai.h2o.featurestore.api.v1.ProjectB\x02\x18\x01\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\t\x12\x12\n\nproject_id\x18\x04 \x01(\t\"\x92\x02\n\x15StartIngestJobRequest\x12?\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSetB\x02\x18\x01\x12\x35\n\x04\x63red\x18\x02 \x01(\x0b\x32\'.ai.h2o.featurestore.api.v1.Credentials\x12@\n\x0b\x64\x61ta_source\x18\x05 \x01(\x0b\x32+.ai.h2o.featurestore.api.v1.RawDataLocation\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x06 \x01(\t\x12\x1b\n\x13\x66\x65\x61ture_set_version\x18\x07 \x01(\tJ\x04\x08\x03\x10\x04J\x04\x08\x04\x10\x05\"\xa4\x03\n\x0eIngestResponse\x12\x43\n\x04meta\x18\x01 \x01(\x0b\x32\x35.ai.h2o.featurestore.api.v1.IngestResponse.IngestMeta\x12?\n\x0b\x66\x65\x61ture_set\x18\x02 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSetB\x02\x18\x01\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x03 \x01(\t\x12\x1b\n\x13\x66\x65\x61ture_set_version\x18\x04 \x01(\t\x1a\xd6\x01\n\nIngestMeta\x12\x16\n\x0e\x63\x61\x63he_location\x18\x01 \x01(\t\x12\x1a\n\x12raw_cache_location\x18\x02 \x01(\t\x12\x37\n\x13ingestion_timestamp\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x37\n\x0cingest_scope\x18\x04 \x01(\x0b\x32!.ai.h2o.featurestore.api.v1.Scope\x12\x0f\n\x07message\x18\x05 \x01(\t\x12\x11\n\tingest_id\x18\x06 \x01(\t\"\xde\x01\n\x0fRetrieveRequest\x12?\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSetB\x02\x18\x01\x12\x17\n\x0fstart_date_time\x18\x02 \x01(\t\x12\x15\n\rend_date_time\x18\x03 \x01(\t\x12\x11\n\tingest_id\x18\x04 \x01(\t\x12\x12\n\nsession_id\x18\x05 \x01(\t\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x06 \x01(\t\x12\x1b\n\x13\x66\x65\x61ture_set_version\x18\x07 \x01(\t\"\x8b\x01\n\x17RetrieveAsLinksResponse\x12\x16\n\x0e\x64ownload_links\x18\x01 \x03(\t\x12\x39\n\x0eretrieve_scope\x18\x02 \x01(\x0b\x32!.ai.h2o.featurestore.api.v1.Scope\x12\x1d\n\x15retrieve_job_executed\x18\x03 \x01(\x08\"\x96\x02\n\x17RetrieveAsSparkResponse\x12\x12\n\ncache_path\x18\x01 \x01(\t\x12Q\n\x07options\x18\x02 \x03(\x0b\x32@.ai.h2o.featurestore.api.v1.RetrieveAsSparkResponse.OptionsEntry\x12\x39\n\x0eretrieve_scope\x18\x03 \x01(\x0b\x32!.ai.h2o.featurestore.api.v1.Scope\x12\x12\n\nsession_id\x18\x04 \x01(\t\x12\x15\n\rdelta_version\x18\x05 \x01(\x03\x1a.\n\x0cOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x99\x01\n!StartMaterializationOnlineRequest\x12?\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSetB\x02\x18\x01\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x02 \x01(\t\x12\x1b\n\x13\x66\x65\x61ture_set_version\x18\x03 \x01(\t\"v\n\x1dMaterializationOnlineResponse\x12@\n\x15materialization_scope\x18\x01 \x01(\x0b\x32!.ai.h2o.featurestore.api.v1.Scope\x12\x13\n\x0bnum_records\x18\x02 \x01(\x04\"2\n\x1cIngestWriteCredentialRequest\x12\x12\n\nsession_id\x18\x01 \x01(\t\"\xca\x01\n\x1dIngestWriteCredentialResponse\x12\x0c\n\x04path\x18\x01 \x01(\t\x12W\n\x07options\x18\x02 \x03(\x0b\x32\x46.ai.h2o.featurestore.api.v1.IngestWriteCredentialResponse.OptionsEntry\x12\x12\n\nsession_id\x18\x03 \x01(\t\x1a.\n\x0cOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb4\x06\n\x0fRawDataLocation\x12\x36\n\x03\x63sv\x18\x01 \x01(\x0b\x32\'.ai.h2o.featurestore.api.v1.CSVFileSpecH\x00\x12>\n\x07parquet\x18\x02 \x01(\x0b\x32+.ai.h2o.featurestore.api.v1.ParquetFileSpecH\x00\x12\x43\n\tsnowflake\x18\x03 \x01(\x0b\x32..ai.h2o.featurestore.api.v1.SnowflakeTableSpecH\x00\x12\x39\n\x04jdbc\x18\x04 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.JDBCTableSpecH\x00\x12\x38\n\x04json\x18\x07 \x01(\x0b\x32(.ai.h2o.featurestore.api.v1.JSONFileSpecH\x00\x12\x41\n\x0b\x64\x65lta_table\x18\x08 \x01(\x0b\x32*.ai.h2o.featurestore.api.v1.DeltaTableSpecH\x00\x12?\n\ncsv_folder\x18\n \x01(\x0b\x32).ai.h2o.featurestore.api.v1.CSVFolderSpecH\x00\x12G\n\x0eparquet_folder\x18\x0b \x01(\x0b\x32-.ai.h2o.featurestore.api.v1.ParquetFolderSpecH\x00\x12\x41\n\x0bjson_folder\x18\x0c \x01(\x0b\x32*.ai.h2o.featurestore.api.v1.JSONFolderSpecH\x00\x12G\n\x0ctemp_parquet\x18\r \x01(\x0b\x32/.ai.h2o.featurestore.api.v1.TempParquetFileSpecH\x00\x12\x45\n\ronline_source\x18\x0e \x01(\x0b\x32,.ai.h2o.featurestore.api.v1.OnlineSourceSpecH\x00\x12\x45\n\x08mongo_db\x18\x0f \x01(\x0b\x32\x31.ai.h2o.featurestore.api.v1.MongoDbCollectionSpecH\x00\x42\x08\n\x06source\"5\n\x10OnlineSourceSpec\x12!\n\x19\x61\x62solute_json_folder_path\x18\x01 \x01(\t\".\n\x0b\x43SVFileSpec\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x11\n\tdelimiter\x18\x02 \x01(\t\"/\n\x0cJSONFileSpec\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x11\n\tmultiline\x18\x02 \x01(\x08\"\x1f\n\x0fParquetFileSpec\x12\x0c\n\x04path\x18\x01 \x01(\t\"#\n\x13TempParquetFileSpec\x12\x0c\n\x04path\x18\x01 \x01(\t\"C\n\x05Proxy\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x05\x12\x0c\n\x04user\x18\x03 \x01(\t\x12\x10\n\x08password\x18\x04 \x01(\t\"\xd7\x01\n\x12SnowflakeTableSpec\x12\r\n\x05table\x18\x01 \x01(\t\x12\x10\n\x08\x64\x61tabase\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\r\n\x05query\x18\x04 \x01(\t\x12\x11\n\twarehouse\x18\x05 \x01(\t\x12\x0e\n\x06schema\x18\x06 \x01(\t\x12\x10\n\x08insecure\x18\x07 \x01(\x08\x12\x30\n\x05proxy\x18\x08 \x01(\x0b\x32!.ai.h2o.featurestore.api.v1.Proxy\x12\x0c\n\x04role\x18\t \x01(\t\x12\x0f\n\x07\x61\x63\x63ount\x18\n \x01(\t\"\xb5\x01\n\rJDBCTableSpec\x12\r\n\x05table\x18\x01 \x01(\t\x12\r\n\x05query\x18\x02 \x01(\t\x12\x16\n\x0e\x63onnection_url\x18\x03 \x01(\t\x12\x16\n\x0enum_partitions\x18\x04 \x01(\x05\x12\x18\n\x10partition_column\x18\x05 \x01(\t\x12\x13\n\x0blower_bound\x18\x06 \x01(\x04\x12\x13\n\x0bupper_bound\x18\x07 \x01(\x04\x12\x12\n\nfetch_size\x18\x08 \x01(\x05\"v\n\x0e\x44\x65ltaTableSpec\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x05\x12\x11\n\ttimestamp\x18\x03 \x01(\t\x12\x32\n\x06\x66ilter\x18\x04 \x01(\x0b\x32\".ai.h2o.featurestore.api.v1.Filter\"O\n\rCSVFolderSpec\x12\x13\n\x0broot_folder\x18\x01 \x01(\t\x12\x16\n\x0e\x66ilter_pattern\x18\x02 \x01(\t\x12\x11\n\tdelimiter\x18\x03 \x01(\t\"@\n\x11ParquetFolderSpec\x12\x13\n\x0broot_folder\x18\x01 \x01(\t\x12\x16\n\x0e\x66ilter_pattern\x18\x02 \x01(\t\"P\n\x0eJSONFolderSpec\x12\x13\n\x0broot_folder\x18\x01 \x01(\t\x12\x16\n\x0e\x66ilter_pattern\x18\x02 \x01(\t\x12\x11\n\tmultiline\x18\x03 \x01(\x08\"U\n\x15MongoDbCollectionSpec\x12\x16\n\x0e\x63onnection_uri\x18\x01 \x01(\t\x12\x10\n\x08\x64\x61tabase\x18\x02 \x01(\t\x12\x12\n\ncollection\x18\x03 \x01(\t\"&\n\x12MojoTransformation\x12\x10\n\x08\x66ilename\x18\x03 \x01(\t\"/\n\x1bSparkPipelineTransformation\x12\x10\n\x08\x66ilename\x18\x03 \x01(\t\"r\n\x12JoinTransformation\x12\x10\n\x08left_key\x18\x01 \x01(\t\x12\x11\n\tright_key\x18\x02 \x01(\t\x12\x37\n\tjoin_type\x18\x03 \x01(\x0e\x32$.ai.h2o.featurestore.api.v1.JoinType\"0\n\x0bVersionedId\x12\n\n\x02id\x18\x01 \x01(\t\x12\x15\n\rmajor_version\x18\x02 \x01(\r\"\xec\x01\n\x0eTransformation\x12>\n\x04mojo\x18\x02 \x01(\x0b\x32..ai.h2o.featurestore.api.v1.MojoTransformationH\x00\x12Q\n\x0espark_pipeline\x18\x03 \x01(\x0b\x32\x37.ai.h2o.featurestore.api.v1.SparkPipelineTransformationH\x00\x12>\n\x04join\x18\x04 \x01(\x0b\x32..ai.h2o.featurestore.api.v1.JoinTransformationH\x00\x42\x07\n\x05value\"\x9a\x01\n\x12\x44\x65rivedInformation\x12@\n\x0f\x66\x65\x61ture_set_ids\x18\x01 \x03(\x0b\x32\'.ai.h2o.featurestore.api.v1.VersionedId\x12\x42\n\x0etransformation\x18\x02 \x01(\x0b\x32*.ai.h2o.featurestore.api.v1.Transformation\"J\n\x0fSelectedFeature\x12\x0e\n\x06prefix\x18\x01 \x01(\t\x12\x0f\n\x07\x66\x65\x61ture\x18\x02 \x01(\t\x12\x16\n\x0etransformation\x18\x03 \x01(\t\"\xa1\x01\n\x14\x46ilterConditionUnion\x12;\n\x06\x66ilter\x18\x01 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.FeatureFilterH\x00\x12?\n\x05logic\x18\x02 \x01(\x0b\x32..ai.h2o.featurestore.api.v1.FeatureFilterLogicH\x00\x42\x0b\n\tcondition\"\xa1\x01\n\rFeatureFilter\x12<\n\x07\x66\x65\x61ture\x18\x01 \x01(\x0b\x32+.ai.h2o.featurestore.api.v1.SelectedFeature\x12\x43\n\x08operator\x18\x02 \x01(\x0e\x32\x31.ai.h2o.featurestore.api.v1.FeatureFilterOperator\x12\r\n\x05value\x18\x03 \x01(\t\"\xe5\x01\n\x12\x46\x65\x61tureFilterLogic\x12>\n\x04left\x18\x01 \x01(\x0b\x32\x30.ai.h2o.featurestore.api.v1.FilterConditionUnion\x12?\n\x05right\x18\x02 \x01(\x0b\x32\x30.ai.h2o.featurestore.api.v1.FilterConditionUnion\x12N\n\x0elogic_operator\x18\x03 \x01(\x0e\x32\x36.ai.h2o.featurestore.api.v1.FeatureFilterLogicOperator\"\xc8\x05\n\x0c\x46\x65\x61tureQuery\x12\x46\n\x11selected_features\x18\x01 \x03(\x0b\x32+.ai.h2o.featurestore.api.v1.SelectedFeature\x12G\n\x10\x66rom_feature_set\x18\x02 \x01(\x0b\x32-.ai.h2o.featurestore.api.v1.FeatureQuery.From\x12;\n\x04join\x18\x03 \x03(\x0b\x32-.ai.h2o.featurestore.api.v1.FeatureQuery.Join\x12?\n\x05where\x18\x04 \x01(\x0b\x32\x30.ai.h2o.featurestore.api.v1.FilterConditionUnion\x1aS\n\x04\x46rom\x12<\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32\'.ai.h2o.featurestore.api.v1.VersionedId\x12\r\n\x05\x61lias\x18\x02 \x01(\t\x1a\xd3\x02\n\x04Join\x12<\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32\'.ai.h2o.featurestore.api.v1.VersionedId\x12\r\n\x05\x61lias\x18\x02 \x01(\t\x12<\n\x02on\x18\x03 \x03(\x0b\x32\x30.ai.h2o.featurestore.api.v1.FeatureQuery.Join.On\x12\x43\n\tjoin_type\x18\x04 \x01(\x0e\x32\x30.ai.h2o.featurestore.api.v1.FeatureQueryJoinType\x1a{\n\x02On\x12\x39\n\x04left\x18\x01 \x01(\x0b\x32+.ai.h2o.featurestore.api.v1.SelectedFeature\x12:\n\x05right\x18\x02 \x01(\x0b\x32+.ai.h2o.featurestore.api.v1.SelectedFeature\"\x9a\x01\n\x0b\x46\x65\x61tureView\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\x05\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x12\n\nproject_id\x18\x05 \x01(\t\x12\x37\n\x05query\x18\x06 \x01(\x0b\x32(.ai.h2o.featurestore.api.v1.FeatureQuery\"\x8a\x01\n\x18\x43reateFeatureViewRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x12\n\nproject_id\x18\x03 \x01(\t\x12\x37\n\x05query\x18\x04 \x01(\x0b\x32(.ai.h2o.featurestore.api.v1.FeatureQuery\"f\n\x18UpdateFeatureViewRequest\x12\x17\n\x0f\x66\x65\x61ture_view_id\x18\x01 \x01(\t\x12\x1c\n\x14\x66\x65\x61ture_view_version\x18\x02 \x01(\x05\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\"\x94\x01\n\"CreateFeatureViewNewVersionRequest\x12\x17\n\x0f\x66\x65\x61ture_view_id\x18\x01 \x01(\t\x12\x1c\n\x14\x66\x65\x61ture_view_version\x18\x02 \x01(\x05\x12\x37\n\x05query\x18\x03 \x01(\x0b\x32(.ai.h2o.featurestore.api.v1.FeatureQuery\"J\n\x15GetFeatureViewRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x03 \x01(\x05\"T\n\x13\x46\x65\x61tureViewResponse\x12=\n\x0c\x66\x65\x61ture_view\x18\x01 \x01(\x0b\x32\'.ai.h2o.featurestore.api.v1.FeatureView\"-\n\x17ListFeatureViewsRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\"Z\n\x18ListFeatureViewsResponse\x12>\n\rfeature_views\x18\x01 \x03(\x0b\x32\'.ai.h2o.featurestore.api.v1.FeatureView\"\xc8\x01\n!RetrieveFeatureViewAsSparkRequest\x12\x17\n\x0f\x66\x65\x61ture_view_id\x18\x01 \x01(\t\x12\x1c\n\x14\x66\x65\x61ture_view_version\x18\x02 \x01(\x05\x12,\n\x08start_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12*\n\x06\x65nd_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nsession_id\x18\x05 \x01(\t\"\xd4\x01\n\"RetrieveFeatureViewAsSparkResponse\x12\x0c\n\x04path\x18\x01 \x01(\t\x12\\\n\x07options\x18\x02 \x03(\x0b\x32K.ai.h2o.featurestore.api.v1.RetrieveFeatureViewAsSparkResponse.OptionsEntry\x12\x12\n\nsession_id\x18\x04 \x01(\t\x1a.\n\x0cOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb6\x01\n#RetrieveFeatureViewAsAsLinksRequest\x12\x17\n\x0f\x66\x65\x61ture_view_id\x18\x01 \x01(\t\x12\x1c\n\x14\x66\x65\x61ture_view_version\x18\x02 \x01(\x05\x12,\n\x08start_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12*\n\x06\x65nd_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\">\n$RetrieveFeatureViewAsAsLinksResponse\x12\x16\n\x0e\x64ownload_links\x18\x01 \x03(\t\"3\n\x18\x44\x65leteFeatureViewRequest\x12\x17\n\x0f\x66\x65\x61ture_view_id\x18\x01 \x01(\t\"\x8f\x03\n\x10MLDatasetFeature\x12\x12\n\nfeature_id\x18\x01 \x01(\t\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x02 \x01(\t\x12!\n\x19\x66\x65\x61ture_set_major_version\x18\x03 \x01(\x05\x12\x17\n\x0f\x66\x65\x61ture_view_id\x18\x04 \x01(\t\x12\x1c\n\x14\x66\x65\x61ture_view_version\x18\x05 \x01(\x05\x12\x11\n\tdata_type\x18\x06 \x01(\t\x12=\n\x0c\x66\x65\x61ture_type\x18\x07 \x01(\x0e\x32\'.ai.h2o.featurestore.api.v1.FeatureType\x12\x15\n\rml_dataset_id\x18\x08 \x01(\t\x12\x0c\n\x04name\x18\t \x01(\t\x12\x15\n\roriginal_name\x18\n \x01(\t\x12\x12\n\nproject_id\x18\x0b \x01(\t\x12\x1a\n\x12original_data_type\x18\x0c \x01(\t\x12\x1f\n\x17transformation_function\x18\r \x01(\t\x12\x16\n\x0eis_primary_key\x18\x0e \x01(\x08\"\xf6\x03\n\tMLDataset\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x33\n\x0fstart_date_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rend_date_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x17\n\x0f\x66\x65\x61ture_view_id\x18\x06 \x01(\t\x12\x1c\n\x14\x66\x65\x61ture_view_version\x18\x07 \x01(\x05\x12\x12\n\nproject_id\x18\x08 \x01(\t\x12>\n\x08\x66\x65\x61tures\x18\t \x03(\x0b\x32,.ai.h2o.featurestore.api.v1.MLDatasetFeature\x12\x43\n\x05state\x18\n \x01(\x0e\x32\x34.ai.h2o.featurestore.api.v1.MLDataset.MLDatasetState\x12\x14\n\x0cprimary_keys\x18\x0b \x03(\t\"l\n\x0eMLDatasetState\x12\x1c\n\x18ML_DATASET_STATE_UNKNOWN\x10\x00\x12\x1c\n\x18ML_DATASET_STATE_PENDING\x10\x01\x12\x1e\n\x1aML_DATASET_STATE_AVAILABLE\x10\x02\"\xda\x01\n\x16\x43reateMLDatasetRequest\x12\x17\n\x0f\x66\x65\x61ture_view_id\x18\x01 \x01(\t\x12\x1c\n\x14\x66\x65\x61ture_view_version\x18\x02 \x01(\x05\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12\x33\n\x0fstart_date_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rend_date_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"D\n\x16UpdateMLDatasetRequest\x12\x15\n\rml_dataset_id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\"/\n\x16\x44\x65leteMLDatasetRequest\x12\x15\n\rml_dataset_id\x18\x01 \x01(\t\"\x84\x01\n\x17\x43reateMLDatasetResponse\x12\x39\n\nml_dataset\x18\x01 \x01(\x0b\x32%.ai.h2o.featurestore.api.v1.MLDataset\x12.\n\x03job\x18\x02 \x01(\x0b\x32!.ai.h2o.featurestore.api.v1.JobId\"e\n\x13GetMLDatasetRequest\x12\x17\n\x0f\x66\x65\x61ture_view_id\x18\x01 \x01(\t\x12\x1c\n\x14\x66\x65\x61ture_view_version\x18\x02 \x01(\x05\x12\x17\n\x0fml_dataset_name\x18\x03 \x01(\t\"N\n\x15ListMLDatasetsRequest\x12\x17\n\x0f\x66\x65\x61ture_view_id\x18\x01 \x01(\t\x12\x1c\n\x14\x66\x65\x61ture_view_version\x18\x02 \x01(\x05\"T\n\x16ListMLDatasetsResponse\x12:\n\x0bml_datasets\x18\x01 \x03(\x0b\x32%.ai.h2o.featurestore.api.v1.MLDataset\"L\n\x1fRetrieveMLDatasetAsSparkRequest\x12\x15\n\rml_dataset_id\x18\x01 \x01(\t\x12\x12\n\nsession_id\x18\x02 \x01(\t\"\xd0\x01\n RetrieveMLDatasetAsSparkResponse\x12\x0c\n\x04path\x18\x01 \x01(\t\x12Z\n\x07options\x18\x02 \x03(\x0b\x32I.ai.h2o.featurestore.api.v1.RetrieveMLDatasetAsSparkResponse.OptionsEntry\x12\x12\n\nsession_id\x18\x04 \x01(\t\x1a.\n\x0cOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\":\n!RetrieveMLDatasetAsAsLinksRequest\x12\x15\n\rml_dataset_id\x18\x01 \x01(\t\"<\n\"RetrieveMLDatasetAsAsLinksResponse\x12\x16\n\x0e\x64ownload_links\x18\x01 \x03(\t\"E\n\x1eRetrieveMLDatasetOnlineRequest\x12\x15\n\rml_dataset_id\x18\x01 \x01(\t\x12\x0c\n\x04keys\x18\x02 \x03(\t\"\xee\x0e\n\nFeatureSet\x12\x0f\n\x07project\x18\x01 \x01(\t\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x02 \x01(\t\x12\x0f\n\x07version\x18\x04 \x01(\t\x12\x16\n\x0eversion_change\x18\x05 \x01(\t\x12\x1a\n\x12time_travel_column\x18\x06 \x01(\t\x12!\n\x19time_travel_column_format\x18\x07 \x01(\t\x12\x44\n\x10\x66\x65\x61ture_set_type\x18\x08 \x01(\x0e\x32*.ai.h2o.featurestore.api.v1.FeatureSetType\x12\x13\n\x0b\x64\x65scription\x18\t \x01(\t\x12\x39\n\x06\x61uthor\x18\x0b \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\x12\x35\n\x11\x63reated_date_time\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x15last_update_date_time\x18\r \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x18\n\x10\x61pplication_name\x18\x0e \x01(\t\x12\x12\n\ndeprecated\x18\x0f \x01(\x08\x12\x33\n\x0f\x64\x65precated_date\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x1b\n\x13\x64\x61ta_source_domains\x18\x11 \x03(\t\x12\x0c\n\x04tags\x18\x12 \x03(\t\x12\x18\n\x10process_interval\x18\x13 \x01(\r\x12N\n\x15process_interval_unit\x18\x14 \x01(\x0e\x32/.ai.h2o.featurestore.api.v1.ProcessIntervalUnit\x12\x0c\n\x04\x66low\x18\x15 \x01(\t\x12<\n\x0ctime_to_live\x18\x16 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.TimeToLive\x12\x35\n\x08\x66\x65\x61tures\x18\x17 \x03(\x0b\x32#.ai.h2o.featurestore.api.v1.Feature\x12\x45\n\nstatistics\x18\x18 \x01(\x0b\x32\x31.ai.h2o.featurestore.api.v1.FeatureSet.Statistics\x12H\n\x0cspecial_data\x18\x19 \x01(\x0b\x32\x32.ai.h2o.featurestore.api.v1.FeatureSet.SpecialData\x12\x13\n\x0bprimary_key\x18\x1a \x03(\t\x12\n\n\x02id\x18\x1c \x01(\t\x12<\n\x11time_travel_scope\x18\x1d \x01(\x0b\x32!.ai.h2o.featurestore.api.v1.Scope\x12\x16\n\x0e\x61pplication_id\x18\x1e \x01(\t\x12\x19\n\x11\x66\x65\x61ture_set_state\x18\x1f \x01(\t\x12=\n\x06online\x18  \x01(\x0b\x32-.ai.h2o.featurestore.api.v1.FeatureSet.Online\x12\x0e\n\x06secret\x18! \x01(\x08\x12\x12\n\nproject_id\x18\" \x01(\t\x12\x14\n\x0cpartition_by\x18# \x03(\t\x12,\n\x0b\x63ustom_data\x18$ \x01(\x0b\x32\x17.google.protobuf.Struct\x12G\n\x1conline_materialization_scope\x18% \x01(\x0b\x32!.ai.h2o.featurestore.api.v1.Scope\x12\x44\n\x0c\x64\x65rived_from\x18& \x01(\x0b\x32..ai.h2o.featurestore.api.v1.DerivedInformation\x12\x1b\n\x13\x66\x65\x61ture_classifiers\x18\' \x03(\t\x12\x42\n\x0flast_updated_by\x18( \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\x1a\x39\n\nStatistics\x12\x14\n\x0c\x64\x61ta_latency\x18\x01 \x01(\x05\x12\x15\n\rrecords_count\x18\x02 \x01(\x03\x1a\x82\x02\n\x0bSpecialData\x12\x0b\n\x03spi\x18\x01 \x01(\x08\x12\x0b\n\x03pci\x18\x02 \x01(\x08\x12\x0b\n\x03rpi\x18\x03 \x01(\x08\x12\x13\n\x0b\x64\x65mographic\x18\x04 \x01(\x08\x12\x11\n\tsensitive\x18\x05 \x01(\x08\x12G\n\x05legal\x18\x06 \x01(\x0b\x32\x38.ai.h2o.featurestore.api.v1.FeatureSet.SpecialData.Legal\x1a[\n\x05Legal\x12\x10\n\x08\x61pproved\x18\x01 \x01(\x08\x12\x31\n\rapproved_date\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\r\n\x05notes\x18\x03 \x01(\t\x1aJ\n\x06Online\x12\x18\n\x10online_namespace\x18\x01 \x01(\t\x12\x17\n\x0f\x63onnection_type\x18\x02 \x01(\t\x12\r\n\x05topic\x18\x03 \x01(\tJ\x04\x08\n\x10\x0b\"R\n\x1bGetFeatureSetPreviewRequest\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x1b\n\x13\x66\x65\x61ture_set_version\x18\x02 \x01(\t\"I\n\x1cGetFeatureSetPreviewResponse\x12\x13\n\x0bpreview_url\x18\x01 \x01(\t\x12\x14\n\x0cmax_cols_num\x18\x02 \x01(\r\"o\n\x05Scope\x12\x33\n\x0fstart_date_time\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rend_date_time\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\xcf\x07\n\x19RegisterFeatureSetRequest\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x01 \x01(\t\x12\x34\n\x07project\x18\x02 \x01(\x0b\x32#.ai.h2o.featurestore.api.v1.Project\x12\x1a\n\x12time_travel_column\x18\x03 \x01(\t\x12!\n\x19time_travel_column_format\x18\x04 \x01(\t\x12\x13\n\x0bprimary_key\x18\x05 \x03(\t\x12\x39\n\x06schema\x18\x07 \x03(\x0b\x32).ai.h2o.featurestore.api.v1.FeatureSchema\x12\x0e\n\x06secret\x18\x08 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\t \x01(\t\x12\x14\n\x0cpartition_by\x18\n \x03(\t\x12\'\n\x1ftime_travel_column_as_partition\x18\x0b \x01(\x08\x12\x44\n\x10\x66\x65\x61ture_set_type\x18\x0c \x01(\x0e\x32*.ai.h2o.featurestore.api.v1.FeatureSetType\x12\x19\n\x11\x66\x65\x61ture_set_state\x18\r \x01(\t\x12\x18\n\x10\x61pplication_name\x18\x0e \x01(\t\x12\x16\n\x0e\x61pplication_id\x18\x0f \x01(\t\x12=\n\x06online\x18\x10 \x01(\x0b\x32-.ai.h2o.featurestore.api.v1.FeatureSet.Online\x12\x1b\n\x13\x64\x61ta_source_domains\x18\x11 \x03(\t\x12\x0c\n\x04tags\x18\x12 \x03(\t\x12\x18\n\x10process_interval\x18\x13 \x01(\r\x12N\n\x15process_interval_unit\x18\x14 \x01(\x0e\x32/.ai.h2o.featurestore.api.v1.ProcessIntervalUnit\x12\x0c\n\x04\x66low\x18\x15 \x01(\t\x12H\n\x0cspecial_data\x18\x16 \x01(\x0b\x32\x32.ai.h2o.featurestore.api.v1.FeatureSet.SpecialData\x12,\n\x0b\x63ustom_data\x18\x17 \x01(\x0b\x32\x17.google.protobuf.Struct\x12<\n\x0ctime_to_live\x18\x18 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.TimeToLive\x12\x44\n\x0c\x64\x65rived_from\x18\x19 \x01(\x0b\x32..ai.h2o.featurestore.api.v1.DerivedInformation\"\xc3\x04\n!CreateNewFeatureSetVersionRequest\x12?\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSetB\x02\x18\x01\x12\x39\n\x06schema\x18\x02 \x03(\x0b\x32).ai.h2o.featurestore.api.v1.FeatureSchema\x12\x19\n\x11\x61\x66\x66\x65\x63ted_features\x18\x03 \x03(\t\x12\x0e\n\x06reason\x18\x04 \x01(\t\x12\x44\n\x0c\x64\x65rived_from\x18\x05 \x01(\x0b\x32..ai.h2o.featurestore.api.v1.DerivedInformation\x12\x13\n\x0bprimary_key\x18\x06 \x03(\t\x12-\n%use_primary_key_from_previous_version\x18\x07 \x01(\x08\x12\x45\n\x10\x62\x61\x63kfill_options\x18\x08 \x01(\x0b\x32+.ai.h2o.featurestore.api.v1.BackfillOptions\x12\x14\n\x0cpartition_by\x18\t \x03(\t\x12.\n&use_partition_by_from_previous_version\x18\n \x01(\x08\x12+\n#use_time_travel_column_as_partition\x18\x0b \x01(\x08\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x0c \x01(\t\x12\x1b\n\x13\x66\x65\x61ture_set_version\x18\r \x01(\t\"\xff\x01\n\x0e\x46\x65\x61tureProfile\x12=\n\x0c\x66\x65\x61ture_type\x18\x01 \x01(\x0e\x32\'.ai.h2o.featurestore.api.v1.FeatureType\x12M\n\x0b\x63\x61tegorical\x18\x02 \x01(\x0b\x32\x38.ai.h2o.featurestore.api.v1.CategoricalFeatureStatistics\x12\x41\n\nstatistics\x18\x03 \x01(\x0b\x32-.ai.h2o.featurestore.api.v1.FeatureStatistics\x12\x1c\n\x14statistics_available\x18\x04 \x01(\x08\"\xa0\x04\n\rFeatureSchema\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tdata_type\x18\x02 \x01(\t\x12\x39\n\x06nested\x18\x03 \x03(\x0b\x32).ai.h2o.featurestore.api.v1.FeatureSchema\x12K\n\x0cspecial_data\x18\x04 \x01(\x0b\x32\x35.ai.h2o.featurestore.api.v1.FeatureSchema.SpecialData\x12=\n\x0c\x66\x65\x61ture_type\x18\x05 \x01(\x0e\x32\'.ai.h2o.featurestore.api.v1.FeatureType\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12\x13\n\x0b\x63lassifiers\x18\x07 \x03(\t\x12,\n\x0b\x63ustom_data\x18\x08 \x01(\x0b\x32\x17.google.protobuf.Struct\x12H\n\nmonitoring\x18\t \x01(\x0b\x32\x34.ai.h2o.featurestore.api.v1.FeatureSchema.Monitoring\x1a\\\n\x0bSpecialData\x12\x0b\n\x03spi\x18\x01 \x01(\x08\x12\x0b\n\x03pci\x18\x02 \x01(\x08\x12\x0b\n\x03rpi\x18\x03 \x01(\x08\x12\x13\n\x0b\x64\x65mographic\x18\x04 \x01(\x08\x12\x11\n\tsensitive\x18\x05 \x01(\x08\x1a\'\n\nMonitoring\x12\x19\n\x11\x61nomaly_detection\x18\x01 \x01(\x08\"\x91\x05\n\x07\x46\x65\x61ture\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x16\n\x0eversion_change\x18\x03 \x01(\t\x12\x0e\n\x06status\x18\x04 \x01(\t\x12\x11\n\tdata_type\x18\x05 \x01(\t\x12;\n\x07profile\x18\x06 \x01(\x0b\x32*.ai.h2o.featurestore.api.v1.FeatureProfile\x12\x13\n\x0b\x64\x65scription\x18\x07 \x01(\t\x12\x12\n\nimportance\x18\x08 \x01(\x01\x12\x0f\n\x07special\x18\t \x01(\t\x12\x42\n\nmonitoring\x18\n \x01(\x0b\x32..ai.h2o.featurestore.api.v1.Feature.Monitoring\x12<\n\x0fnested_features\x18\x0b \x03(\x0b\x32#.ai.h2o.featurestore.api.v1.Feature\x12\x45\n\x0cspecial_data\x18\r \x01(\x0b\x32/.ai.h2o.featurestore.api.v1.Feature.SpecialData\x12\x13\n\x0b\x63lassifiers\x18\x0e \x03(\t\x12,\n\x0b\x63ustom_data\x18\x0f \x01(\x0b\x32\x17.google.protobuf.Struct\x12\n\n\x02id\x18\x10 \x01(\t\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x11 \x01(\t\x1a\'\n\nMonitoring\x12\x19\n\x11\x61nomaly_detection\x18\x01 \x01(\x08\x1a\\\n\x0bSpecialData\x12\x0b\n\x03spi\x18\x01 \x01(\x08\x12\x0b\n\x03pci\x18\x02 \x01(\x08\x12\x0b\n\x03rpi\x18\x03 \x01(\x08\x12\x13\n\x0b\x64\x65mographic\x18\x04 \x01(\x08\x12\x11\n\tsensitive\x18\x05 \x01(\x08\"\xac\x01\n\x11\x46\x65\x61tureStatistics\x12\x0b\n\x03max\x18\x01 \x01(\x01\x12\x0c\n\x04mean\x18\x02 \x01(\x01\x12\x0e\n\x06median\x18\x03 \x01(\x01\x12\x0b\n\x03min\x18\x04 \x01(\x01\x12\x0e\n\x06stddev\x18\x05 \x01(\x01\x12\x18\n\x10stddev_rec_count\x18\x06 \x01(\x03\x12\x12\n\nnull_count\x18\x07 \x01(\x03\x12\x11\n\tnan_count\x18\x08 \x01(\x03\x12\x0e\n\x06unique\x18\t \x01(\x03\"\xab\x01\n\x1c\x43\x61tegoricalFeatureStatistics\x12\x0e\n\x06unique\x18\x01 \x01(\x03\x12P\n\x03top\x18\x02 \x03(\x0b\x32\x43.ai.h2o.featurestore.api.v1.CategoricalFeatureStatistics.FeatureTop\x1a)\n\nFeatureTop\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05\x63ount\x18\x02 \x01(\x03\"%\n\x12GetVersionResponse\x12\x0f\n\x07version\x18\x01 \x01(\t\"\x99\x03\n\x07Project\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x39\n\x06\x61uthor\x18\x04 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\x12\x35\n\x11\x63reated_date_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x15last_update_date_time\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06secret\x18\x07 \x01(\x08\x12\x0e\n\x06locked\x18\x08 \x01(\x08\x12\n\n\x02id\x18\t \x01(\t\x12,\n\x0b\x63ustom_data\x18\n \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x1a\n\x12\x66\x65\x61ture_sets_count\x18\x0b \x01(\x04\x12\x42\n\x0flast_updated_by\x18\x0c \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfoJ\x04\x08\x03\x10\x04\"\xa4\x02\n\x0fListableProject\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x39\n\x15last_update_date_time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06locked\x18\x05 \x01(\x08\x12@\n\npermission\x18\x06 \x01(\x0e\x32,.ai.h2o.featurestore.api.v1.ActivePermission\x12\x39\n\x06\x61uthor\x18\x07 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\x12\x1a\n\x12\x66\x65\x61ture_sets_count\x18\x08 \x01(\x04\"\xf6\x02\n\x10\x46\x65\x61tureSetIngest\x12\x11\n\tingest_id\x18\x01 \x01(\t\x12\x34\n\x10ingest_timestamp\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12;\n\x06source\x18\x03 \x01(\x0b\x32+.ai.h2o.featurestore.api.v1.RawDataLocation\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x04 \x01(\t\x12\x1b\n\x13\x66\x65\x61ture_set_version\x18\x05 \x01(\t\x12\x30\n\x05scope\x18\x07 \x01(\x0b\x32!.ai.h2o.featurestore.api.v1.Scope\x12\x16\n\x0eparent_ingests\x18\x08 \x03(\t\x12\x1e\n\x16ingested_records_count\x18\t \x01(\t\x12=\n\nstarted_by\x18\n \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\"\xd7\x01\n\x13PersonalAccessToken\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12-\n\tlast_used\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x31\n\rcreation_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x65xpiry_date\x18\x06 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"\x88\x01\n#GenerateTransformationUploadRequest\x12K\n\x13transformation_type\x18\x01 \x01(\x0e\x32..ai.h2o.featurestore.api.v1.TransformationType\x12\x14\n\x0cmd5_checksum\x18\x02 \x01(\t\"\xd5\x01\n$GenerateTransformationUploadResponse\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x0b\n\x03url\x18\x02 \x01(\t\x12^\n\x07headers\x18\x03 \x03(\x0b\x32M.ai.h2o.featurestore.api.v1.GenerateTransformationUploadResponse.HeadersEntry\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"@\n\x17ListProjectsPageRequest\x12\x11\n\tpage_size\x18\x01 \x01(\x05\x12\x12\n\npage_token\x18\x02 \x01(\t\"j\n\x18ListProjectsPageResponse\x12\x35\n\x08projects\x18\x01 \x03(\x0b\x32#.ai.h2o.featurestore.api.v1.Project\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xa0\x04\n\x14ProjectSearchRequest\x12\r\n\x05query\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\x12I\n\x13required_permission\x18\x04 \x01(\x0e\x32,.ai.h2o.featurestore.api.v1.ActivePermission\x12\x13\n\x0bproject_ids\x18\x05 \x03(\t\x12U\n\nsort_field\x18\x06 \x01(\x0e\x32\x41.ai.h2o.featurestore.api.v1.ProjectSearchRequest.ProjectSortField\x12\x41\n\x0esort_direction\x18\x07 \x01(\x0e\x32).ai.h2o.featurestore.api.v1.SortDirection\"\xd7\x01\n\x10ProjectSortField\x12 \n\x1cPROJECT_SORT_FIELD_UNDEFINED\x10\x00\x12\x1b\n\x17PROJECT_SORT_FIELD_NAME\x10\x01\x12\"\n\x1ePROJECT_SORT_FIELD_DESCRIPTION\x10\x02\x12\x1d\n\x19PROJECT_SORT_FIELD_LOCKED\x10\x03\x12\x1d\n\x19PROJECT_SORT_FIELD_AUTHOR\x10\x04\x12\"\n\x1ePROJECT_SORT_FIELD_LAST_UPDATE\x10\x05\"\x93\x04\n\x17\x46\x65\x61tureSetSearchRequest\x12\r\n\x05query\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x12\n\nowned_only\x18\x04 \x01(\x08\x12\x13\n\x0bproject_ids\x18\x05 \x03(\t\x12[\n\nsort_field\x18\x06 \x01(\x0e\x32G.ai.h2o.featurestore.api.v1.FeatureSetSearchRequest.FeatureSetSortField\x12\x41\n\x0esort_direction\x18\x07 \x01(\x0e\x32).ai.h2o.featurestore.api.v1.SortDirection\"\xf8\x01\n\x13\x46\x65\x61tureSetSortField\x12$\n FEATURE_SET_SORT_FIELD_UNDEFINED\x10\x00\x12\x1f\n\x1b\x46\x45\x41TURE_SET_SORT_FIELD_NAME\x10\x01\x12&\n\"FEATURE_SET_SORT_FIELD_DESCRIPTION\x10\x02\x12!\n\x1d\x46\x45\x41TURE_SET_SORT_FIELD_AUTHOR\x10\x03\x12&\n\"FEATURE_SET_SORT_FIELD_LAST_UPDATE\x10\x04\x12\'\n#FEATURE_SET_SORT_FIELD_PROJECT_NAME\x10\x05\"\x86\x03\n\x14\x46\x65\x61tureSearchRequest\x12\r\n\x05query\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\x12\n\nowned_only\x18\x04 \x01(\x08\x12\x13\n\x0bproject_ids\x18\x05 \x03(\t\x12U\n\nsort_field\x18\x06 \x01(\x0e\x32\x41.ai.h2o.featurestore.api.v1.FeatureSearchRequest.FeatureSortField\x12\x41\n\x0esort_direction\x18\x07 \x01(\x0e\x32).ai.h2o.featurestore.api.v1.SortDirection\"u\n\x10\x46\x65\x61tureSortField\x12 \n\x1c\x46\x45\x41TURE_SORT_FIELD_UNDEFINED\x10\x00\x12\x1b\n\x17\x46\x45\x41TURE_SORT_FIELD_NAME\x10\x01\x12\"\n\x1e\x46\x45\x41TURE_SORT_FIELD_DESCRIPTION\x10\x02\"v\n\x14ProjectSearchResults\x12\x45\n\x10listable_project\x18\x01 \x03(\x0b\x32+.ai.h2o.featurestore.api.v1.ListableProject\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xdf\x08\n\x12ListableFeatureSet\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x14\n\x0cproject_name\x18\x04 \x01(\t\x12\x39\n\x15last_update_date_time\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07version\x18\x06 \x01(\t\x12@\n\npermission\x18\x07 \x01(\x0e\x32,.ai.h2o.featurestore.api.v1.ActivePermission\x12\x12\n\nproject_id\x18\x08 \x01(\t\x12\x16\n\x0eversion_change\x18\t \x01(\t\x12\x1a\n\x12time_travel_column\x18\n \x01(\t\x12!\n\x19time_travel_column_format\x18\x0b \x01(\t\x12\x44\n\x10\x66\x65\x61ture_set_type\x18\x0c \x01(\x0e\x32*.ai.h2o.featurestore.api.v1.FeatureSetType\x12\x39\n\x06\x61uthor\x18\r \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\x12\x35\n\x11\x63reated_date_time\x18\x0e \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\ndeprecated\x18\x0f \x01(\x08\x12\x33\n\x0f\x64\x65precated_date\x18\x10 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0c\n\x04tags\x18\x11 \x03(\t\x12<\n\x0ctime_to_live\x18\x12 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.TimeToLive\x12H\n\x0cspecial_data\x18\x13 \x01(\x0b\x32\x32.ai.h2o.featurestore.api.v1.FeatureSet.SpecialData\x12\x13\n\x0bprimary_key\x18\x14 \x03(\t\x12<\n\x11time_travel_scope\x18\x15 \x01(\x0b\x32!.ai.h2o.featurestore.api.v1.Scope\x12\x0e\n\x06secret\x18\x16 \x01(\x08\x12\x14\n\x0cpartition_by\x18\x17 \x03(\t\x12G\n\x1conline_materialization_scope\x18\x18 \x01(\x0b\x32!.ai.h2o.featurestore.api.v1.Scope\x12\x44\n\x0c\x64\x65rived_from\x18\x19 \x01(\x0b\x32..ai.h2o.featurestore.api.v1.DerivedInformation\x12\x1b\n\x13\x66\x65\x61ture_classifiers\x18\x1a \x03(\t\x12\x15\n\rrecords_count\x18\x1b \x01(\x04\x12\x38\n\x04\x66low\x18\x1c \x01(\x0e\x32*.ai.h2o.featurestore.api.v1.FeatureSetFlow\"\x80\x01\n\x17\x46\x65\x61tureSetSearchResults\x12L\n\x14listable_feature_set\x18\x01 \x03(\x0b\x32..ai.h2o.featurestore.api.v1.ListableFeatureSet\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xde\x01\n\x0fListableFeature\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x19\n\x11\x61nomaly_detection\x18\x04 \x01(\x08\x12=\n\x0c\x66\x65\x61ture_type\x18\x05 \x01(\x0e\x32\'.ai.h2o.featurestore.api.v1.FeatureType\x12\x11\n\tdata_type\x18\x06 \x01(\t\x12\x0f\n\x07version\x18\x07 \x01(\t\x12\x12\n\nfeature_id\x18\x08 \x01(\t\"v\n\x14\x46\x65\x61tureSearchResults\x12\x45\n\x10listable_feature\x18\x01 \x03(\x0b\x32+.ai.h2o.featurestore.api.v1.ListableFeature\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"J\n\x13\x46\x65\x61tureSetRequestId\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x1b\n\x13\x66\x65\x61ture_set_version\x18\x02 \x01(\t\"\\\n\x11GetFeatureRequest\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x1b\n\x13\x66\x65\x61ture_set_version\x18\x02 \x01(\t\x12\x12\n\nfeature_id\x18\x03 \x01(\t\"j\n\x18ListFeaturesPageResponse\x12\x35\n\x08\x66\x65\x61tures\x18\x01 \x03(\x0b\x32#.ai.h2o.featurestore.api.v1.Feature\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"G\n\x0f\x46\x65\x61tureResponse\x12\x34\n\x07\x66\x65\x61ture\x18\x01 \x01(\x0b\x32#.ai.h2o.featurestore.api.v1.Feature\"c\n\x13ListFeaturesRequest\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\r\n\x05query\x18\x04 \x01(\t\"f\n\x14ListFeaturesResponse\x12\x35\n\x08\x66\x65\x61tures\x18\x01 \x03(\x0b\x32#.ai.h2o.featurestore.api.v1.Feature\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"P\n\x19ListableFeatureSetRequest\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x1b\n\x13\x66\x65\x61ture_set_version\x18\x02 \x01(\t\"j\n\x1aListableFeatureSetResponse\x12L\n\x14listable_feature_set\x18\x01 \x01(\x0b\x32..ai.h2o.featurestore.api.v1.ListableFeatureSet\"\x85\x01\n\x1eSubmitPendingPermissionRequest\x12\x13\n\x0bresource_id\x18\x01 \x01(\t\x12>\n\npermission\x18\x02 \x01(\x0e\x32*.ai.h2o.featurestore.api.v1.PermissionType\x12\x0e\n\x06reason\x18\x03 \x01(\t\"8\n\x1fSubmitPendingPermissionResponse\x12\x15\n\rpermission_id\x18\x01 \x01(\t\"\x81\x01\n\x1aListPermissionsPageRequest\x12<\n\x07\x66ilters\x18\x01 \x03(\x0e\x32+.ai.h2o.featurestore.api.v1.PermissionState\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\x88\x01\n#ListProjectsPermissionsPageResponse\x12H\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\x37.ai.h2o.featurestore.api.v1.ListableProjectToPermission\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x8e\x01\n&ListFeatureSetsPermissionsPageResponse\x12K\n\x07\x65ntries\x18\x01 \x03(\x0b\x32:.ai.h2o.featurestore.api.v1.ListableFeatureSetToPermission\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\x97\x01\n\x1bListableProjectToPermission\x12<\n\x07project\x18\x01 \x01(\x0b\x32+.ai.h2o.featurestore.api.v1.ListableProject\x12:\n\npermission\x18\x02 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.Permission\"\xa1\x01\n\x1eListableFeatureSetToPermission\x12\x43\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32..ai.h2o.featurestore.api.v1.ListableFeatureSet\x12:\n\npermission\x18\x02 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.Permission\"\xec\x08\n\nPermission\x12\n\n\x02id\x18\x01 \x01(\t\x12\x13\n\x0bresource_id\x18\x02 \x01(\t\x12?\n\rresource_type\x18\x03 \x01(\x0e\x32(.ai.h2o.featurestore.api.v1.ResourceType\x12>\n\npermission\x18\x04 \x01(\x0e\x32*.ai.h2o.featurestore.api.v1.PermissionType\x12\x37\n\x04user\x18\x05 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\x12\x17\n\x0f\x63reation_reason\x18\x06 \x01(\t\x12:\n\x05state\x18\x07 \x01(\x0e\x32+.ai.h2o.featurestore.api.v1.PermissionState\x12.\n\ncreated_on\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0elast_update_on\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06\x61\x63tive\x18\n \x01(\x08\x12[\n\x13granted_or_rejected\x18\x0b \x01(\x0b\x32>.ai.h2o.featurestore.api.v1.Permission.GrantedOrRejectedUpdate\x12\x45\n\x07revoked\x18\x0c \x01(\x0b\x32\x34.ai.h2o.featurestore.api.v1.Permission.RevokedUpdate\x12G\n\x08promoted\x18\r \x01(\x0b\x32\x35.ai.h2o.featurestore.api.v1.Permission.PromotedUpdate\x1a\xac\x01\n\x0ePromotedUpdate\x12\x37\n\x04user\x18\x01 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\x12.\n\nupdated_on\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06reason\x18\x03 \x01(\t\x12!\n\x19replaced_by_permission_id\x18\x04 \x01(\t\x1a\x88\x01\n\rRevokedUpdate\x12\x37\n\x04user\x18\x01 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\x12.\n\nupdated_on\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06reason\x18\x03 \x01(\t\x1a\x92\x01\n\x17GrantedOrRejectedUpdate\x12\x37\n\x04user\x18\x01 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\x12.\n\nupdated_on\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0e\n\x06reason\x18\x03 \x01(\t\"@\n\x17RevokePermissionRequest\x12\x15\n\rpermission_id\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\"H\n\x1f\x41pprovePendingPermissionRequest\x12\x15\n\rpermission_id\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\"G\n\x1eRejectPendingPermissionRequest\x12\x15\n\rpermission_id\x18\x01 \x01(\t\x12\x0e\n\x06reason\x18\x02 \x01(\t\"1\n\x1aGetActivePermissionRequest\x12\x13\n\x0bresource_id\x18\x01 \x01(\t\"_\n\x1bGetActivePermissionResponse\x12@\n\npermission\x18\x01 \x01(\x0e\x32,.ai.h2o.featurestore.api.v1.ActivePermission\"\xcf\x04\n\rScheduledTask\x12\n\n\x02id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x04 \x01(\t\x12\x12\n\nproject_id\x18\x05 \x01(\t\x12;\n\x06source\x18\x06 \x01(\x0b\x32+.ai.h2o.featurestore.api.v1.RawDataLocation\x12\x10\n\x08schedule\x18\x07 \x01(\t\x12\x31\n\rnext_run_time\x18\x08 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tlast_exec\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x38\n\x05owner\x18\n \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\x12\x35\n\x11\x63reated_date_time\x18\x0b \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x39\n\x15last_update_date_time\x18\x0c \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x37\n\ttask_type\x18\r \x01(\x0e\x32$.ai.h2o.featurestore.api.v1.TaskType\x12\x1b\n\x13\x66\x65\x61ture_set_version\x18\x0e \x01(\t\x12\x16\n\x0e\x63ron_time_zone\x18\x0f \x01(\t\x12\x18\n\x10\x61llowed_failures\x18\x10 \x01(\x05\"\xb9\x02\n\x13ScheduleTaskRequest\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x12\n\nproject_id\x18\x04 \x01(\t\x12\x35\n\x04\x63red\x18\x05 \x01(\x0b\x32\'.ai.h2o.featurestore.api.v1.Credentials\x12;\n\x06source\x18\x06 \x01(\x0b\x32+.ai.h2o.featurestore.api.v1.RawDataLocation\x12\x10\n\x08schedule\x18\x07 \x01(\t\x12\x1b\n\x13\x66\x65\x61ture_set_version\x18\x08 \x01(\t\x12\x16\n\x0e\x63ron_time_zone\x18\t \x01(\t\x12\x18\n\x10\x61llowed_failures\x18\n \x01(\x05\"Z\n\x19ListScheduledTasksRequest\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"o\n\x1aListScheduledTasksResponse\x12\x38\n\x05tasks\x18\x01 \x03(\x0b\x32).ai.h2o.featurestore.api.v1.ScheduledTask\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\",\n\x0fScheduledTaskId\x12\x19\n\x11scheduled_task_id\x18\x01 \x01(\t\"P\n\x15ScheduledTaskResponse\x12\x37\n\x04task\x18\x01 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.ScheduledTask\"v\n\x1aScheduledTaskUpdateRequest\x12\x19\n\x11scheduled_task_id\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x10\n\x08schedule\x18\x03 \x01(\t\x12\x16\n\x0eupdated_fields\x18\x04 \x03(\t\"6\n\x19PauseScheduledTaskRequest\x12\x19\n\x11scheduled_task_id\x18\x01 \x01(\t\"i\n\x1aResumeScheduledTaskRequest\x12\x19\n\x11scheduled_task_id\x18\x01 \x01(\t\x12\x16\n\x0esetup_failures\x18\x02 \x01(\x08\x12\x18\n\x10\x61llowed_failures\x18\x03 \x01(\x05\"H\n\x11LazyIngestRequest\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x1b\n\x13\x66\x65\x61ture_set_version\x18\x02 \x01(\t\"G\n\x12LazyIngestResponse\x12\x31\n\x06job_id\x18\x01 \x01(\x0b\x32!.ai.h2o.featurestore.api.v1.JobId\"O\n\x18GetLazyIngestTaskRequest\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x1b\n\x13\x66\x65\x61ture_set_version\x18\x02 \x01(\t\"f\n\"ListScheduledTaskExecutionsRequest\x12\x19\n\x11scheduled_task_id\x18\x01 \x01(\t\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\xe9\x01\n\x16ScheduledTaskExecution\x12\x31\n\x06job_id\x18\x01 \x01(\x0b\x32!.ai.h2o.featurestore.api.v1.JobId\x12.\n\nstarted_at\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12/\n\x0b\x66inished_at\x18\x03 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12;\n\x0c\x66inal_status\x18\x04 \x01(\x0e\x32%.ai.h2o.featurestore.api.v1.JobStatus\"\x8d\x01\n#ListScheduledTaskExecutionsResponse\x12M\n\x11\x65xecution_history\x18\x01 \x03(\x0b\x32\x32.ai.h2o.featurestore.api.v1.ScheduledTaskExecution\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"c\n\x16TransformationFunction\x12\x15\n\rfunction_name\x18\x01 \x01(\t\x12\x1d\n\x15supported_input_types\x18\x02 \x03(\t\x12\x13\n\x0boutput_type\x18\x03 \x01(\t\"$\n\"ListTransformationFunctionsRequest\"{\n#ListTransformationFunctionsResponse\x12T\n\x18transformation_functions\x18\x01 \x03(\x0b\x32\x32.ai.h2o.featurestore.api.v1.TransformationFunction\"H\n GetTransformationFunctionRequest\x12$\n\x1ctransformation_function_name\x18\x01 \x01(\t\"x\n!GetTransformationFunctionResponse\x12S\n\x17transformation_function\x18\x01 \x01(\x0b\x32\x32.ai.h2o.featurestore.api.v1.TransformationFunction\"\xda\x01\n\x14UpdateProjectRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x0e\n\x06locked\x18\x02 \x01(\x08\x12\x0e\n\x06secret\x18\x03 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12,\n\x0b\x63ustom_data\x18\x05 \x01(\x0b\x32\x17.google.protobuf.Struct\x12K\n\x10\x66ields_to_update\x18\x06 \x03(\x0e\x32\x31.ai.h2o.featurestore.api.v1.UpdatableProjectField\"\xbc\x07\n\x17UpdateFeatureSetRequest\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x1b\n\x13\x66\x65\x61ture_set_version\x18\x02 \x01(\t\x12\x0c\n\x04tags\x18\x03 \x03(\t\x12\x1b\n\x13\x64\x61ta_source_domains\x18\x04 \x03(\t\x12\x13\n\x0b\x64\x65scription\x18\x05 \x01(\t\x12\x38\n\x04type\x18\x06 \x01(\x0e\x32*.ai.h2o.featurestore.api.v1.FeatureSetType\x12\x12\n\ndeprecated\x18\x07 \x01(\x08\x12\x18\n\x10process_interval\x18\x08 \x01(\x05\x12N\n\x15process_interval_unit\x18\t \x01(\x0e\x32/.ai.h2o.featurestore.api.v1.ProcessIntervalUnit\x12\x0e\n\x06secret\x18\n \x01(\x08\x12%\n\x1dtime_to_live_offline_interval\x18\x0b \x01(\r\x12\x62\n\"time_to_live_offline_interval_unit\x18\x0c \x01(\x0e\x32\x36.ai.h2o.featurestore.api.v1.Offline.TimeToLiveInterval\x12$\n\x1ctime_to_live_online_interval\x18\r \x01(\r\x12`\n!time_to_live_online_interval_unit\x18\x0e \x01(\x0e\x32\x35.ai.h2o.featurestore.api.v1.Online.TimeToLiveInterval\x12\x16\n\x0elegal_approved\x18\x0f \x01(\x08\x12\x1c\n\x14legal_approved_notes\x18\x10 \x01(\t\x12\r\n\x05state\x18\x11 \x01(\t\x12\x0c\n\x04\x66low\x18\x12 \x01(\t\x12\x18\n\x10\x61pplication_name\x18\x13 \x01(\t\x12\x16\n\x0e\x61pplication_id\x18\x14 \x01(\t\x12,\n\x0b\x63ustom_data\x18\x15 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x18\n\x10online_namespace\x18\x16 \x01(\t\x12\x14\n\x0conline_topic\x18\x17 \x01(\t\x12\x1e\n\x16online_connection_type\x18\x18 \x01(\t\x12N\n\x10\x66ields_to_update\x18\x19 \x03(\x0e\x32\x34.ai.h2o.featurestore.api.v1.UpdatableFeatureSetField\"\x8b\x03\n\x14UpdateFeatureRequest\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x1b\n\x13\x66\x65\x61ture_set_version\x18\x02 \x01(\t\x12\x12\n\nfeature_id\x18\x03 \x01(\t\x12\x0e\n\x06status\x18\x04 \x01(\t\x12\x35\n\x04type\x18\x05 \x01(\x0e\x32\'.ai.h2o.featurestore.api.v1.FeatureType\x12\x12\n\nimportance\x18\x06 \x01(\x01\x12,\n\x0b\x63ustom_data\x18\x07 \x01(\x0b\x32\x17.google.protobuf.Struct\x12\x13\n\x0b\x64\x65scription\x18\x08 \x01(\t\x12\x0f\n\x07special\x18\t \x01(\t\x12\x19\n\x11\x61nomaly_detection\x18\n \x01(\x08\x12\x13\n\x0b\x63lassifiers\x18\x0b \x03(\t\x12K\n\x10\x66ields_to_update\x18\x0c \x03(\x0e\x32\x31.ai.h2o.featurestore.api.v1.UpdatableFeatureField\"\'\n\x10GetOwnersRequest\x12\x13\n\x0bresource_id\x18\x01 \x01(\t\"N\n\x11GetOwnersResponse\x12\x39\n\x06owners\x18\x01 \x03(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\"\xe5\x02\n\x0f\x42\x61\x63kfillOptions\x12-\n\tfrom_date\x18\x01 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12+\n\x07to_date\x18\x02 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x14\n\x0c\x66rom_version\x18\x03 \x01(\t\x12O\n\x0espark_pipeline\x18\x04 \x01(\x0b\x32\x37.ai.h2o.featurestore.api.v1.SparkPipelineTransformation\x12X\n\x0f\x66\x65\x61ture_mapping\x18\x05 \x03(\x0b\x32?.ai.h2o.featurestore.api.v1.BackfillOptions.FeatureMappingEntry\x1a\x35\n\x13\x46\x65\x61tureMappingEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"W\n\x10\x42\x61\x63kfillResponse\x12\x43\n\x0fingest_response\x18\x01 \x01(\x0b\x32*.ai.h2o.featurestore.api.v1.IngestResponse\"\xe1\x01\n\x16\x46\x65\x61tureSetDraftRequest\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0c\n\x04tags\x18\x04 \x03(\t\x12\x35\n\x04\x63red\x18\x05 \x01(\x0b\x32\'.ai.h2o.featurestore.api.v1.Credentials\x12;\n\x06source\x18\x06 \x01(\x0b\x32+.ai.h2o.featurestore.api.v1.RawDataLocation\x12\x0e\n\x06secret\x18\x07 \x01(\x08\"\x93\x03\n\x18\x44raftToFeatureSetRequest\x12\n\n\x02id\x18\x01 \x01(\x04\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12>\n\x06schema\x18\x05 \x03(\x0b\x32..ai.h2o.featurestore.api.v1.FeatureSchemaDraft\x12\x61\n\x12time_travel_column\x18\x06 \x01(\x0b\x32\x45.ai.h2o.featurestore.api.v1.DraftToFeatureSetRequest.TimeTravelColumn\x12\x0e\n\x06secret\x18\x07 \x01(\x08\x12\x0c\n\x04tags\x18\x08 \x03(\t\x1as\n\x10TimeTravelColumn\x12\x1f\n\x17time_travel_column_name\x18\x01 \x01(\t\x12!\n\x19time_travel_column_format\x18\x02 \x01(\t\x12\x1b\n\x13is_partition_column\x18\x03 \x01(\x08\"3\n\x19\x44raftToFeatureSetResponse\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\"\xc9\x03\n\x12\x46\x65\x61tureSchemaDraft\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x11\n\tdata_type\x18\x02 \x01(\t\x12>\n\x06nested\x18\x03 \x03(\x0b\x32..ai.h2o.featurestore.api.v1.FeatureSchemaDraft\x12P\n\x0cspecial_data\x18\x04 \x01(\x0b\x32:.ai.h2o.featurestore.api.v1.FeatureSchemaDraft.SpecialData\x12=\n\x0c\x66\x65\x61ture_type\x18\x05 \x01(\x0e\x32\'.ai.h2o.featurestore.api.v1.FeatureType\x12\x13\n\x0b\x64\x65scription\x18\x06 \x01(\t\x12\x19\n\x11\x61nomaly_detection\x18\x07 \x01(\x08\x12\x16\n\x0eis_primary_key\x18\x08 \x01(\x08\x12\x1b\n\x13is_partition_column\x18\t \x01(\x08\x1a\\\n\x0bSpecialData\x12\x0b\n\x03spi\x18\x01 \x01(\x08\x12\x0b\n\x03pci\x18\x02 \x01(\x08\x12\x0b\n\x03rpi\x18\x03 \x01(\x08\x12\x13\n\x0b\x64\x65mographic\x18\x04 \x01(\x08\x12\x11\n\tsensitive\x18\x05 \x01(\x08\"1\n\x11\x46\x65\x61tureSetDraftId\x12\x1c\n\x14\x66\x65\x61ture_set_draft_id\x18\x01 \x01(\x04\"D\n\x1bListFeatureSetDraftsRequest\x12\x11\n\tpage_size\x18\x01 \x01(\x05\x12\x12\n\npage_token\x18\x02 \x01(\t\"\xe6\x03\n\x17ListableFeatureSetDraft\x12\x1c\n\x14\x66\x65\x61ture_set_draft_id\x18\x01 \x01(\x04\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x14\n\x0cproject_name\x18\x04 \x01(\t\x12\x38\n\x05owner\x18\x05 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\x12Y\n\x06status\x18\x06 \x01(\x0e\x32I.ai.h2o.featurestore.api.v1.ListableFeatureSetDraft.FeatureSetDraftStatus\x12\x15\n\rerror_message\x18\x07 \x01(\t\x12\x0e\n\x06job_id\x18\x08 \x01(\t\"\xb7\x01\n\x15\x46\x65\x61tureSetDraftStatus\x12(\n$FEATURE_SET_DRAFT_STATUS_UNSPECIFIED\x10\x00\x12(\n$FEATURE_SET_DRAFT_STATUS_IN_PROGRESS\x10\x01\x12%\n!FEATURE_SET_DRAFT_STATUS_FINISHED\x10\x02\x12#\n\x1f\x46\x45\x41TURE_SET_DRAFT_STATUS_FAILED\x10\x03\"\xc4\x01\n\x0f\x46\x65\x61tureSetDraft\x12\x1c\n\x14\x66\x65\x61ture_set_draft_id\x18\x01 \x01(\x04\x12\x12\n\nproject_id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x04 \x01(\t\x12>\n\x06schema\x18\x05 \x03(\x0b\x32..ai.h2o.featurestore.api.v1.FeatureSchemaDraft\x12\x0e\n\x06secret\x18\x06 \x01(\x08\x12\x0c\n\x04tags\x18\x07 \x03(\t\"|\n\x1cListFeatureSetDraftsResponse\x12\x43\n\x06\x64rafts\x18\x01 \x03(\x0b\x32\x33.ai.h2o.featurestore.api.v1.ListableFeatureSetDraft\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"a\n\x17\x46\x65\x61tureSetDraftResponse\x12\x46\n\x11\x66\x65\x61ture_set_draft\x18\x01 \x01(\x0b\x32+.ai.h2o.featurestore.api.v1.FeatureSetDraft\"\xec\x01\n\x08\x41rtifact\x12\x13\n\x0b\x61rtifact_id\x18\x01 \x01(\x04\x12\r\n\x05title\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x10\n\x08\x66ilename\x18\x04 \x01(\t\x12\x0b\n\x03url\x18\x05 \x01(\t\x12?\n\rartifact_type\x18\x06 \x01(\x0e\x32(.ai.h2o.featurestore.api.v1.ArtifactType\x12G\n\rupload_status\x18\x07 \x01(\x0e\x32\x30.ai.h2o.featurestore.api.v1.ArtifactUploadStatus\"\xaf\x01\n\x18StoreFileArtifactRequest\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\x11\n\tfile_name\x18\x04 \x01(\t\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x05 \x01(\t\x12!\n\x19\x66\x65\x61ture_set_major_version\x18\x06 \x01(\r\x12\x14\n\x0cmd5_checksum\x18\x07 \x01(\t\"\xd4\x01\n\x19StoreFileArtifactResponse\x12\x13\n\x0b\x61rtifact_id\x18\x01 \x01(\x04\x12\x10\n\x08\x66ilename\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\x12S\n\x07headers\x18\x04 \x03(\x0b\x32\x42.ai.h2o.featurestore.api.v1.StoreFileArtifactResponse.HeadersEntry\x1a.\n\x0cHeadersEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\".\n\x17RetrieveArtifactRequest\x12\x13\n\x0b\x61rtifact_id\x18\x01 \x01(\x04\"R\n\x18RetrieveArtifactResponse\x12\x36\n\x08\x61rtifact\x18\x01 \x01(\x0b\x32$.ai.h2o.featurestore.api.v1.Artifact\"y\n\x19UpdateUploadStatusRequest\x12\x13\n\x0b\x61rtifact_id\x18\x01 \x01(\x04\x12G\n\rupload_status\x18\x02 \x01(\x0e\x32\x30.ai.h2o.featurestore.api.v1.ArtifactUploadStatus\",\n\x15\x44\x65leteArtifactRequest\x12\x13\n\x0b\x61rtifact_id\x18\x01 \x01(\x04\"x\n\x14ListArtifactsRequest\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12!\n\x19\x66\x65\x61ture_set_major_version\x18\x02 \x01(\r\x12\x11\n\tpage_size\x18\x03 \x01(\x05\x12\x12\n\npage_token\x18\x04 \x01(\t\"i\n\x15ListArtifactsResponse\x12\x37\n\tartifacts\x18\x01 \x03(\x0b\x32$.ai.h2o.featurestore.api.v1.Artifact\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"~\n\x10StoreLinkRequest\x12\r\n\x05title\x18\x01 \x01(\t\x12\x13\n\x0b\x64\x65scription\x18\x02 \x01(\t\x12\x0b\n\x03url\x18\x03 \x01(\t\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x04 \x01(\t\x12!\n\x19\x66\x65\x61ture_set_major_version\x18\x05 \x01(\r\"\xc9\x01\n\x14\x46\x65\x61tureSetPopularity\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x1c\n\x14number_of_retrievals\x18\x02 \x01(\x04\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x03 \x01(\t\x12\x1f\n\x17\x66\x65\x61ture_set_description\x18\x04 \x01(\t\x12@\n\npermission\x18\x05 \x01(\x0e\x32,.ai.h2o.featurestore.api.v1.ActivePermission\"g\n\x1d\x46\x65\x61tureSetsPopularityResponse\x12\x46\n\x0c\x66\x65\x61ture_sets\x18\x01 \x03(\x0b\x32\x30.ai.h2o.featurestore.api.v1.FeatureSetPopularity\"\x82\x01\n\x1eListFeatureSetsToReviewRequest\x12\x11\n\tpage_size\x18\x01 \x01(\x05\x12\x12\n\npage_token\x18\x02 \x01(\t\x12\x39\n\x07\x66ilters\x18\x03 \x03(\x0e\x32(.ai.h2o.featurestore.api.v1.ReviewStatus\"{\n\x1fListFeatureSetsToReviewResponse\x12?\n\x07\x65ntries\x18\x01 \x03(\x0b\x32..ai.h2o.featurestore.api.v1.FeatureSetToReview\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"\xb6\x02\n\x12\x46\x65\x61tureSetToReview\x12\x11\n\treview_id\x18\x01 \x01(\x04\x12\x14\n\x0cproject_name\x18\x02 \x01(\t\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x03 \x01(\t\x12\x38\n\x05owner\x18\x04 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\x12.\n\ncreated_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x38\n\x06status\x18\x07 \x01(\x0e\x32(.ai.h2o.featurestore.api.v1.ReviewStatus\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x08 \x01(\t\x12!\n\x19\x66\x65\x61ture_set_major_version\x18\t \x01(\r\"9\n\x14\x41pproveReviewRequest\x12\x11\n\treview_id\x18\x01 \x01(\x04\x12\x0e\n\x06reason\x18\x02 \x01(\t\"8\n\x13RejectReviewRequest\x12\x11\n\treview_id\x18\x01 \x01(\x04\x12\x0e\n\x06reason\x18\x02 \x01(\t\"\x84\x01\n ListFeatureSetReviewsPageRequest\x12\x39\n\x07\x66ilters\x18\x01 \x03(\x0e\x32(.ai.h2o.featurestore.api.v1.ReviewStatus\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\"\xf8\x02\n\x10\x46\x65\x61tureSetReview\x12\x11\n\treview_id\x18\x01 \x01(\x04\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x02 \x01(\t\x12!\n\x19\x66\x65\x61ture_set_major_version\x18\x03 \x01(\r\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x04 \x01(\t\x12\x14\n\x0cproject_name\x18\x05 \x01(\t\x12\x38\n\x06status\x18\x06 \x01(\x0e\x32(.ai.h2o.featurestore.api.v1.ReviewStatus\x12\x0e\n\x06reason\x18\x07 \x01(\t\x12;\n\x08reviewer\x18\x08 \x01(\x0b\x32).ai.h2o.featurestore.api.v1.UserBasicInfo\x12/\n\x0breviewed_at\x18\t \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12.\n\ncreated_at\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"{\n!ListFeatureSetReviewsPageResponse\x12=\n\x07\x65ntries\x18\x01 \x03(\x0b\x32,.ai.h2o.featurestore.api.v1.FeatureSetReview\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"9\n$GetListableFeatureSetToReviewRequest\x12\x11\n\treview_id\x18\x01 \x01(\x04\"u\n%GetListableFeatureSetToReviewResponse\x12L\n\x14listable_feature_set\x18\x01 \x01(\x0b\x32..ai.h2o.featurestore.api.v1.ListableFeatureSet\"9\n$GetListableFeatureSetInReviewRequest\x12\x11\n\treview_id\x18\x01 \x01(\x04\"u\n%GetListableFeatureSetInReviewResponse\x12L\n\x14listable_feature_set\x18\x01 \x01(\x0b\x32..ai.h2o.featurestore.api.v1.ListableFeatureSet\"4\n\x1f\x44\x65leteRejectedFeatureSetRequest\x12\x11\n\treview_id\x18\x01 \x01(\x04\"f\n\x1bListFeaturesToReviewRequest\x12\x11\n\treview_id\x18\x01 \x01(\x04\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\r\n\x05query\x18\x04 \x01(\t\"n\n\x1cListFeaturesToReviewResponse\x12\x35\n\x08\x66\x65\x61tures\x18\x01 \x03(\x0b\x32#.ai.h2o.featurestore.api.v1.Feature\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"f\n\x1bListFeaturesInReviewRequest\x12\x11\n\treview_id\x18\x01 \x01(\x04\x12\x11\n\tpage_size\x18\x02 \x01(\x05\x12\x12\n\npage_token\x18\x03 \x01(\t\x12\r\n\x05query\x18\x04 \x01(\t\"n\n\x1cListFeaturesInReviewResponse\x12\x35\n\x08\x66\x65\x61tures\x18\x01 \x03(\x0b\x32#.ai.h2o.featurestore.api.v1.Feature\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"8\n#GetFeatureSetPreviewToReviewRequest\x12\x11\n\treview_id\x18\x01 \x01(\x04\"Q\n$GetFeatureSetPreviewToReviewResponse\x12\x13\n\x0bpreview_url\x18\x01 \x01(\t\x12\x14\n\x0cmax_cols_num\x18\x02 \x01(\r\"8\n#GetFeatureSetPreviewInReviewRequest\x12\x11\n\treview_id\x18\x01 \x01(\x04\"Q\n$GetFeatureSetPreviewInReviewResponse\x12\x13\n\x0bpreview_url\x18\x01 \x01(\t\x12\x14\n\x0cmax_cols_num\x18\x02 \x01(\r\"1\n\x1cGetFeatureSetToReviewRequest\x12\x11\n\treview_id\x18\x01 \x01(\x04\"\\\n\x1dGetFeatureSetToReviewResponse\x12;\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSet\"1\n\x1cGetFeatureSetInReviewRequest\x12\x11\n\treview_id\x18\x01 \x01(\x04\"\\\n\x1dGetFeatureSetInReviewResponse\x12;\n\x0b\x66\x65\x61ture_set\x18\x01 \x01(\x0b\x32&.ai.h2o.featurestore.api.v1.FeatureSet\"\xc0\x01\n\x13RecentlyUsedProject\x12\x12\n\nproject_id\x18\x01 \x01(\t\x12\x14\n\x0cproject_name\x18\x02 \x01(\t\x12\x1b\n\x13project_description\x18\x03 \x01(\t\x12.\n\nupdated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0elast_access_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"a\n\x1cRecentlyUsedProjectsResponse\x12\x41\n\x08projects\x18\x01 \x03(\x0b\x32/.ai.h2o.featurestore.api.v1.RecentlyUsedProject\"\xcf\x01\n\x16RecentlyUsedFeatureSet\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x02 \x01(\t\x12\x1f\n\x17\x66\x65\x61ture_set_description\x18\x03 \x01(\t\x12.\n\nupdated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x32\n\x0elast_access_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\"k\n\x1fRecentlyUsedFeatureSetsResponse\x12H\n\x0c\x66\x65\x61ture_sets\x18\x01 \x03(\x0b\x32\x32.ai.h2o.featurestore.api.v1.RecentlyUsedFeatureSet\"_\n\x14TargetFeatureRequest\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x1b\n\x13\x66\x65\x61ture_set_version\x18\x02 \x01(\t\x12\x12\n\nfeature_id\x18\x03 \x01(\t\"P\n\x19ListTargetFeaturesRequest\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x1b\n\x13\x66\x65\x61ture_set_version\x18\x02 \x01(\t\"B\n\x16TargetFeatureReference\x12\x12\n\nfeature_id\x18\x01 \x01(\t\x12\x14\n\x0c\x66\x65\x61ture_name\x18\x02 \x01(\t\"b\n\x1aListTargetFeaturesResponse\x12\x44\n\x08\x66\x65\x61tures\x18\x01 \x03(\x0b\x32\x32.ai.h2o.featurestore.api.v1.TargetFeatureReference\"\xc1\x01\n#ListJobsPageByFeatureSetNameRequest\x12\x11\n\tpage_size\x18\x01 \x01(\x05\x12\x12\n\npage_token\x18\x02 \x01(\t\x12\x41\n\rstatus_filter\x18\x03 \x01(\x0e\x32%.ai.h2o.featurestore.api.v1.JobStatusH\x00\x88\x01\x01\x12\x1e\n\x16\x66\x65\x61ture_set_name_query\x18\x04 \x01(\tB\x10\n\x0e_status_filter\"\xb7\x01\n!ListJobsPageByFeatureSetIdRequest\x12\x11\n\tpage_size\x18\x01 \x01(\x05\x12\x12\n\npage_token\x18\x02 \x01(\t\x12\x41\n\rstatus_filter\x18\x03 \x01(\x0e\x32%.ai.h2o.featurestore.api.v1.JobStatusH\x00\x88\x01\x01\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x04 \x01(\tB\x10\n\x0e_status_filter\"m\n\x18\x46\x65\x61tureSetJobRelatedInfo\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x02 \x01(\t\x12\x1f\n\x17\x66\x65\x61ture_set_description\x18\x03 \x01(\t\"\xe0\x01\n\x0bListableJob\x12R\n\x14\x66\x65\x61ture_set_job_info\x18\x01 \x01(\x0b\x32\x34.ai.h2o.featurestore.api.v1.FeatureSetJobRelatedInfo\x12,\n\x03job\x18\x02 \x01(\x0b\x32\x1f.ai.h2o.featurestore.api.v1.Job\x12;\n\nchild_jobs\x18\x03 \x03(\x0b\x32\'.ai.h2o.featurestore.api.v1.ListableJob\x12\x12\n\nis_derived\x18\x04 \x01(\x08\"i\n\x14ListJobsPageResponse\x12\x38\n\x07\x65ntries\x18\x01 \x03(\x0b\x32\'.ai.h2o.featurestore.api.v1.ListableJob\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"]\n\x1dGetJobsWithStatusCountRequest\x12<\n\rstatus_filter\x18\x01 \x01(\x0e\x32%.ai.h2o.featurestore.api.v1.JobStatus\"4\n\x1eGetJobsWithStatusCountResponse\x12\x12\n\njobs_count\x18\x01 \x01(\r\".\n\x14PinFeatureSetRequest\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\"0\n\x16UnpinFeatureSetRequest\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\"A\n\x18PinnedFeatureSetsRequest\x12\x11\n\tpage_size\x18\x01 \x01(\x05\x12\x12\n\npage_token\x18\x02 \x01(\t\"\xd8\x01\n\x10PinnedFeatureSet\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\x12\x18\n\x10\x66\x65\x61ture_set_name\x18\x02 \x01(\t\x12\x1f\n\x17\x66\x65\x61ture_set_description\x18\x03 \x01(\t\x12.\n\nupdated_at\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12-\n\tpinned_at\x18\x05 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x12\n\nuser_order\x18\x06 \x01(\x03\"x\n\x19PinnedFeatureSetsResponse\x12\x42\n\x0c\x66\x65\x61ture_sets\x18\x01 \x03(\x0b\x32,.ai.h2o.featurestore.api.v1.PinnedFeatureSet\x12\x17\n\x0fnext_page_token\x18\x02 \x01(\t\"3\n\x19IsFeatureSetPinnedRequest\x12\x16\n\x0e\x66\x65\x61ture_set_id\x18\x01 \x01(\t\",\n\x1aIsFeatureSetPinnedResponse\x12\x0e\n\x06pinned\x18\x01 \x01(\x08*\x90\x02\n\x07JobType\x12\x0b\n\x07Unknown\x10\x00\x12\n\n\x06Ingest\x10\x01\x12\x0c\n\x08Retrieve\x10\x02\x12\x11\n\rExtractSchema\x10\x03\x12\x15\n\x11\x43omputeStatistics\x10\x05\x12\n\n\x06Revert\x10\x06\x12\x19\n\x15MaterializationOnline\x10\x07\x12$\n ComputeRecommendationClassifiers\x10\x08\x12\x13\n\x0f\x43reateMLDataset\x10\t\x12\x1e\n\x1a\x46\x65\x61tureViewRetrieveAsLinks\x10\n\x12\x1e\n\x1a\x46\x65\x61tureViewRetrieveAsSpark\x10\x0b\x12\x0c\n\x08\x42\x61\x63kfill\x10\x0c\"\x04\x08\x04\x10\x04*X\n\x0ePermissionType\x12\t\n\x05Owner\x10\x00\x12\n\n\x06\x45\x64itor\x10\x01\x12\x0c\n\x08\x43onsumer\x10\x02\x12\x15\n\x11SensitiveConsumer\x10\x03\x12\n\n\x06Viewer\x10\x04*\xd1\x01\n\x10\x41\x63tivePermission\x12\x1a\n\x16\x41\x43TIVE_PERMISSION_NONE\x10\x00\x12\x1b\n\x17\x41\x43TIVE_PERMISSION_OWNER\x10\x01\x12\x1c\n\x18\x41\x43TIVE_PERMISSION_EDITOR\x10\x02\x12\x1e\n\x1a\x41\x43TIVE_PERMISSION_CONSUMER\x10\x03\x12(\n$ACTIVE_PERMISSION_SENSITIVE_CONSUMER\x10\x04\x12\x1c\n\x18\x41\x43TIVE_PERMISSION_VIEWER\x10\x05*9\n\rProjectAction\x12\x13\n\x0fPROJECT_CREATED\x10\x00\x12\x13\n\x0fPROJECT_UPDATED\x10\x01*q\n\x08JoinType\x12\x13\n\x0fJOIN_TYPE_INNER\x10\x00\x12\x12\n\x0eJOIN_TYPE_LEFT\x10\x01\x12\x13\n\x0fJOIN_TYPE_RIGHT\x10\x02\x12\x12\n\x0eJOIN_TYPE_FULL\x10\x03\x12\x13\n\x0fJOIN_TYPE_CROSS\x10\x04*\xfc\x01\n\x15\x46\x65\x61tureFilterOperator\x12#\n\x1f\x46\x45\x41TURE_FILTER_OPERATOR_UNKNOWN\x10\x00\x12\x1e\n\x1a\x46\x45\x41TURE_FILTER_OPERATOR_EQ\x10\x01\x12\x1e\n\x1a\x46\x45\x41TURE_FILTER_OPERATOR_LT\x10\x02\x12\x1e\n\x1a\x46\x45\x41TURE_FILTER_OPERATOR_LE\x10\x03\x12\x1e\n\x1a\x46\x45\x41TURE_FILTER_OPERATOR_GT\x10\x04\x12\x1e\n\x1a\x46\x45\x41TURE_FILTER_OPERATOR_GE\x10\x05\x12\x1e\n\x1a\x46\x45\x41TURE_FILTER_OPERATOR_NE\x10\x06*\x94\x01\n\x1a\x46\x65\x61tureFilterLogicOperator\x12)\n%FEATURE_FILTER_LOGIC_OPERATOR_UNKNOWN\x10\x00\x12%\n!FEATURE_FILTER_LOGIC_OPERATOR_AND\x10\x01\x12$\n FEATURE_FILTER_LOGIC_OPERATOR_OR\x10\x02*Q\n\x14\x46\x65\x61tureQueryJoinType\x12\x1c\n\x18\x46\x45\x41TURE_QUERY_JOIN_INNER\x10\x00\x12\x1b\n\x17\x46\x45\x41TURE_QUERY_JOIN_LEFT\x10\x01*\x96\x01\n\x0f\x46\x65\x61tureDataType\x12\x0b\n\x07TinyInt\x10\x00\x12\x0c\n\x08SmallInt\x10\x01\x12\n\n\x06\x42igInt\x10\x02\x12\x07\n\x03Int\x10\x03\x12\t\n\x05\x46loat\x10\x04\x12\n\n\x06\x44ouble\x10\x05\x12\n\n\x06String\x10\x06\x12\n\n\x06\x42inary\x10\x07\x12\x0b\n\x07\x42oolean\x10\x08\x12\x08\n\x04\x44\x61te\x10\t\x12\r\n\tTimestamp\x10\n*q\n\x13ProcessIntervalUnit\x12\r\n\tUNDEFINED\x10\x00\x12\t\n\x05HOURS\x10\x01\x12\n\n\x06MONTHS\x10\x02\x12\x08\n\x04\x44\x41YS\x10\x03\x12\x0b\n\x07MINUTES\x10\x04\x12\x0b\n\x07SECONDS\x10\x05\x12\x10\n\x0cMILLISECONDS\x10\x06*h\n\x12TransformationType\x12\x19\n\x15TransformationUnknown\x10\x00\x12\x16\n\x12TransformationMojo\x10\x01\x12\x1f\n\x1bTransformationSparkPipeline\x10\x02*,\n\rSortDirection\x12\x0c\n\x08SORT_ASC\x10\x00\x12\r\n\tSORT_DESC\x10\x01*,\n\x0cResourceType\x12\x0b\n\x07PROJECT\x10\x00\x12\x0f\n\x0b\x46\x45\x41TURE_SET\x10\x01*T\n\x0fPermissionState\x12\x0b\n\x07PENDING\x10\x00\x12\x0b\n\x07GRANTED\x10\x01\x12\x0c\n\x08REJECTED\x10\x02\x12\x0b\n\x07REVOKED\x10\x03\x12\x0c\n\x08PROMOTED\x10\x04*\'\n\x08TaskType\x12\n\n\x06INGEST\x10\x00\x12\x0f\n\x0bLAZY_INGEST\x10\x01*\x8f\x01\n\tJobStatus\x12\x0b\n\x07\x43reated\x10\x00\x12\r\n\tSubmitted\x10\x01\x12\x0b\n\x07Running\x10\x02\x12\x14\n\x10SubmissionFailed\x10\x03\x12\n\n\x06\x46\x61iled\x10\x04\x12\x0b\n\x07Success\x10\x06\x12\x0b\n\x07Pending\x10\x07\x12\x10\n\x0cPendingRerun\x10\x08\x12\x0b\n\x07\x46\x61iling\x10\t*\x8a\x01\n\x15UpdatableProjectField\x12\x17\n\x13PROJECT_UNSPECIFIED\x10\x00\x12\x12\n\x0ePROJECT_LOCKED\x10\x01\x12\x12\n\x0ePROJECT_SECRET\x10\x02\x12\x17\n\x13PROJECT_DESCRIPTION\x10\x03\x12\x17\n\x13PROJECT_CUSTOM_DATA\x10\x04*\xf1\x05\n\x18UpdatableFeatureSetField\x12\x1b\n\x17\x46\x45\x41TURE_SET_UNSPECIFIED\x10\x00\x12\x14\n\x10\x46\x45\x41TURE_SET_TAGS\x10\x01\x12#\n\x1f\x46\x45\x41TURE_SET_DATA_SOURCE_DOMAINS\x10\x02\x12\x1b\n\x17\x46\x45\x41TURE_SET_DESCRIPTION\x10\x03\x12\x14\n\x10\x46\x45\x41TURE_SET_TYPE\x10\x04\x12 \n\x1c\x46\x45\x41TURE_SET_APPLICATION_NAME\x10\x05\x12\x1e\n\x1a\x46\x45\x41TURE_SET_APPLICATION_ID\x10\x06\x12\x1a\n\x16\x46\x45\x41TURE_SET_DEPRECATED\x10\x07\x12 \n\x1c\x46\x45\x41TURE_SET_PROCESS_INTERVAL\x10\x08\x12%\n!FEATURE_SET_PROCESS_INTERVAL_UNIT\x10\t\x12\x14\n\x10\x46\x45\x41TURE_SET_FLOW\x10\n\x12\x15\n\x11\x46\x45\x41TURE_SET_STATE\x10\x0b\x12\x16\n\x12\x46\x45\x41TURE_SET_SECRET\x10\x0c\x12\x1b\n\x17\x46\x45\x41TURE_SET_TTL_OFFLINE\x10\r\x12$\n FEATURE_SET_TTL_OFFLINE_INTERVAL\x10\x0e\x12\x1a\n\x16\x46\x45\x41TURE_SET_TTL_ONLINE\x10\x0f\x12#\n\x1f\x46\x45\x41TURE_SET_TTL_ONLINE_INTERVAL\x10\x10\x12\x1b\n\x17\x46\x45\x41TURE_SET_CUSTOM_DATA\x10\x11\x12+\n\'FEATURE_SET_SPECIAL_DATA_LEGAL_APPROVED\x10\x12\x12(\n$FEATURE_SET_SPECIAL_DATA_LEGAL_NOTES\x10\x13\x12 \n\x1c\x46\x45\x41TURE_SET_ONLINE_NAMESPACE\x10\x14\x12\x1c\n\x18\x46\x45\x41TURE_SET_ONLINE_TOPIC\x10\x15\x12&\n\"FEATURE_SET_ONLINE_CONNECTION_TYPE\x10\x16*\xed\x01\n\x15UpdatableFeatureField\x12\x17\n\x13\x46\x45\x41TURE_UNSPECIFIED\x10\x00\x12\x12\n\x0e\x46\x45\x41TURE_STATUS\x10\x01\x12\x10\n\x0c\x46\x45\x41TURE_TYPE\x10\x02\x12\x16\n\x12\x46\x45\x41TURE_IMPORTANCE\x10\x03\x12\x17\n\x13\x46\x45\x41TURE_CUSTOM_DATA\x10\x04\x12\x17\n\x13\x46\x45\x41TURE_DESCRIPTION\x10\x05\x12\x13\n\x0f\x46\x45\x41TURE_SPECIAL\x10\x06\x12\x1d\n\x19\x46\x45\x41TURE_ANOMALY_DETECTION\x10\x07\x12\x17\n\x13\x46\x45\x41TURE_CLASSIFIERS\x10\x08*]\n\x0c\x41rtifactType\x12\x1d\n\x19\x41RTIFACT_TYPE_UNSPECIFIED\x10\x00\x12\x16\n\x12\x41RTIFACT_TYPE_LINK\x10\x01\x12\x16\n\x12\x41RTIFACT_TYPE_FILE\x10\x02*\xad\x01\n\x14\x41rtifactUploadStatus\x12)\n%ARTIFACT_UPLOAD_STATUS_NOT_APPLICABLE\x10\x00\x12&\n\"ARTIFACT_UPLOAD_STATUS_IN_PROGRESS\x10\x01\x12\x1f\n\x1b\x41RTIFACT_UPLOAD_STATUS_DONE\x10\x02\x12!\n\x1d\x41RTIFACT_UPLOAD_STATUS_FAILED\x10\x03*\x82\x01\n\x0cReviewStatus\x12\x1d\n\x19REVIEW_STATUS_UNSPECIFIED\x10\x00\x12\x1b\n\x17REVIEW_STATUS_TO_REVIEW\x10\x01\x12\x1a\n\x16REVIEW_STATUS_APPROVED\x10\x02\x12\x1a\n\x16REVIEW_STATUS_REJECTED\x10\x03\x32\x81\xda\x01\n\x0b\x43oreService\x12{\n\x08ListJobs\x12+.ai.h2o.featurestore.api.v1.ListJobsRequest\x1a,.ai.h2o.featurestore.api.v1.ListJobsResponse\"\x14\x82\xd3\xe4\x93\x02\x0e\x12\x0c/api/v1/jobs\x12k\n\x06GetJob\x12!.ai.h2o.featurestore.api.v1.JobId\x1a\x1f.ai.h2o.featurestore.api.v1.Job\"\x1d\x82\xd3\xe4\x93\x02\x17\x12\x15/api/v1/jobs/{job_id}\x12\xa2\x01\n\x0eGetJobProgress\x12,.ai.h2o.featurestore.api.v1.JobProgressInput\x1a-.ai.h2o.featurestore.api.v1.JobProgressOutput\"3\x82\xd3\xe4\x93\x02-\x12+/api/v1/jobs/{job_id}/progress/{next_index}\x12\x65\n\tCancelJob\x12!.ai.h2o.featurestore.api.v1.JobId\x1a\x16.google.protobuf.Empty\"\x1d\x82\xd3\xe4\x93\x02\x17*\x15/api/v1/jobs/{job_id}\x12\xb8\x01\n\x1cListJobsPageByFeatureSetName\x12?.ai.h2o.featurestore.api.v1.ListJobsPageByFeatureSetNameRequest\x1a\x30.ai.h2o.featurestore.api.v1.ListJobsPageResponse\"%\x82\xd3\xe4\x93\x02\x1f\x12\x1d/api/v1/jobs/feature-set/name\x12\xb2\x01\n\x1aListJobsPageByFeatureSetId\x12=.ai.h2o.featurestore.api.v1.ListJobsPageByFeatureSetIdRequest\x1a\x30.ai.h2o.featurestore.api.v1.ListJobsPageResponse\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/api/v1/jobs/feature-set/id\x12\xb5\x01\n\x16GetJobsWithStatusCount\x12\x39.ai.h2o.featurestore.api.v1.GetJobsWithStatusCountRequest\x1a:.ai.h2o.featurestore.api.v1.GetJobsWithStatusCountResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/api/v1/jobs/count-by-status\x12\x9c\x01\n\x15StartExtractSchemaJob\x12\x38.ai.h2o.featurestore.api.v1.StartExtractSchemaJobRequest\x1a!.ai.h2o.featurestore.api.v1.JobId\"&\x82\xd3\xe4\x93\x02 \"\x1b/api/v1/jobs/extract-schema:\x01*\x12\xa6\x01\n\x19GetExtractSchemaJobOutput\x12!.ai.h2o.featurestore.api.v1.JobId\x1a\x31.ai.h2o.featurestore.api.v1.ExtractSchemaResponse\"3\x82\xd3\xe4\x93\x02-\x12+/api/v1/jobs/{job_id}/output/extract-schema\x12\x87\x01\n\x0eStartIngestJob\x12\x31.ai.h2o.featurestore.api.v1.StartIngestJobRequest\x1a!.ai.h2o.featurestore.api.v1.JobId\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x14/api/v1/ingest/start:\x01*\x12\x93\x01\n\x12GetIngestJobOutput\x12!.ai.h2o.featurestore.api.v1.JobId\x1a*.ai.h2o.featurestore.api.v1.IngestResponse\".\x82\xd3\xe4\x93\x02(\x12&/api/v1/jobs/{job_id}/output/ingestion\x12\x93\x01\n\x17StartRetrieveAsLinksJob\x12+.ai.h2o.featurestore.api.v1.RetrieveRequest\x1a!.ai.h2o.featurestore.api.v1.JobId\"(\x82\xd3\xe4\x93\x02\"\"\x1d/api/v1/feature-sets/retrieve:\x01*\x12\xa4\x01\n\x1bGetRetrieveAsLinksJobOutput\x12!.ai.h2o.featurestore.api.v1.JobId\x1a\x33.ai.h2o.featurestore.api.v1.RetrieveAsLinksResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/api/v1/feature-sets/retrieve{job_id}\x12\xa6\x01\n\x0fRetrieveAsSpark\x12+.ai.h2o.featurestore.api.v1.RetrieveRequest\x1a\x33.ai.h2o.featurestore.api.v1.RetrieveAsSparkResponse\"1\x82\xd3\xe4\x93\x02+\"&/api/v1/feature-sets/retrieve/as-spark:\x01*\x12\xc0\x01\n\x19GetIngestWriteCredentials\x12\x38.ai.h2o.featurestore.api.v1.IngestWriteCredentialRequest\x1a\x39.ai.h2o.featurestore.api.v1.IngestWriteCredentialResponse\".\x82\xd3\xe4\x93\x02(\x12&/api/v1/ingest/credential/{session_id}\x12\x94\x01\n\x14StartRevertIngestJob\x12\x37.ai.h2o.featurestore.api.v1.StartRevertIngestJobRequest\x1a!.ai.h2o.featurestore.api.v1.JobId\" \x82\xd3\xe4\x93\x02\x1a\"\x15/api/v1/ingest/revert:\x01*\x12}\n\x18GetRevertIngestJobOutput\x12!.ai.h2o.featurestore.api.v1.JobId\x1a\x16.google.protobuf.Empty\"&\x82\xd3\xe4\x93\x02 \x12\x1e/api/v1/ingest/revert/{job_id}\x12\xe6\x01\n\x17HasPermissionToRetrieve\x12:.ai.h2o.featurestore.api.v1.HasPermissionToRetrieveRequest\x1a;.ai.h2o.featurestore.api.v1.HasPermissionToRetrieveResponse\"R\x82\xd3\xe4\x93\x02L\x12J/api/v1/feature-sets/retrieve/permission/{project_name}/{feature_set_name}\x12\x9c\x01\n\x12RegisterFeatureSet\x12\x35.ai.h2o.featurestore.api.v1.RegisterFeatureSetRequest\x1a..ai.h2o.featurestore.api.v1.FeatureSetResponse\"\x1f\x82\xd3\xe4\x93\x02\x19\"\x14/api/v1/feature-sets:\x01*\x12\xc5\x01\n\x1a\x43reateNewFeatureSetVersion\x12=.ai.h2o.featurestore.api.v1.CreateNewFeatureSetVersionRequest\x1a..ai.h2o.featurestore.api.v1.FeatureSetResponse\"8\x82\xd3\xe4\x93\x02\x32\"-/api/v1/feature-sets/{feature_set_id}/version:\x01*\x12\x80\x01\n\x15GetOnlineRetrieveMeta\x12\x16.google.protobuf.Empty\x1a..ai.h2o.featurestore.api.v1.OnlineRetrieveMeta\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/api/v1/online-retrieve\x12m\n\nGetVersion\x12\x16.google.protobuf.Empty\x1a..ai.h2o.featurestore.api.v1.GetVersionResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/api/v1/version\x12\xb8\x01\n\rGetFeatureSet\x12\x30.ai.h2o.featurestore.api.v1.GetFeatureSetRequest\x1a..ai.h2o.featurestore.api.v1.FeatureSetResponse\"E\x82\xd3\xe4\x93\x02?\x12=/api/v1/projects/{project_id}/feature-sets/{feature_set_name}\x12\xa3\x01\n\x11GetFeatureSetById\x12/.ai.h2o.featurestore.api.v1.FeatureSetRequestId\x1a..ai.h2o.featurestore.api.v1.FeatureSetResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/api/v1/feature-sets/{feature_set_id}\x12\xd7\x01\n&GetFeatureSetsLastMinorForCurrentMajor\x12I.ai.h2o.featurestore.api.v1.GetFeatureSetsLastMinorForCurrentMajorRequest\x1a..ai.h2o.featurestore.api.v1.FeatureSetResponse\"2\x82\xd3\xe4\x93\x02,\x12*/api/v1/feature-sets/{feature_set_id}/last\x12\xc7\x01\n\x16ListFeatureSetVersions\x12\x39.ai.h2o.featurestore.api.v1.ListFeatureSetsVersionRequest\x1a:.ai.h2o.featurestore.api.v1.ListFeatureSetVersionsResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./api/v1/feature-sets/{feature_set_id}/versions\x12\x8e\x01\n\x10\x44\x65leteFeatureSet\x12\x33.ai.h2o.featurestore.api.v1.DeleteFeatureSetRequest\x1a\x16.google.protobuf.Empty\"-\x82\xd3\xe4\x93\x02\'*%/api/v1/feature-sets/{feature_set_id}\x12\xc1\x01\n\x17\x44\x65leteFeatureSetVersion\x12:.ai.h2o.featurestore.api.v1.DeleteFeatureSetVersionRequest\x1a\x16.google.protobuf.Empty\"R\x82\xd3\xe4\x93\x02L*J/api/v1/feature-sets/{feature_set_id}/versions/{feature_set_major_version}\x12\xa4\x01\n\x13ListFeatureSetsPage\x12\x36.ai.h2o.featurestore.api.v1.ListFeatureSetsPageRequest\x1a\x37.ai.h2o.featurestore.api.v1.ListFeatureSetsPageResponse\"\x1c\x82\xd3\xe4\x93\x02\x16\x12\x14/api/v1/feature-sets\x12\xa9\x01\n\x10\x46\x65\x61tureSetExists\x12\x33.ai.h2o.featurestore.api.v1.FeatureSetExistsRequest\x1a*.ai.h2o.featurestore.api.v1.ExistsResponse\"4\x82\xd3\xe4\x93\x02.\x12,/api/v1/feature-sets/exists/{feature_set_id}\x12\x9d\x01\n\x10GetIngestHistory\x12\x33.ai.h2o.featurestore.api.v1.GetIngestHistoryRequest\x1a\x34.ai.h2o.featurestore.api.v1.GetIngestHistoryResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\x12\x16/api/v1/ingest/history\x12\xdf\x01\n\x1cIsFeatureSetSchemaCompatible\x12@.ai.h2o.featurestore.api.v1.FeatureSetSchemaCompatibilityRequest\x1a\x41.ai.h2o.featurestore.api.v1.FeatureSetSchemaCompatibilityResponse\":\x82\xd3\xe4\x93\x02\x34\"//api/v1/feature-sets/features/schema-compatible:\x01*\x12\xc3\x01\n\x15\x46\x65\x61tureSetSchemaPatch\x12\x38.ai.h2o.featurestore.api.v1.FeatureSetSchemaPatchRequest\x1a\x39.ai.h2o.featurestore.api.v1.FeatureSetSchemaPatchResponse\"5\x82\xd3\xe4\x93\x02/\"*/api/v1/feature-sets/features/schema-patch:\x01*\x12\xc0\x01\n\x14GetFeatureSetPreview\x12\x37.ai.h2o.featurestore.api.v1.GetFeatureSetPreviewRequest\x1a\x38.ai.h2o.featurestore.api.v1.GetFeatureSetPreviewResponse\"5\x82\xd3\xe4\x93\x02/\x12-/api/v1/feature-sets/{feature_set_id}/preview\x12\xaf\x01\n\x10UpdateFeatureSet\x12\x33.ai.h2o.featurestore.api.v1.UpdateFeatureSetRequest\x1a\x34.ai.h2o.featurestore.api.v1.UpdateFeatureSetResponse\"0\x82\xd3\xe4\x93\x02*\x1a%/api/v1/feature-sets/{feature_set_id}:\x01*\x12\x9c\x01\n\x11\x43reateFeatureView\x12\x34.ai.h2o.featurestore.api.v1.CreateFeatureViewRequest\x1a/.ai.h2o.featurestore.api.v1.FeatureViewResponse\" \x82\xd3\xe4\x93\x02\x1a\"\x15/api/v1/feature-views:\x01*\x12\xae\x01\n\x11UpdateFeatureView\x12\x34.ai.h2o.featurestore.api.v1.UpdateFeatureViewRequest\x1a/.ai.h2o.featurestore.api.v1.FeatureViewResponse\"2\x82\xd3\xe4\x93\x02,\x1a\'/api/v1/feature-views/{feature_view_id}:\x01*\x12\xb0\x01\n\x0eGetFeatureView\x12\x31.ai.h2o.featurestore.api.v1.GetFeatureViewRequest\x1a/.ai.h2o.featurestore.api.v1.FeatureViewResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/api/v1/projects/{project_id}/feature-views/{name}\x12\xad\x01\n\x11\x46\x65\x61tureViewExists\x12\x34.ai.h2o.featurestore.api.v1.FeatureViewExistsRequest\x1a*.ai.h2o.featurestore.api.v1.ExistsResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./api/v1/feature-views/{feature_view_id}/exists\x12\xb2\x01\n\x10ListFeatureViews\x12\x33.ai.h2o.featurestore.api.v1.ListFeatureViewsRequest\x1a\x34.ai.h2o.featurestore.api.v1.ListFeatureViewsResponse\"3\x82\xd3\xe4\x93\x02-\x12+/api/v1/projects/{project_id}/feature-views\x12\xb0\x01\n\x1b\x43reateFeatureViewNewVersion\x12>.ai.h2o.featurestore.api.v1.CreateFeatureViewNewVersionRequest\x1a/.ai.h2o.featurestore.api.v1.FeatureViewResponse\" \x82\xd3\xe4\x93\x02\x1a\"\x15/api/v1/feature-views:\x01*\x12\xe7\x01\n\"StartRetrieveFeatureViewAsSparkJob\x12=.ai.h2o.featurestore.api.v1.RetrieveFeatureViewAsSparkRequest\x1a!.ai.h2o.featurestore.api.v1.JobId\"_\x82\xd3\xe4\x93\x02Y\"T/api/v1/feature-views/{feature_view_id}/{feature_view_version}/retrieve-as-spark-job:\x01*\x12\xb9\x01\n&GetRetrieveFeatureViewAsSparkJobOutput\x12!.ai.h2o.featurestore.api.v1.JobId\x1a>.ai.h2o.featurestore.api.v1.RetrieveFeatureViewAsSparkResponse\",\x82\xd3\xe4\x93\x02&\x12$/api/v1/feature-views/spark/{job_id}\x12\xe9\x01\n\"StartRetrieveFeatureViewAsLinksJob\x12?.ai.h2o.featurestore.api.v1.RetrieveFeatureViewAsAsLinksRequest\x1a!.ai.h2o.featurestore.api.v1.JobId\"_\x82\xd3\xe4\x93\x02Y\"T/api/v1/feature-views/{feature_view_id}/{feature_view_version}/retrieve-as-links-job:\x01*\x12\xbb\x01\n&GetRetrieveFeatureViewAsLinksJobOutput\x12!.ai.h2o.featurestore.api.v1.JobId\x1a@.ai.h2o.featurestore.api.v1.RetrieveFeatureViewAsAsLinksResponse\",\x82\xd3\xe4\x93\x02&\x12$/api/v1/feature-views/links/{job_id}\x12\x92\x01\n\x11\x44\x65leteFeatureView\x12\x34.ai.h2o.featurestore.api.v1.DeleteFeatureViewRequest\x1a\x16.google.protobuf.Empty\"/\x82\xd3\xe4\x93\x02)*\'/api/v1/feature-views/{feature_view_id}\x12\x9a\x01\n\x0f\x43reateMLDataset\x12\x32.ai.h2o.featurestore.api.v1.CreateMLDatasetRequest\x1a\x33.ai.h2o.featurestore.api.v1.CreateMLDatasetResponse\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x13/api/v1/ml-datasets:\x01*\x12\xae\x01\n\x1dGetMLDatasetCreationJobOutput\x12!.ai.h2o.featurestore.api.v1.JobId\x1a%.ai.h2o.featurestore.api.v1.MLDataset\"C\x82\xd3\xe4\x93\x02=\x12;/api/v1/ml-datasets//{ml_datasets_id}/creation-job/{job_id}\x12\x9c\x01\n\x0fUpdateMLDataset\x12\x32.ai.h2o.featurestore.api.v1.UpdateMLDatasetRequest\x1a%.ai.h2o.featurestore.api.v1.MLDataset\".\x82\xd3\xe4\x93\x02(\x1a#/api/v1/ml-datasets/{ml_dataset_id}:\x01*\x12\x8a\x01\n\x0f\x44\x65leteMLDataset\x12\x32.ai.h2o.featurestore.api.v1.DeleteMLDatasetRequest\x1a\x16.google.protobuf.Empty\"+\x82\xd3\xe4\x93\x02%*#/api/v1/ml-datasets/{ml_dataset_id}\x12\xc2\x01\n\x0cGetMLDataset\x12/.ai.h2o.featurestore.api.v1.GetMLDatasetRequest\x1a%.ai.h2o.featurestore.api.v1.MLDataset\"Z\x82\xd3\xe4\x93\x02T\x12R/api/v1/feature-views/{feature_view_id}/version/{feature_view_version}/ml-datasets\x12\xa5\x01\n\x0fMLDatasetExists\x12\x32.ai.h2o.featurestore.api.v1.MLDatasetExistsRequest\x1a*.ai.h2o.featurestore.api.v1.ExistsResponse\"2\x82\xd3\xe4\x93\x02,\x12*/api/v1/ml-datasets/{ml_dataset_id}/exists\x12\x94\x01\n\x0eListMLDatasets\x12\x31.ai.h2o.featurestore.api.v1.ListMLDatasetsRequest\x1a\x32.ai.h2o.featurestore.api.v1.ListMLDatasetsResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/api/v1/ml-datasets\x12\xcb\x01\n\x18RetrieveMLDatasetAsSpark\x12;.ai.h2o.featurestore.api.v1.RetrieveMLDatasetAsSparkRequest\x1a<.ai.h2o.featurestore.api.v1.RetrieveMLDatasetAsSparkResponse\"4\x82\xd3\xe4\x93\x02.\")/api/v1/ml-datasets/{ml_dataset_id}/spark:\x01*\x12\xcc\x01\n\x18RetrieveMLDatasetAsLinks\x12=.ai.h2o.featurestore.api.v1.RetrieveMLDatasetAsAsLinksRequest\x1a>.ai.h2o.featurestore.api.v1.RetrieveMLDatasetAsAsLinksResponse\"1\x82\xd3\xe4\x93\x02+\x12)/api/v1/ml-datasets/{ml_dataset_id}/links\x12\xc6\x01\n\x17RetrieveMLDatasetOnline\x12:.ai.h2o.featurestore.api.v1.RetrieveMLDatasetOnlineRequest\x1a\x32.ai.h2o.featurestore.api.v1.OnlineRetrieveResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/api/v1/ml-datasets/{ml_dataset_id}/online/retrieve\x12\x97\x01\n\x10ListProjectsPage\x12\x33.ai.h2o.featurestore.api.v1.ListProjectsPageRequest\x1a\x34.ai.h2o.featurestore.api.v1.ListProjectsPageResponse\"\x18\x82\xd3\xe4\x93\x02\x12\x12\x10/api/v1/projects\x12\x91\x01\n\rCreateProject\x12\x30.ai.h2o.featurestore.api.v1.CreateProjectRequest\x1a\x31.ai.h2o.featurestore.api.v1.CreateProjectResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\"\x10/api/v1/projects:\x01*\x12\x91\x01\n\nGetProject\x12-.ai.h2o.featurestore.api.v1.GetProjectRequest\x1a+.ai.h2o.featurestore.api.v1.ProjectResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/api/v1/projects/{project_name}\x12\x7f\n\rDeleteProject\x12\x30.ai.h2o.featurestore.api.v1.DeleteProjectRequest\x1a\x16.google.protobuf.Empty\"$\x82\xd3\xe4\x93\x02\x1e*\x1c/api/v1/projects/{projectId}\x12\x83\x01\n\x12GetProjectsDefault\x12\x16.google.protobuf.Empty\x1a\x33.ai.h2o.featurestore.api.v1.ProjectsDefaultResponse\" \x82\xd3\xe4\x93\x02\x1a\x12\x18/api/v1/projects/default\x12\x9b\x01\n\rProjectExists\x12\x30.ai.h2o.featurestore.api.v1.ProjectExistsRequest\x1a*.ai.h2o.featurestore.api.v1.ExistsResponse\",\x82\xd3\xe4\x93\x02&\x12$/api/v1/projects/{project_id}/exists\x12\x9e\x01\n\rUpdateProject\x12\x30.ai.h2o.featurestore.api.v1.UpdateProjectRequest\x1a\x31.ai.h2o.featurestore.api.v1.UpdateProjectResponse\"(\x82\xd3\xe4\x93\x02\"\x1a\x1d/api/v1/projects/{project_id}:\x01*\x12\xbe\x01\n\x16ListProjectHistoryPage\x12\x39.ai.h2o.featurestore.api.v1.ListProjectHistoryPageRequest\x1a:.ai.h2o.featurestore.api.v1.ListProjectHistoryPageResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/api/v1/projects/{project_id}/history\x12\x91\x01\n\x0eGetAccessToken\x12/.ai.h2o.featurestore.api.v1.RefreshTokenRequest\x1a/.ai.h2o.featurestore.api.v1.AccessTokenResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/api/v1/auth/token:\x01*\x12\x98\x01\n\rGetUserByMail\x12\x30.ai.h2o.featurestore.api.v1.GetUserByMailRequest\x1a\x31.ai.h2o.featurestore.api.v1.GetUserByMailResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/api/v1/auth/users/{email}\x12k\n\x06Logout\x12).ai.h2o.featurestore.api.v1.LogoutRequest\x1a\x16.google.protobuf.Empty\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x13/api/v1/auth/logout:\x01*\x12v\n\rGetActiveUser\x12\x16.google.protobuf.Empty\x1a\x31.ai.h2o.featurestore.api.v1.GetActiveUserResponse\"\x1a\x82\xd3\xe4\x93\x02\x14\x12\x12/api/v1/auth/users\x12k\n\x05Login\x12\x16.google.protobuf.Empty\x1a).ai.h2o.featurestore.api.v1.LoginResponse\"\x1d\x82\xd3\xe4\x93\x02\x17\"\x12/api/v1/auth/login:\x01*0\x01\x12p\n\x0cGetWebConfig\x12\x16.google.protobuf.Empty\x1a\x30.ai.h2o.featurestore.api.v1.GetWebConfigResponse\"\x16\x82\xd3\xe4\x93\x02\x10\x12\x0e/api/v1/config\x12\x9c\x01\n\x17\x41\x64\x64\x46\x65\x61tureSetPermission\x12\x37.ai.h2o.featurestore.api.v1.FeatureSetPermissionRequest\x1a\x16.google.protobuf.Empty\"0\x82\xd3\xe4\x93\x02*\"%/api/v1/auth/feature-sets/permissions:\x01*\x12\xa9\x01\n\x14\x41\x64\x64ProjectPermission\x12\x34.ai.h2o.featurestore.api.v1.ProjectPermissionRequest\x1a\x16.google.protobuf.Empty\"C\x82\xd3\xe4\x93\x02=\"8/api/v1/permissions/projects/add/permission/{resourceId}:\x01*\x12\xba\x01\n\x1aRemoveFeatureSetPermission\x12\x37.ai.h2o.featurestore.api.v1.FeatureSetPermissionRequest\x1a\x16.google.protobuf.Empty\"K\x82\xd3\xe4\x93\x02\x45*@/api/v1/permissions/feature-sets/remove/permission/{resource_id}:\x01*\x12\xb1\x01\n\x17RemoveProjectPermission\x12\x34.ai.h2o.featurestore.api.v1.ProjectPermissionRequest\x1a\x16.google.protobuf.Empty\"H\x82\xd3\xe4\x93\x02\x42*=/api/v1/permissions/projects/remove/permissions/{resource_id}:\x01*\x12\xd0\x01\n\x1eSubmitPendingProjectPermission\x12:.ai.h2o.featurestore.api.v1.SubmitPendingPermissionRequest\x1a;.ai.h2o.featurestore.api.v1.SubmitPendingPermissionResponse\"5\x82\xd3\xe4\x93\x02/\"*/api/v1/permissions/projects/{resource_id}:\x01*\x12\xd7\x01\n!SubmitPendingFeatureSetPermission\x12:.ai.h2o.featurestore.api.v1.SubmitPendingPermissionRequest\x1a;.ai.h2o.featurestore.api.v1.SubmitPendingPermissionResponse\"9\x82\xd3\xe4\x93\x02\x33\"./api/v1/permissions/feature-sets/{resource_id}:\x01*\x12\xbb\x01\n\x1aListProjectPermissionsPage\x12\x36.ai.h2o.featurestore.api.v1.ListPermissionsPageRequest\x1a?.ai.h2o.featurestore.api.v1.ListProjectsPermissionsPageResponse\"$\x82\xd3\xe4\x93\x02\x1e\x12\x1c/api/v1/permissions/projects\x12\xc6\x01\n\x1eListFeatureSetsPermissionsPage\x12\x36.ai.h2o.featurestore.api.v1.ListPermissionsPageRequest\x1a\x42.ai.h2o.featurestore.api.v1.ListFeatureSetsPermissionsPageResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /api/v1/permissions/feature-sets\x12\xd0\x01\n$ListManageableProjectPermissionsPage\x12\x36.ai.h2o.featurestore.api.v1.ListPermissionsPageRequest\x1a?.ai.h2o.featurestore.api.v1.ListProjectsPermissionsPageResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/api/v1/permissions/manageable-projects\x12\xdb\x01\n(ListManageableFeatureSetsPermissionsPage\x12\x36.ai.h2o.featurestore.api.v1.ListPermissionsPageRequest\x1a\x42.ai.h2o.featurestore.api.v1.ListFeatureSetsPermissionsPageResponse\"3\x82\xd3\xe4\x93\x02-\x12+/api/v1/permissions/manageable-feature-sets\x12\x98\x01\n\x18\x41pprovePendingPermission\x12;.ai.h2o.featurestore.api.v1.ApprovePendingPermissionRequest\x1a\x16.google.protobuf.Empty\"\'\x82\xd3\xe4\x93\x02!\"\x1c/api/v1/permissions/approval:\x01*\x12\x97\x01\n\x17RejectPendingPermission\x12:.ai.h2o.featurestore.api.v1.RejectPendingPermissionRequest\x1a\x16.google.protobuf.Empty\"(\x82\xd3\xe4\x93\x02\"\"\x1d/api/v1/permissions/rejection:\x01*\x12\x86\x01\n\x10RevokePermission\x12\x33.ai.h2o.featurestore.api.v1.RevokePermissionRequest\x1a\x16.google.protobuf.Empty\"%\x82\xd3\xe4\x93\x02\x1f\"\x1a/api/v1/permissions/revoke:\x01*\x12\xc8\x01\n\x1aGetActiveProjectPermission\x12\x36.ai.h2o.featurestore.api.v1.GetActivePermissionRequest\x1a\x37.ai.h2o.featurestore.api.v1.GetActivePermissionResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/api/v1/permissions/projects/{resource_id}/active\x12\xcf\x01\n\x1dGetActiveFeatureSetPermission\x12\x36.ai.h2o.featurestore.api.v1.GetActivePermissionRequest\x1a\x37.ai.h2o.featurestore.api.v1.GetActivePermissionResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/api/v1/permissions/feature-sets/{resource_id}/active\x12\xa9\x01\n\x10GetProjectOwners\x12,.ai.h2o.featurestore.api.v1.GetOwnersRequest\x1a-.ai.h2o.featurestore.api.v1.GetOwnersResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/api/v1/permissions/project/{resource_id}/owners\x12\xb1\x01\n\x13GetFeatureSetOwners\x12,.ai.h2o.featurestore.api.v1.GetOwnersRequest\x1a-.ai.h2o.featurestore.api.v1.GetOwnersResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/api/v1/permissions/feature-sets/{resource_id}/owners\x12\xbe\x01\n\x19GetUserProjectPermissions\x12\x35.ai.h2o.featurestore.api.v1.GetUserPermissionsRequest\x1a\x36.ai.h2o.featurestore.api.v1.GetUserPermissionsResponse\"2\x82\xd3\xe4\x93\x02,\x12*/api/v1/permissions/projects/{resource_id}\x12\xc5\x01\n\x1cGetUserFeatureSetPermissions\x12\x35.ai.h2o.featurestore.api.v1.GetUserPermissionsRequest\x1a\x36.ai.h2o.featurestore.api.v1.GetUserPermissionsResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./api/v1/permissions/feature-sets/{resource_id}\x12u\n\x0bRevokeToken\x12(.ai.h2o.featurestore.api.v1.TokenRequest\x1a\x16.google.protobuf.Empty\"$\x82\xd3\xe4\x93\x02\x1e\"\x19/api/v1/auth/token/revoke:\x01*\x12\x97\x01\n\rGenerateToken\x12\x30.ai.h2o.featurestore.api.v1.GenerateTokenRequest\x1a,.ai.h2o.featurestore.api.v1.RawTokenResponse\"&\x82\xd3\xe4\x93\x02 *\x1e/api/v1/auth/tokens/{token_id}\x12T\n\nListTokens\x12\x16.google.protobuf.Empty\x1a..ai.h2o.featurestore.api.v1.ListTokensResponse\x12\xb2\x01\n\x18ListPersonalAccessTokens\x12;.ai.h2o.featurestore.api.v1.ListPersonalAccessTokensRequest\x1a<.ai.h2o.featurestore.api.v1.ListPersonalAccessTokensResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/api/v1/auth/tokens\x12\x87\x01\n\x08GetToken\x12(.ai.h2o.featurestore.api.v1.TokenRequest\x1a).ai.h2o.featurestore.api.v1.TokenResponse\"&\x82\xd3\xe4\x93\x02 \x12\x1e/api/v1/auth/tokens/{token_id}\x12\xb6\x01\n\x0eOnlineRetrieve\x12\x31.ai.h2o.featurestore.api.v1.OnlineRetrieveRequest\x1a\x32.ai.h2o.featurestore.api.v1.OnlineRetrieveResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/api/v1/feature-sets/{feature_set_id}/online/retrieve\x12\x97\x01\n\x0cOnlineIngest\x12/.ai.h2o.featurestore.api.v1.OnlineIngestRequest\x1a\x16.google.protobuf.Empty\">\x82\xd3\xe4\x93\x02\x38\x1a\x33/api/v1/feature-sets/{feature_set_id}/online/ingest:\x01*\x12\xca\x01\n\x1dStartMaterializationOnlineJob\x12=.ai.h2o.featurestore.api.v1.StartMaterializationOnlineRequest\x1a!.ai.h2o.featurestore.api.v1.JobId\"G\x82\xd3\xe4\x93\x02\x41\"</api/v1/feature-sets/{feature_set_id}/online-materialization:\x01*\x12\xbe\x01\n!GetMaterializationOnlineJobOutput\x12!.ai.h2o.featurestore.api.v1.JobId\x1a\x39.ai.h2o.featurestore.api.v1.MaterializationOnlineResponse\";\x82\xd3\xe4\x93\x02\x35\x12\x33/api/v1/jobs/{job_id}/output/online-materialization\x12\x87\x01\n\x1dGetComputeStatisticsJobOutput\x12!.ai.h2o.featurestore.api.v1.JobId\x1a\x16.google.protobuf.Empty\"+\x82\xd3\xe4\x93\x02%\x12#/api/v1/compute-statistics/{job_id}\x12\xb6\x01\n,GetComputeRecommendationClassifiersJobOutput\x12!.ai.h2o.featurestore.api.v1.JobId\x1a\x16.google.protobuf.Empty\"K\x82\xd3\xe4\x93\x02\x45\x12\x43/api/v1/jobs/{job_id}/output/recommendation-classifiers-computation\x12\xc5\x01\n\x1cGenerateTransformationUpload\x12?.ai.h2o.featurestore.api.v1.GenerateTransformationUploadRequest\x1a@.ai.h2o.featurestore.api.v1.GenerateTransformationUploadResponse\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/api/v1/transformations:\x01*\x12\x96\x01\n\x1dListRecommendationClassifiers\x12\x16.google.protobuf.Empty\x1a@.ai.h2o.featurestore.api.v1.ListRecommendationClassifierResponse\"\x1b\x82\xd3\xe4\x93\x02\x15\x12\x13/api/v1/classifiers\x12\x9b\x01\n\x1e\x43reateRecommendationClassifier\x12\x41.ai.h2o.featurestore.api.v1.CreateRecommendationClassifierRequest\x1a\x16.google.protobuf.Empty\"\x1e\x82\xd3\xe4\x93\x02\x18\"\x13/api/v1/classifiers:\x01*\x12\xa2\x01\n\x1eUpdateRecommendationClassifier\x12\x41.ai.h2o.featurestore.api.v1.UpdateRecommendationClassifierRequest\x1a\x16.google.protobuf.Empty\"%\x82\xd3\xe4\x93\x02\x1f\x1a\x1a/api/v1/classifiers/{name}:\x01*\x12\xaa\x01\n\x1e\x44\x65leteRecommendationClassifier\x12\x41.ai.h2o.featurestore.api.v1.DeleteRecommendationClassifierRequest\x1a\x16.google.protobuf.Empty\"-\x82\xd3\xe4\x93\x02\'*%/api/v1/classifiers/{classifier_name}\x12\xc0\x01\n\x12GetRecommendations\x12\x34.ai.h2o.featurestore.api.v1.GetRecommendationRequest\x1a\x35.ai.h2o.featurestore.api.v1.GetRecommendationResponse\"=\x82\xd3\xe4\x93\x02\x37\x12\x35/api/v1/feature-sets/{feature_set_id}/recommendations\x12p\n\x0cGetDashboard\x12\x16.google.protobuf.Empty\x1a-.ai.h2o.featurestore.api.v1.DashboardResponse\"\x19\x82\xd3\xe4\x93\x02\x13\x12\x11/api/v1/dashboard\x12\x9d\x01\n\x18GetFeatureSetsPopularity\x12\x16.google.protobuf.Empty\x1a\x39.ai.h2o.featurestore.api.v1.FeatureSetsPopularityResponse\".\x82\xd3\xe4\x93\x02(\x12&/api/v1/dashboard/popular-feature-sets\x12\x9d\x01\n\x17GetRecentlyUsedProjects\x12\x16.google.protobuf.Empty\x1a\x38.ai.h2o.featurestore.api.v1.RecentlyUsedProjectsResponse\"0\x82\xd3\xe4\x93\x02*\x12(/api/v1/dashboard/recently-used-projects\x12\xa7\x01\n\x1aGetRecentlyUsedFeatureSets\x12\x16.google.protobuf.Empty\x1a;.ai.h2o.featurestore.api.v1.RecentlyUsedFeatureSetsResponse\"4\x82\xd3\xe4\x93\x02.\x12,/api/v1/dashboard/recently-used-feature-sets\x12\x9c\x01\n\rPinFeatureSet\x12\x30.ai.h2o.featurestore.api.v1.PinFeatureSetRequest\x1a\x16.google.protobuf.Empty\"A\x82\xd3\xe4\x93\x02;\x1a\x36/api/v1/dashboard/pinned-feature-sets/{feature_set_id}:\x01*\x12\xa0\x01\n\x0fUnpinFeatureSet\x12\x32.ai.h2o.featurestore.api.v1.UnpinFeatureSetRequest\x1a\x16.google.protobuf.Empty\"A\x82\xd3\xe4\x93\x02;*6/api/v1/dashboard/pinned-feature-sets/{feature_set_id}:\x01*\x12\xcd\x01\n\x12IsFeatureSetPinned\x12\x35.ai.h2o.featurestore.api.v1.IsFeatureSetPinnedRequest\x1a\x36.ai.h2o.featurestore.api.v1.IsFeatureSetPinnedResponse\"H\x82\xd3\xe4\x93\x02\x42\x12=/api/v1/dashboard/pinned-feature-sets/exists/{feature_set_id}:\x01*\x12\xb3\x01\n\x15ListPinnedFeatureSets\x12\x34.ai.h2o.featurestore.api.v1.PinnedFeatureSetsRequest\x1a\x35.ai.h2o.featurestore.api.v1.PinnedFeatureSetsResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/api/v1/dashboard/pinned-feature-sets\x12\x95\x01\n\x0eSearchProjects\x12\x30.ai.h2o.featurestore.api.v1.ProjectSearchRequest\x1a\x30.ai.h2o.featurestore.api.v1.ProjectSearchResults\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/api/v1/search/projects\x12\xa2\x01\n\x11SearchFeatureSets\x12\x33.ai.h2o.featurestore.api.v1.FeatureSetSearchRequest\x1a\x33.ai.h2o.featurestore.api.v1.FeatureSetSearchResults\"#\x82\xd3\xe4\x93\x02\x1d\x12\x1b/api/v1/search/feature-sets\x12\x95\x01\n\x0eSearchFeatures\x12\x30.ai.h2o.featurestore.api.v1.FeatureSearchRequest\x1a\x30.ai.h2o.featurestore.api.v1.FeatureSearchResults\"\x1f\x82\xd3\xe4\x93\x02\x19\x12\x17/api/v1/search/features\x12\xad\x01\n\nGetFeature\x12-.ai.h2o.featurestore.api.v1.GetFeatureRequest\x1a+.ai.h2o.featurestore.api.v1.FeatureResponse\"C\x82\xd3\xe4\x93\x02=\x12;/api/v1/feature-sets/{feature_set_id}/features/{feature_id}\x12\xa9\x01\n\x0cListFeatures\x12/.ai.h2o.featurestore.api.v1.ListFeaturesRequest\x1a\x30.ai.h2o.featurestore.api.v1.ListFeaturesResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./api/v1/feature-sets/{feature_set_id}/features\x12\xbc\x01\n\rUpdateFeature\x12\x30.ai.h2o.featurestore.api.v1.UpdateFeatureRequest\x1a\x31.ai.h2o.featurestore.api.v1.UpdateFeatureResponse\"F\x82\xd3\xe4\x93\x02@\x1a;/api/v1/feature-sets/{feature_set_id}/features/{feature_id}:\x01*\x12\xac\x01\n\x13MarkFeatureAsTarget\x12\x30.ai.h2o.featurestore.api.v1.TargetFeatureRequest\x1a\x16.google.protobuf.Empty\"K\x82\xd3\xe4\x93\x02\x45\x1a\x43/api/v1/feature-sets/{feature_set_id}/target-variables/{feature_id}\x12\xaf\x01\n\x16\x44iscardFeatureAsTarget\x12\x30.ai.h2o.featurestore.api.v1.TargetFeatureRequest\x1a\x16.google.protobuf.Empty\"K\x82\xd3\xe4\x93\x02\x45*C/api/v1/feature-sets/{feature_set_id}/target-variables/{feature_id}\x12\xc3\x01\n\x12ListTargetFeatures\x12\x35.ai.h2o.featurestore.api.v1.ListTargetFeaturesRequest\x1a\x36.ai.h2o.featurestore.api.v1.ListTargetFeaturesResponse\">\x82\xd3\xe4\x93\x02\x38\x12\x36/api/v1/feature-sets/{feature_set_id}/target-variables\x12\xbe\x01\n\x15GetListableFeatureSet\x12\x35.ai.h2o.featurestore.api.v1.ListableFeatureSetRequest\x1a\x36.ai.h2o.featurestore.api.v1.ListableFeatureSetResponse\"6\x82\xd3\xe4\x93\x02\x30\x12./api/v1/feature-sets/{feature_set_id}/listable\x12\x9f\x01\n\x11ScheduleIngestJob\x12/.ai.h2o.featurestore.api.v1.ScheduleTaskRequest\x1a\x31.ai.h2o.featurestore.api.v1.ScheduledTaskResponse\"&\x82\xd3\xe4\x93\x02 \"\x1b/api/v1/schedules/ingestion:\x01*\x12\xaf\x01\n\x12ListScheduledTasks\x12\x35.ai.h2o.featurestore.api.v1.ListScheduledTasksRequest\x1a\x36.ai.h2o.featurestore.api.v1.ListScheduledTasksResponse\"*\x82\xd3\xe4\x93\x02$\x12\"/api/v1/schedules/{feature_set_id}\x12\xa1\x01\n\x10GetScheduledTask\x12+.ai.h2o.featurestore.api.v1.ScheduledTaskId\x1a\x31.ai.h2o.featurestore.api.v1.ScheduledTaskResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/api/v1/schedules/{scheduled_task_id}\x12\x89\x01\n\x13\x44\x65leteScheduledTask\x12+.ai.h2o.featurestore.api.v1.ScheduledTaskId\x1a\x16.google.protobuf.Empty\"-\x82\xd3\xe4\x93\x02\'*%/api/v1/schedules/{scheduled_task_id}\x12\x97\x01\n\x13UpdateScheduledTask\x12\x36.ai.h2o.featurestore.api.v1.ScheduledTaskUpdateRequest\x1a\x16.google.protobuf.Empty\"0\x82\xd3\xe4\x93\x02*\x1a%/api/v1/schedules/{scheduled_task_id}:\x01*\x12\x9b\x01\n\x12PauseScheduledTask\x12\x35.ai.h2o.featurestore.api.v1.PauseScheduledTaskRequest\x1a\x16.google.protobuf.Empty\"6\x82\xd3\xe4\x93\x02\x30\x1a+/api/v1/schedules/{scheduled_task_id}/pause:\x01*\x12\x9e\x01\n\x13ResumeScheduledTask\x12\x36.ai.h2o.featurestore.api.v1.ResumeScheduledTaskRequest\x1a\x16.google.protobuf.Empty\"7\x82\xd3\xe4\x93\x02\x31\x1a,/api/v1/schedules/{scheduled_task_id}/resume:\x01*\x12\xa9\x01\n\x16ScheduleLazyIngestTask\x12/.ai.h2o.featurestore.api.v1.ScheduleTaskRequest\x1a\x31.ai.h2o.featurestore.api.v1.ScheduledTaskResponse\"+\x82\xd3\xe4\x93\x02%\" /api/v1/schedules/lazy/ingestion:\x01*\x12\xa4\x01\n\x13StartLazyIngestTask\x12-.ai.h2o.featurestore.api.v1.LazyIngestRequest\x1a..ai.h2o.featurestore.api.v1.LazyIngestResponse\".\x82\xd3\xe4\x93\x02(\x12&/api/v1/schedules/lazy/ingestion/start\x12\xcd\x01\n\x11GetLazyIngestTask\x12\x34.ai.h2o.featurestore.api.v1.GetLazyIngestTaskRequest\x1a\x31.ai.h2o.featurestore.api.v1.ScheduledTaskResponse\"O\x82\xd3\xe4\x93\x02I\x12G/api/v1/schedules/lazy/ingestion/{feature_set_id}/{feature_set_version}\x12\xe8\x01\n!ListScheduledTaskExecutionHistory\x12>.ai.h2o.featurestore.api.v1.ListScheduledTaskExecutionsRequest\x1a?.ai.h2o.featurestore.api.v1.ListScheduledTaskExecutionsResponse\"B\x82\xd3\xe4\x93\x02<\x12\x37/api/v1/schedules/{scheduled_task_id}/execution-history:\x01*\x12\xc8\x01\n\x1bListTransformationFunctions\x12>.ai.h2o.featurestore.api.v1.ListTransformationFunctionsRequest\x1a?.ai.h2o.featurestore.api.v1.ListTransformationFunctionsResponse\"(\x82\xd3\xe4\x93\x02\"\x12 /api/v1/transformation_functions\x12\xe1\x01\n\x19GetTransformationFunction\x12<.ai.h2o.featurestore.api.v1.GetTransformationFunctionRequest\x1a=.ai.h2o.featurestore.api.v1.GetTransformationFunctionResponse\"G\x82\xd3\xe4\x93\x02\x41\x12?/api/v1/transformation_functions/{transformation_function_name}\x12\x96\x01\n\x14GetBackfillJobOutput\x12!.ai.h2o.featurestore.api.v1.JobId\x1a,.ai.h2o.featurestore.api.v1.BackfillResponse\"-\x82\xd3\xe4\x93\x02\'\x12%/api/v1/jobs/{job_id}/output/backfill\x12\x8a\x01\n\x15\x43reateDraftFeatureSet\x12\x32.ai.h2o.featurestore.api.v1.FeatureSetDraftRequest\x1a\x16.google.protobuf.Empty\"%\x82\xd3\xe4\x93\x02\x1f\"\x1a/api/v1/feature-sets/draft:\x01*\x12\xb7\x01\n\x19\x43reateFeatureSetFromDraft\x12\x34.ai.h2o.featurestore.api.v1.DraftToFeatureSetRequest\x1a\x35.ai.h2o.featurestore.api.v1.DraftToFeatureSetResponse\"-\x82\xd3\xe4\x93\x02\'\"\"/api/v1/feature-sets/draft/publish:\x01*\x12\x99\x01\n\x15\x44\x65leteFeatureSetDraft\x12-.ai.h2o.featurestore.api.v1.FeatureSetDraftId\x1a\x16.google.protobuf.Empty\"9\x82\xd3\xe4\x93\x02\x33*1/api/v1/feature-sets/draft/{feature_set_draft_id}\x12\xad\x01\n\x14ListFeatureSetDrafts\x12\x37.ai.h2o.featurestore.api.v1.ListFeatureSetDraftsRequest\x1a\x38.ai.h2o.featurestore.api.v1.ListFeatureSetDraftsResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/api/v1/feature-sets/draft\x12\xb3\x01\n\x12GetFeatureSetDraft\x12-.ai.h2o.featurestore.api.v1.FeatureSetDraftId\x1a\x33.ai.h2o.featurestore.api.v1.FeatureSetDraftResponse\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/api/v1/feature-sets/draft/{feature_set_draft_id}\x12\xa4\x01\n\x11StoreFileArtifact\x12\x34.ai.h2o.featurestore.api.v1.StoreFileArtifactRequest\x1a\x35.ai.h2o.featurestore.api.v1.StoreFileArtifactResponse\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/api/v1/artifacts/files:\x01*\x12\xa6\x01\n\x10RetrieveArtifact\x12\x33.ai.h2o.featurestore.api.v1.RetrieveArtifactRequest\x1a\x34.ai.h2o.featurestore.api.v1.RetrieveArtifactResponse\"\'\x82\xd3\xe4\x93\x02!\x12\x1f/api/v1/artifacts/{artifact_id}\x12\x96\x01\n\x12UpdateUploadStatus\x12\x35.ai.h2o.featurestore.api.v1.UpdateUploadStatusRequest\x1a\x16.google.protobuf.Empty\"1\x82\xd3\xe4\x93\x02+\x1a&/api/v1/artifacts/{artifact_id}/status:\x01*\x12\x84\x01\n\x0e\x44\x65leteArtifact\x12\x31.ai.h2o.featurestore.api.v1.DeleteArtifactRequest\x1a\x16.google.protobuf.Empty\"\'\x82\xd3\xe4\x93\x02!*\x1f/api/v1/artifacts/{artifact_id}\x12\xbc\x01\n\rListArtifacts\x12\x30.ai.h2o.featurestore.api.v1.ListArtifactsRequest\x1a\x31.ai.h2o.featurestore.api.v1.ListArtifactsResponse\"F\x82\xd3\xe4\x93\x02@\x12>/api/v1/artifacts/{feature_set_id}/{feature_set_major_version}\x12u\n\tStoreLink\x12,.ai.h2o.featurestore.api.v1.StoreLinkRequest\x1a\x16.google.protobuf.Empty\"\"\x82\xd3\xe4\x93\x02\x1c\"\x17/api/v1/artifacts/links:\x01*\x12\xab\x01\n\x17ListFeatureSetsToReview\x12:.ai.h2o.featurestore.api.v1.ListFeatureSetsToReviewRequest\x1a;.ai.h2o.featurestore.api.v1.ListFeatureSetsToReviewResponse\"\x17\x82\xd3\xe4\x93\x02\x11\x12\x0f/api/v1/reviews\x12\x8a\x01\n\rApproveReview\x12\x30.ai.h2o.featurestore.api.v1.ApproveReviewRequest\x1a\x16.google.protobuf.Empty\"/\x82\xd3\xe4\x93\x02)\"$/api/v1/reviews/{review_id}/approval:\x01*\x12\x89\x01\n\x0cRejectReview\x12/.ai.h2o.featurestore.api.v1.RejectReviewRequest\x1a\x16.google.protobuf.Empty\"0\x82\xd3\xe4\x93\x02*\"%/api/v1/reviews/{review_id}/rejection:\x01*\x12\xbd\x01\n\x1aListFeatureSetsReviewsPage\x12<.ai.h2o.featurestore.api.v1.ListFeatureSetReviewsPageRequest\x1a=.ai.h2o.featurestore.api.v1.ListFeatureSetReviewsPageResponse\"\"\x82\xd3\xe4\x93\x02\x1c\x12\x1a/api/v1/reviews/my-reviews\x12\xde\x01\n\x1dGetListableFeatureSetToReview\x12@.ai.h2o.featurestore.api.v1.GetListableFeatureSetToReviewRequest\x1a\x41.ai.h2o.featurestore.api.v1.GetListableFeatureSetToReviewResponse\"8\x82\xd3\xe4\x93\x02\x32\x12\x30/api/v1/reviews/{review_id}/listable/feature-set\x12\xe9\x01\n\x1dGetListableFeatureSetInReview\x12@.ai.h2o.featurestore.api.v1.GetListableFeatureSetInReviewRequest\x1a\x41.ai.h2o.featurestore.api.v1.GetListableFeatureSetInReviewResponse\"C\x82\xd3\xe4\x93\x02=\x12;/api/v1/reviews/my-reviews/{review_id}/listable/feature-set\x12\xb2\x01\n\x1f\x44\x65leteFeatureSetVersionInReview\x12;.ai.h2o.featurestore.api.v1.DeleteRejectedFeatureSetRequest\x1a\x16.google.protobuf.Empty\":\x82\xd3\xe4\x93\x02\x34\x12\x32/api/v1/reviews/my-reviews/{review_id}/feature-set\x12\xcc\x01\n\x14ListFeaturesToReview\x12\x37.ai.h2o.featurestore.api.v1.ListFeaturesToReviewRequest\x1a\x38.ai.h2o.featurestore.api.v1.ListFeaturesToReviewResponse\"A\x82\xd3\xe4\x93\x02;\x12\x39/api/v1/reviews/{review_id}/listable/feature-set/features\x12\xd7\x01\n\x14ListFeaturesInReview\x12\x37.ai.h2o.featurestore.api.v1.ListFeaturesInReviewRequest\x1a\x38.ai.h2o.featurestore.api.v1.ListFeaturesInReviewResponse\"L\x82\xd3\xe4\x93\x02\x46\x12\x44/api/v1/reviews/my-reviews/{review_id}/listable/feature-set/features\x12\xda\x01\n\x1cGetFeatureSetPreviewToReview\x12?.ai.h2o.featurestore.api.v1.GetFeatureSetPreviewToReviewRequest\x1a@.ai.h2o.featurestore.api.v1.GetFeatureSetPreviewToReviewResponse\"7\x82\xd3\xe4\x93\x02\x31\x12//api/v1/reviews/{review_id}/feature-set/preview\x12\xe5\x01\n\x1cGetFeatureSetPreviewInReview\x12?.ai.h2o.featurestore.api.v1.GetFeatureSetPreviewInReviewRequest\x1a@.ai.h2o.featurestore.api.v1.GetFeatureSetPreviewInReviewResponse\"B\x82\xd3\xe4\x93\x02<\x12:/api/v1/reviews/my-reviews/{review_id}/feature-set/preview\x12\xbd\x01\n\x15GetFeatureSetToReview\x12\x38.ai.h2o.featurestore.api.v1.GetFeatureSetToReviewRequest\x1a\x39.ai.h2o.featurestore.api.v1.GetFeatureSetToReviewResponse\"/\x82\xd3\xe4\x93\x02)\x12\'/api/v1/reviews/{review_id}/feature-set\x12\xc8\x01\n\x15GetFeatureSetInReview\x12\x38.ai.h2o.featurestore.api.v1.GetFeatureSetInReviewRequest\x1a\x39.ai.h2o.featurestore.api.v1.GetFeatureSetInReviewResponse\":\x82\xd3\xe4\x93\x02\x34\x12\x32/api/v1/reviews/my-reviews/{review_id}/feature-setB\x14\x42\x10\x43oreServiceProtoP\x01\x62\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ai.h2o.featurestore.api.v1.CoreService_pb2', _globals)
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'B\020CoreServiceProtoP\001'
  _GETINGESTHISTORYREQUEST.fields_by_name['feature_set']._options = None
  _GETINGESTHISTORYREQUEST.fields_by_name['feature_set']._serialized_options = b'\030\001'
  _STARTREVERTINGESTJOBREQUEST.fields_by_name['feature_set']._options = None
  _STARTREVERTINGESTJOBREQUEST.fields_by_name['feature_set']._serialized_options = b'\030\001'
  _LISTJOBSREQUEST.fields_by_name['feature_set']._options = None
  _LISTJOBSREQUEST.fields_by_name['feature_set']._serialized_options = b'\030\001'
  _GETRECOMMENDATIONREQUEST.fields_by_name['feature_set']._options = None
  _GETRECOMMENDATIONREQUEST.fields_by_name['feature_set']._serialized_options = b'\030\001'
  _FEATURESETPERMISSIONREQUEST.fields_by_name['feature_set']._options = None
  _FEATURESETPERMISSIONREQUEST.fields_by_name['feature_set']._serialized_options = b'\030\001'
  _PROJECTPERMISSIONREQUEST.fields_by_name['project']._options = None
  _PROJECTPERMISSIONREQUEST.fields_by_name['project']._serialized_options = b'\030\001'
  _LISTFEATURESETSVERSIONREQUEST.fields_by_name['feature_set']._options = None
  _LISTFEATURESETSVERSIONREQUEST.fields_by_name['feature_set']._serialized_options = b'\030\001'
  _DELETEFEATURESETREQUEST.fields_by_name['feature_set']._options = None
  _DELETEFEATURESETREQUEST.fields_by_name['feature_set']._serialized_options = b'\030\001'
  _DELETEPROJECTREQUEST.fields_by_name['project']._options = None
  _DELETEPROJECTREQUEST.fields_by_name['project']._serialized_options = b'\030\001'
  _AWSCREDENTIALS.fields_by_name['bucket_name']._options = None
  _AWSCREDENTIALS.fields_by_name['bucket_name']._serialized_options = b'\030\001'
  _GETFEATURESETREQUEST.fields_by_name['project']._options = None
  _GETFEATURESETREQUEST.fields_by_name['project']._serialized_options = b'\030\001'
  _STARTINGESTJOBREQUEST.fields_by_name['feature_set']._options = None
  _STARTINGESTJOBREQUEST.fields_by_name['feature_set']._serialized_options = b'\030\001'
  _INGESTRESPONSE.fields_by_name['feature_set']._options = None
  _INGESTRESPONSE.fields_by_name['feature_set']._serialized_options = b'\030\001'
  _RETRIEVEREQUEST.fields_by_name['feature_set']._options = None
  _RETRIEVEREQUEST.fields_by_name['feature_set']._serialized_options = b'\030\001'
  _RETRIEVEASSPARKRESPONSE_OPTIONSENTRY._options = None
  _RETRIEVEASSPARKRESPONSE_OPTIONSENTRY._serialized_options = b'8\001'
  _STARTMATERIALIZATIONONLINEREQUEST.fields_by_name['feature_set']._options = None
  _STARTMATERIALIZATIONONLINEREQUEST.fields_by_name['feature_set']._serialized_options = b'\030\001'
  _INGESTWRITECREDENTIALRESPONSE_OPTIONSENTRY._options = None
  _INGESTWRITECREDENTIALRESPONSE_OPTIONSENTRY._serialized_options = b'8\001'
  _RETRIEVEFEATUREVIEWASSPARKRESPONSE_OPTIONSENTRY._options = None
  _RETRIEVEFEATUREVIEWASSPARKRESPONSE_OPTIONSENTRY._serialized_options = b'8\001'
  _RETRIEVEMLDATASETASSPARKRESPONSE_OPTIONSENTRY._options = None
  _RETRIEVEMLDATASETASSPARKRESPONSE_OPTIONSENTRY._serialized_options = b'8\001'
  _CREATENEWFEATURESETVERSIONREQUEST.fields_by_name['feature_set']._options = None
  _CREATENEWFEATURESETVERSIONREQUEST.fields_by_name['feature_set']._serialized_options = b'\030\001'
  _GENERATETRANSFORMATIONUPLOADRESPONSE_HEADERSENTRY._options = None
  _GENERATETRANSFORMATIONUPLOADRESPONSE_HEADERSENTRY._serialized_options = b'8\001'
  _BACKFILLOPTIONS_FEATUREMAPPINGENTRY._options = None
  _BACKFILLOPTIONS_FEATUREMAPPINGENTRY._serialized_options = b'8\001'
  _STOREFILEARTIFACTRESPONSE_HEADERSENTRY._options = None
  _STOREFILEARTIFACTRESPONSE_HEADERSENTRY._serialized_options = b'8\001'
  _CORESERVICE.methods_by_name['ListJobs']._options = None
  _CORESERVICE.methods_by_name['ListJobs']._serialized_options = b'\202\323\344\223\002\016\022\014/api/v1/jobs'
  _CORESERVICE.methods_by_name['GetJob']._options = None
  _CORESERVICE.methods_by_name['GetJob']._serialized_options = b'\202\323\344\223\002\027\022\025/api/v1/jobs/{job_id}'
  _CORESERVICE.methods_by_name['GetJobProgress']._options = None
  _CORESERVICE.methods_by_name['GetJobProgress']._serialized_options = b'\202\323\344\223\002-\022+/api/v1/jobs/{job_id}/progress/{next_index}'
  _CORESERVICE.methods_by_name['CancelJob']._options = None
  _CORESERVICE.methods_by_name['CancelJob']._serialized_options = b'\202\323\344\223\002\027*\025/api/v1/jobs/{job_id}'
  _CORESERVICE.methods_by_name['ListJobsPageByFeatureSetName']._options = None
  _CORESERVICE.methods_by_name['ListJobsPageByFeatureSetName']._serialized_options = b'\202\323\344\223\002\037\022\035/api/v1/jobs/feature-set/name'
  _CORESERVICE.methods_by_name['ListJobsPageByFeatureSetId']._options = None
  _CORESERVICE.methods_by_name['ListJobsPageByFeatureSetId']._serialized_options = b'\202\323\344\223\002\035\022\033/api/v1/jobs/feature-set/id'
  _CORESERVICE.methods_by_name['GetJobsWithStatusCount']._options = None
  _CORESERVICE.methods_by_name['GetJobsWithStatusCount']._serialized_options = b'\202\323\344\223\002\036\022\034/api/v1/jobs/count-by-status'
  _CORESERVICE.methods_by_name['StartExtractSchemaJob']._options = None
  _CORESERVICE.methods_by_name['StartExtractSchemaJob']._serialized_options = b'\202\323\344\223\002 \"\033/api/v1/jobs/extract-schema:\001*'
  _CORESERVICE.methods_by_name['GetExtractSchemaJobOutput']._options = None
  _CORESERVICE.methods_by_name['GetExtractSchemaJobOutput']._serialized_options = b'\202\323\344\223\002-\022+/api/v1/jobs/{job_id}/output/extract-schema'
  _CORESERVICE.methods_by_name['StartIngestJob']._options = None
  _CORESERVICE.methods_by_name['StartIngestJob']._serialized_options = b'\202\323\344\223\002\031\"\024/api/v1/ingest/start:\001*'
  _CORESERVICE.methods_by_name['GetIngestJobOutput']._options = None
  _CORESERVICE.methods_by_name['GetIngestJobOutput']._serialized_options = b'\202\323\344\223\002(\022&/api/v1/jobs/{job_id}/output/ingestion'
  _CORESERVICE.methods_by_name['StartRetrieveAsLinksJob']._options = None
  _CORESERVICE.methods_by_name['StartRetrieveAsLinksJob']._serialized_options = b'\202\323\344\223\002\"\"\035/api/v1/feature-sets/retrieve:\001*'
  _CORESERVICE.methods_by_name['GetRetrieveAsLinksJobOutput']._options = None
  _CORESERVICE.methods_by_name['GetRetrieveAsLinksJobOutput']._serialized_options = b'\202\323\344\223\002\'\022%/api/v1/feature-sets/retrieve{job_id}'
  _CORESERVICE.methods_by_name['RetrieveAsSpark']._options = None
  _CORESERVICE.methods_by_name['RetrieveAsSpark']._serialized_options = b'\202\323\344\223\002+\"&/api/v1/feature-sets/retrieve/as-spark:\001*'
  _CORESERVICE.methods_by_name['GetIngestWriteCredentials']._options = None
  _CORESERVICE.methods_by_name['GetIngestWriteCredentials']._serialized_options = b'\202\323\344\223\002(\022&/api/v1/ingest/credential/{session_id}'
  _CORESERVICE.methods_by_name['StartRevertIngestJob']._options = None
  _CORESERVICE.methods_by_name['StartRevertIngestJob']._serialized_options = b'\202\323\344\223\002\032\"\025/api/v1/ingest/revert:\001*'
  _CORESERVICE.methods_by_name['GetRevertIngestJobOutput']._options = None
  _CORESERVICE.methods_by_name['GetRevertIngestJobOutput']._serialized_options = b'\202\323\344\223\002 \022\036/api/v1/ingest/revert/{job_id}'
  _CORESERVICE.methods_by_name['HasPermissionToRetrieve']._options = None
  _CORESERVICE.methods_by_name['HasPermissionToRetrieve']._serialized_options = b'\202\323\344\223\002L\022J/api/v1/feature-sets/retrieve/permission/{project_name}/{feature_set_name}'
  _CORESERVICE.methods_by_name['RegisterFeatureSet']._options = None
  _CORESERVICE.methods_by_name['RegisterFeatureSet']._serialized_options = b'\202\323\344\223\002\031\"\024/api/v1/feature-sets:\001*'
  _CORESERVICE.methods_by_name['CreateNewFeatureSetVersion']._options = None
  _CORESERVICE.methods_by_name['CreateNewFeatureSetVersion']._serialized_options = b'\202\323\344\223\0022\"-/api/v1/feature-sets/{feature_set_id}/version:\001*'
  _CORESERVICE.methods_by_name['GetOnlineRetrieveMeta']._options = None
  _CORESERVICE.methods_by_name['GetOnlineRetrieveMeta']._serialized_options = b'\202\323\344\223\002\031\022\027/api/v1/online-retrieve'
  _CORESERVICE.methods_by_name['GetVersion']._options = None
  _CORESERVICE.methods_by_name['GetVersion']._serialized_options = b'\202\323\344\223\002\021\022\017/api/v1/version'
  _CORESERVICE.methods_by_name['GetFeatureSet']._options = None
  _CORESERVICE.methods_by_name['GetFeatureSet']._serialized_options = b'\202\323\344\223\002?\022=/api/v1/projects/{project_id}/feature-sets/{feature_set_name}'
  _CORESERVICE.methods_by_name['GetFeatureSetById']._options = None
  _CORESERVICE.methods_by_name['GetFeatureSetById']._serialized_options = b'\202\323\344\223\002\'\022%/api/v1/feature-sets/{feature_set_id}'
  _CORESERVICE.methods_by_name['GetFeatureSetsLastMinorForCurrentMajor']._options = None
  _CORESERVICE.methods_by_name['GetFeatureSetsLastMinorForCurrentMajor']._serialized_options = b'\202\323\344\223\002,\022*/api/v1/feature-sets/{feature_set_id}/last'
  _CORESERVICE.methods_by_name['ListFeatureSetVersions']._options = None
  _CORESERVICE.methods_by_name['ListFeatureSetVersions']._serialized_options = b'\202\323\344\223\0020\022./api/v1/feature-sets/{feature_set_id}/versions'
  _CORESERVICE.methods_by_name['DeleteFeatureSet']._options = None
  _CORESERVICE.methods_by_name['DeleteFeatureSet']._serialized_options = b'\202\323\344\223\002\'*%/api/v1/feature-sets/{feature_set_id}'
  _CORESERVICE.methods_by_name['DeleteFeatureSetVersion']._options = None
  _CORESERVICE.methods_by_name['DeleteFeatureSetVersion']._serialized_options = b'\202\323\344\223\002L*J/api/v1/feature-sets/{feature_set_id}/versions/{feature_set_major_version}'
  _CORESERVICE.methods_by_name['ListFeatureSetsPage']._options = None
  _CORESERVICE.methods_by_name['ListFeatureSetsPage']._serialized_options = b'\202\323\344\223\002\026\022\024/api/v1/feature-sets'
  _CORESERVICE.methods_by_name['FeatureSetExists']._options = None
  _CORESERVICE.methods_by_name['FeatureSetExists']._serialized_options = b'\202\323\344\223\002.\022,/api/v1/feature-sets/exists/{feature_set_id}'
  _CORESERVICE.methods_by_name['GetIngestHistory']._options = None
  _CORESERVICE.methods_by_name['GetIngestHistory']._serialized_options = b'\202\323\344\223\002\030\022\026/api/v1/ingest/history'
  _CORESERVICE.methods_by_name['IsFeatureSetSchemaCompatible']._options = None
  _CORESERVICE.methods_by_name['IsFeatureSetSchemaCompatible']._serialized_options = b'\202\323\344\223\0024\"//api/v1/feature-sets/features/schema-compatible:\001*'
  _CORESERVICE.methods_by_name['FeatureSetSchemaPatch']._options = None
  _CORESERVICE.methods_by_name['FeatureSetSchemaPatch']._serialized_options = b'\202\323\344\223\002/\"*/api/v1/feature-sets/features/schema-patch:\001*'
  _CORESERVICE.methods_by_name['GetFeatureSetPreview']._options = None
  _CORESERVICE.methods_by_name['GetFeatureSetPreview']._serialized_options = b'\202\323\344\223\002/\022-/api/v1/feature-sets/{feature_set_id}/preview'
  _CORESERVICE.methods_by_name['UpdateFeatureSet']._options = None
  _CORESERVICE.methods_by_name['UpdateFeatureSet']._serialized_options = b'\202\323\344\223\002*\032%/api/v1/feature-sets/{feature_set_id}:\001*'
  _CORESERVICE.methods_by_name['CreateFeatureView']._options = None
  _CORESERVICE.methods_by_name['CreateFeatureView']._serialized_options = b'\202\323\344\223\002\032\"\025/api/v1/feature-views:\001*'
  _CORESERVICE.methods_by_name['UpdateFeatureView']._options = None
  _CORESERVICE.methods_by_name['UpdateFeatureView']._serialized_options = b'\202\323\344\223\002,\032\'/api/v1/feature-views/{feature_view_id}:\001*'
  _CORESERVICE.methods_by_name['GetFeatureView']._options = None
  _CORESERVICE.methods_by_name['GetFeatureView']._serialized_options = b'\202\323\344\223\0024\0222/api/v1/projects/{project_id}/feature-views/{name}'
  _CORESERVICE.methods_by_name['FeatureViewExists']._options = None
  _CORESERVICE.methods_by_name['FeatureViewExists']._serialized_options = b'\202\323\344\223\0020\022./api/v1/feature-views/{feature_view_id}/exists'
  _CORESERVICE.methods_by_name['ListFeatureViews']._options = None
  _CORESERVICE.methods_by_name['ListFeatureViews']._serialized_options = b'\202\323\344\223\002-\022+/api/v1/projects/{project_id}/feature-views'
  _CORESERVICE.methods_by_name['CreateFeatureViewNewVersion']._options = None
  _CORESERVICE.methods_by_name['CreateFeatureViewNewVersion']._serialized_options = b'\202\323\344\223\002\032\"\025/api/v1/feature-views:\001*'
  _CORESERVICE.methods_by_name['StartRetrieveFeatureViewAsSparkJob']._options = None
  _CORESERVICE.methods_by_name['StartRetrieveFeatureViewAsSparkJob']._serialized_options = b'\202\323\344\223\002Y\"T/api/v1/feature-views/{feature_view_id}/{feature_view_version}/retrieve-as-spark-job:\001*'
  _CORESERVICE.methods_by_name['GetRetrieveFeatureViewAsSparkJobOutput']._options = None
  _CORESERVICE.methods_by_name['GetRetrieveFeatureViewAsSparkJobOutput']._serialized_options = b'\202\323\344\223\002&\022$/api/v1/feature-views/spark/{job_id}'
  _CORESERVICE.methods_by_name['StartRetrieveFeatureViewAsLinksJob']._options = None
  _CORESERVICE.methods_by_name['StartRetrieveFeatureViewAsLinksJob']._serialized_options = b'\202\323\344\223\002Y\"T/api/v1/feature-views/{feature_view_id}/{feature_view_version}/retrieve-as-links-job:\001*'
  _CORESERVICE.methods_by_name['GetRetrieveFeatureViewAsLinksJobOutput']._options = None
  _CORESERVICE.methods_by_name['GetRetrieveFeatureViewAsLinksJobOutput']._serialized_options = b'\202\323\344\223\002&\022$/api/v1/feature-views/links/{job_id}'
  _CORESERVICE.methods_by_name['DeleteFeatureView']._options = None
  _CORESERVICE.methods_by_name['DeleteFeatureView']._serialized_options = b'\202\323\344\223\002)*\'/api/v1/feature-views/{feature_view_id}'
  _CORESERVICE.methods_by_name['CreateMLDataset']._options = None
  _CORESERVICE.methods_by_name['CreateMLDataset']._serialized_options = b'\202\323\344\223\002\030\"\023/api/v1/ml-datasets:\001*'
  _CORESERVICE.methods_by_name['GetMLDatasetCreationJobOutput']._options = None
  _CORESERVICE.methods_by_name['GetMLDatasetCreationJobOutput']._serialized_options = b'\202\323\344\223\002=\022;/api/v1/ml-datasets//{ml_datasets_id}/creation-job/{job_id}'
  _CORESERVICE.methods_by_name['UpdateMLDataset']._options = None
  _CORESERVICE.methods_by_name['UpdateMLDataset']._serialized_options = b'\202\323\344\223\002(\032#/api/v1/ml-datasets/{ml_dataset_id}:\001*'
  _CORESERVICE.methods_by_name['DeleteMLDataset']._options = None
  _CORESERVICE.methods_by_name['DeleteMLDataset']._serialized_options = b'\202\323\344\223\002%*#/api/v1/ml-datasets/{ml_dataset_id}'
  _CORESERVICE.methods_by_name['GetMLDataset']._options = None
  _CORESERVICE.methods_by_name['GetMLDataset']._serialized_options = b'\202\323\344\223\002T\022R/api/v1/feature-views/{feature_view_id}/version/{feature_view_version}/ml-datasets'
  _CORESERVICE.methods_by_name['MLDatasetExists']._options = None
  _CORESERVICE.methods_by_name['MLDatasetExists']._serialized_options = b'\202\323\344\223\002,\022*/api/v1/ml-datasets/{ml_dataset_id}/exists'
  _CORESERVICE.methods_by_name['ListMLDatasets']._options = None
  _CORESERVICE.methods_by_name['ListMLDatasets']._serialized_options = b'\202\323\344\223\002\025\022\023/api/v1/ml-datasets'
  _CORESERVICE.methods_by_name['RetrieveMLDatasetAsSpark']._options = None
  _CORESERVICE.methods_by_name['RetrieveMLDatasetAsSpark']._serialized_options = b'\202\323\344\223\002.\")/api/v1/ml-datasets/{ml_dataset_id}/spark:\001*'
  _CORESERVICE.methods_by_name['RetrieveMLDatasetAsLinks']._options = None
  _CORESERVICE.methods_by_name['RetrieveMLDatasetAsLinks']._serialized_options = b'\202\323\344\223\002+\022)/api/v1/ml-datasets/{ml_dataset_id}/links'
  _CORESERVICE.methods_by_name['RetrieveMLDatasetOnline']._options = None
  _CORESERVICE.methods_by_name['RetrieveMLDatasetOnline']._serialized_options = b'\202\323\344\223\0025\0223/api/v1/ml-datasets/{ml_dataset_id}/online/retrieve'
  _CORESERVICE.methods_by_name['ListProjectsPage']._options = None
  _CORESERVICE.methods_by_name['ListProjectsPage']._serialized_options = b'\202\323\344\223\002\022\022\020/api/v1/projects'
  _CORESERVICE.methods_by_name['CreateProject']._options = None
  _CORESERVICE.methods_by_name['CreateProject']._serialized_options = b'\202\323\344\223\002\025\"\020/api/v1/projects:\001*'
  _CORESERVICE.methods_by_name['GetProject']._options = None
  _CORESERVICE.methods_by_name['GetProject']._serialized_options = b'\202\323\344\223\002!\022\037/api/v1/projects/{project_name}'
  _CORESERVICE.methods_by_name['DeleteProject']._options = None
  _CORESERVICE.methods_by_name['DeleteProject']._serialized_options = b'\202\323\344\223\002\036*\034/api/v1/projects/{projectId}'
  _CORESERVICE.methods_by_name['GetProjectsDefault']._options = None
  _CORESERVICE.methods_by_name['GetProjectsDefault']._serialized_options = b'\202\323\344\223\002\032\022\030/api/v1/projects/default'
  _CORESERVICE.methods_by_name['ProjectExists']._options = None
  _CORESERVICE.methods_by_name['ProjectExists']._serialized_options = b'\202\323\344\223\002&\022$/api/v1/projects/{project_id}/exists'
  _CORESERVICE.methods_by_name['UpdateProject']._options = None
  _CORESERVICE.methods_by_name['UpdateProject']._serialized_options = b'\202\323\344\223\002\"\032\035/api/v1/projects/{project_id}:\001*'
  _CORESERVICE.methods_by_name['ListProjectHistoryPage']._options = None
  _CORESERVICE.methods_by_name['ListProjectHistoryPage']._serialized_options = b'\202\323\344\223\002\'\022%/api/v1/projects/{project_id}/history'
  _CORESERVICE.methods_by_name['GetAccessToken']._options = None
  _CORESERVICE.methods_by_name['GetAccessToken']._serialized_options = b'\202\323\344\223\002\027\"\022/api/v1/auth/token:\001*'
  _CORESERVICE.methods_by_name['GetUserByMail']._options = None
  _CORESERVICE.methods_by_name['GetUserByMail']._serialized_options = b'\202\323\344\223\002\034\022\032/api/v1/auth/users/{email}'
  _CORESERVICE.methods_by_name['Logout']._options = None
  _CORESERVICE.methods_by_name['Logout']._serialized_options = b'\202\323\344\223\002\030\"\023/api/v1/auth/logout:\001*'
  _CORESERVICE.methods_by_name['GetActiveUser']._options = None
  _CORESERVICE.methods_by_name['GetActiveUser']._serialized_options = b'\202\323\344\223\002\024\022\022/api/v1/auth/users'
  _CORESERVICE.methods_by_name['Login']._options = None
  _CORESERVICE.methods_by_name['Login']._serialized_options = b'\202\323\344\223\002\027\"\022/api/v1/auth/login:\001*'
  _CORESERVICE.methods_by_name['GetWebConfig']._options = None
  _CORESERVICE.methods_by_name['GetWebConfig']._serialized_options = b'\202\323\344\223\002\020\022\016/api/v1/config'
  _CORESERVICE.methods_by_name['AddFeatureSetPermission']._options = None
  _CORESERVICE.methods_by_name['AddFeatureSetPermission']._serialized_options = b'\202\323\344\223\002*\"%/api/v1/auth/feature-sets/permissions:\001*'
  _CORESERVICE.methods_by_name['AddProjectPermission']._options = None
  _CORESERVICE.methods_by_name['AddProjectPermission']._serialized_options = b'\202\323\344\223\002=\"8/api/v1/permissions/projects/add/permission/{resourceId}:\001*'
  _CORESERVICE.methods_by_name['RemoveFeatureSetPermission']._options = None
  _CORESERVICE.methods_by_name['RemoveFeatureSetPermission']._serialized_options = b'\202\323\344\223\002E*@/api/v1/permissions/feature-sets/remove/permission/{resource_id}:\001*'
  _CORESERVICE.methods_by_name['RemoveProjectPermission']._options = None
  _CORESERVICE.methods_by_name['RemoveProjectPermission']._serialized_options = b'\202\323\344\223\002B*=/api/v1/permissions/projects/remove/permissions/{resource_id}:\001*'
  _CORESERVICE.methods_by_name['SubmitPendingProjectPermission']._options = None
  _CORESERVICE.methods_by_name['SubmitPendingProjectPermission']._serialized_options = b'\202\323\344\223\002/\"*/api/v1/permissions/projects/{resource_id}:\001*'
  _CORESERVICE.methods_by_name['SubmitPendingFeatureSetPermission']._options = None
  _CORESERVICE.methods_by_name['SubmitPendingFeatureSetPermission']._serialized_options = b'\202\323\344\223\0023\"./api/v1/permissions/feature-sets/{resource_id}:\001*'
  _CORESERVICE.methods_by_name['ListProjectPermissionsPage']._options = None
  _CORESERVICE.methods_by_name['ListProjectPermissionsPage']._serialized_options = b'\202\323\344\223\002\036\022\034/api/v1/permissions/projects'
  _CORESERVICE.methods_by_name['ListFeatureSetsPermissionsPage']._options = None
  _CORESERVICE.methods_by_name['ListFeatureSetsPermissionsPage']._serialized_options = b'\202\323\344\223\002\"\022 /api/v1/permissions/feature-sets'
  _CORESERVICE.methods_by_name['ListManageableProjectPermissionsPage']._options = None
  _CORESERVICE.methods_by_name['ListManageableProjectPermissionsPage']._serialized_options = b'\202\323\344\223\002)\022\'/api/v1/permissions/manageable-projects'
  _CORESERVICE.methods_by_name['ListManageableFeatureSetsPermissionsPage']._options = None
  _CORESERVICE.methods_by_name['ListManageableFeatureSetsPermissionsPage']._serialized_options = b'\202\323\344\223\002-\022+/api/v1/permissions/manageable-feature-sets'
  _CORESERVICE.methods_by_name['ApprovePendingPermission']._options = None
  _CORESERVICE.methods_by_name['ApprovePendingPermission']._serialized_options = b'\202\323\344\223\002!\"\034/api/v1/permissions/approval:\001*'
  _CORESERVICE.methods_by_name['RejectPendingPermission']._options = None
  _CORESERVICE.methods_by_name['RejectPendingPermission']._serialized_options = b'\202\323\344\223\002\"\"\035/api/v1/permissions/rejection:\001*'
  _CORESERVICE.methods_by_name['RevokePermission']._options = None
  _CORESERVICE.methods_by_name['RevokePermission']._serialized_options = b'\202\323\344\223\002\037\"\032/api/v1/permissions/revoke:\001*'
  _CORESERVICE.methods_by_name['GetActiveProjectPermission']._options = None
  _CORESERVICE.methods_by_name['GetActiveProjectPermission']._serialized_options = b'\202\323\344\223\0023\0221/api/v1/permissions/projects/{resource_id}/active'
  _CORESERVICE.methods_by_name['GetActiveFeatureSetPermission']._options = None
  _CORESERVICE.methods_by_name['GetActiveFeatureSetPermission']._serialized_options = b'\202\323\344\223\0027\0225/api/v1/permissions/feature-sets/{resource_id}/active'
  _CORESERVICE.methods_by_name['GetProjectOwners']._options = None
  _CORESERVICE.methods_by_name['GetProjectOwners']._serialized_options = b'\202\323\344\223\0022\0220/api/v1/permissions/project/{resource_id}/owners'
  _CORESERVICE.methods_by_name['GetFeatureSetOwners']._options = None
  _CORESERVICE.methods_by_name['GetFeatureSetOwners']._serialized_options = b'\202\323\344\223\0027\0225/api/v1/permissions/feature-sets/{resource_id}/owners'
  _CORESERVICE.methods_by_name['GetUserProjectPermissions']._options = None
  _CORESERVICE.methods_by_name['GetUserProjectPermissions']._serialized_options = b'\202\323\344\223\002,\022*/api/v1/permissions/projects/{resource_id}'
  _CORESERVICE.methods_by_name['GetUserFeatureSetPermissions']._options = None
  _CORESERVICE.methods_by_name['GetUserFeatureSetPermissions']._serialized_options = b'\202\323\344\223\0020\022./api/v1/permissions/feature-sets/{resource_id}'
  _CORESERVICE.methods_by_name['RevokeToken']._options = None
  _CORESERVICE.methods_by_name['RevokeToken']._serialized_options = b'\202\323\344\223\002\036\"\031/api/v1/auth/token/revoke:\001*'
  _CORESERVICE.methods_by_name['GenerateToken']._options = None
  _CORESERVICE.methods_by_name['GenerateToken']._serialized_options = b'\202\323\344\223\002 *\036/api/v1/auth/tokens/{token_id}'
  _CORESERVICE.methods_by_name['ListPersonalAccessTokens']._options = None
  _CORESERVICE.methods_by_name['ListPersonalAccessTokens']._serialized_options = b'\202\323\344\223\002\025\022\023/api/v1/auth/tokens'
  _CORESERVICE.methods_by_name['GetToken']._options = None
  _CORESERVICE.methods_by_name['GetToken']._serialized_options = b'\202\323\344\223\002 \022\036/api/v1/auth/tokens/{token_id}'
  _CORESERVICE.methods_by_name['OnlineRetrieve']._options = None
  _CORESERVICE.methods_by_name['OnlineRetrieve']._serialized_options = b'\202\323\344\223\0027\0225/api/v1/feature-sets/{feature_set_id}/online/retrieve'
  _CORESERVICE.methods_by_name['OnlineIngest']._options = None
  _CORESERVICE.methods_by_name['OnlineIngest']._serialized_options = b'\202\323\344\223\0028\0323/api/v1/feature-sets/{feature_set_id}/online/ingest:\001*'
  _CORESERVICE.methods_by_name['StartMaterializationOnlineJob']._options = None
  _CORESERVICE.methods_by_name['StartMaterializationOnlineJob']._serialized_options = b'\202\323\344\223\002A\"</api/v1/feature-sets/{feature_set_id}/online-materialization:\001*'
  _CORESERVICE.methods_by_name['GetMaterializationOnlineJobOutput']._options = None
  _CORESERVICE.methods_by_name['GetMaterializationOnlineJobOutput']._serialized_options = b'\202\323\344\223\0025\0223/api/v1/jobs/{job_id}/output/online-materialization'
  _CORESERVICE.methods_by_name['GetComputeStatisticsJobOutput']._options = None
  _CORESERVICE.methods_by_name['GetComputeStatisticsJobOutput']._serialized_options = b'\202\323\344\223\002%\022#/api/v1/compute-statistics/{job_id}'
  _CORESERVICE.methods_by_name['GetComputeRecommendationClassifiersJobOutput']._options = None
  _CORESERVICE.methods_by_name['GetComputeRecommendationClassifiersJobOutput']._serialized_options = b'\202\323\344\223\002E\022C/api/v1/jobs/{job_id}/output/recommendation-classifiers-computation'
  _CORESERVICE.methods_by_name['GenerateTransformationUpload']._options = None
  _CORESERVICE.methods_by_name['GenerateTransformationUpload']._serialized_options = b'\202\323\344\223\002\034\"\027/api/v1/transformations:\001*'
  _CORESERVICE.methods_by_name['ListRecommendationClassifiers']._options = None
  _CORESERVICE.methods_by_name['ListRecommendationClassifiers']._serialized_options = b'\202\323\344\223\002\025\022\023/api/v1/classifiers'
  _CORESERVICE.methods_by_name['CreateRecommendationClassifier']._options = None
  _CORESERVICE.methods_by_name['CreateRecommendationClassifier']._serialized_options = b'\202\323\344\223\002\030\"\023/api/v1/classifiers:\001*'
  _CORESERVICE.methods_by_name['UpdateRecommendationClassifier']._options = None
  _CORESERVICE.methods_by_name['UpdateRecommendationClassifier']._serialized_options = b'\202\323\344\223\002\037\032\032/api/v1/classifiers/{name}:\001*'
  _CORESERVICE.methods_by_name['DeleteRecommendationClassifier']._options = None
  _CORESERVICE.methods_by_name['DeleteRecommendationClassifier']._serialized_options = b'\202\323\344\223\002\'*%/api/v1/classifiers/{classifier_name}'
  _CORESERVICE.methods_by_name['GetRecommendations']._options = None
  _CORESERVICE.methods_by_name['GetRecommendations']._serialized_options = b'\202\323\344\223\0027\0225/api/v1/feature-sets/{feature_set_id}/recommendations'
  _CORESERVICE.methods_by_name['GetDashboard']._options = None
  _CORESERVICE.methods_by_name['GetDashboard']._serialized_options = b'\202\323\344\223\002\023\022\021/api/v1/dashboard'
  _CORESERVICE.methods_by_name['GetFeatureSetsPopularity']._options = None
  _CORESERVICE.methods_by_name['GetFeatureSetsPopularity']._serialized_options = b'\202\323\344\223\002(\022&/api/v1/dashboard/popular-feature-sets'
  _CORESERVICE.methods_by_name['GetRecentlyUsedProjects']._options = None
  _CORESERVICE.methods_by_name['GetRecentlyUsedProjects']._serialized_options = b'\202\323\344\223\002*\022(/api/v1/dashboard/recently-used-projects'
  _CORESERVICE.methods_by_name['GetRecentlyUsedFeatureSets']._options = None
  _CORESERVICE.methods_by_name['GetRecentlyUsedFeatureSets']._serialized_options = b'\202\323\344\223\002.\022,/api/v1/dashboard/recently-used-feature-sets'
  _CORESERVICE.methods_by_name['PinFeatureSet']._options = None
  _CORESERVICE.methods_by_name['PinFeatureSet']._serialized_options = b'\202\323\344\223\002;\0326/api/v1/dashboard/pinned-feature-sets/{feature_set_id}:\001*'
  _CORESERVICE.methods_by_name['UnpinFeatureSet']._options = None
  _CORESERVICE.methods_by_name['UnpinFeatureSet']._serialized_options = b'\202\323\344\223\002;*6/api/v1/dashboard/pinned-feature-sets/{feature_set_id}:\001*'
  _CORESERVICE.methods_by_name['IsFeatureSetPinned']._options = None
  _CORESERVICE.methods_by_name['IsFeatureSetPinned']._serialized_options = b'\202\323\344\223\002B\022=/api/v1/dashboard/pinned-feature-sets/exists/{feature_set_id}:\001*'
  _CORESERVICE.methods_by_name['ListPinnedFeatureSets']._options = None
  _CORESERVICE.methods_by_name['ListPinnedFeatureSets']._serialized_options = b'\202\323\344\223\002\'\022%/api/v1/dashboard/pinned-feature-sets'
  _CORESERVICE.methods_by_name['SearchProjects']._options = None
  _CORESERVICE.methods_by_name['SearchProjects']._serialized_options = b'\202\323\344\223\002\031\022\027/api/v1/search/projects'
  _CORESERVICE.methods_by_name['SearchFeatureSets']._options = None
  _CORESERVICE.methods_by_name['SearchFeatureSets']._serialized_options = b'\202\323\344\223\002\035\022\033/api/v1/search/feature-sets'
  _CORESERVICE.methods_by_name['SearchFeatures']._options = None
  _CORESERVICE.methods_by_name['SearchFeatures']._serialized_options = b'\202\323\344\223\002\031\022\027/api/v1/search/features'
  _CORESERVICE.methods_by_name['GetFeature']._options = None
  _CORESERVICE.methods_by_name['GetFeature']._serialized_options = b'\202\323\344\223\002=\022;/api/v1/feature-sets/{feature_set_id}/features/{feature_id}'
  _CORESERVICE.methods_by_name['ListFeatures']._options = None
  _CORESERVICE.methods_by_name['ListFeatures']._serialized_options = b'\202\323\344\223\0020\022./api/v1/feature-sets/{feature_set_id}/features'
  _CORESERVICE.methods_by_name['UpdateFeature']._options = None
  _CORESERVICE.methods_by_name['UpdateFeature']._serialized_options = b'\202\323\344\223\002@\032;/api/v1/feature-sets/{feature_set_id}/features/{feature_id}:\001*'
  _CORESERVICE.methods_by_name['MarkFeatureAsTarget']._options = None
  _CORESERVICE.methods_by_name['MarkFeatureAsTarget']._serialized_options = b'\202\323\344\223\002E\032C/api/v1/feature-sets/{feature_set_id}/target-variables/{feature_id}'
  _CORESERVICE.methods_by_name['DiscardFeatureAsTarget']._options = None
  _CORESERVICE.methods_by_name['DiscardFeatureAsTarget']._serialized_options = b'\202\323\344\223\002E*C/api/v1/feature-sets/{feature_set_id}/target-variables/{feature_id}'
  _CORESERVICE.methods_by_name['ListTargetFeatures']._options = None
  _CORESERVICE.methods_by_name['ListTargetFeatures']._serialized_options = b'\202\323\344\223\0028\0226/api/v1/feature-sets/{feature_set_id}/target-variables'
  _CORESERVICE.methods_by_name['GetListableFeatureSet']._options = None
  _CORESERVICE.methods_by_name['GetListableFeatureSet']._serialized_options = b'\202\323\344\223\0020\022./api/v1/feature-sets/{feature_set_id}/listable'
  _CORESERVICE.methods_by_name['ScheduleIngestJob']._options = None
  _CORESERVICE.methods_by_name['ScheduleIngestJob']._serialized_options = b'\202\323\344\223\002 \"\033/api/v1/schedules/ingestion:\001*'
  _CORESERVICE.methods_by_name['ListScheduledTasks']._options = None
  _CORESERVICE.methods_by_name['ListScheduledTasks']._serialized_options = b'\202\323\344\223\002$\022\"/api/v1/schedules/{feature_set_id}'
  _CORESERVICE.methods_by_name['GetScheduledTask']._options = None
  _CORESERVICE.methods_by_name['GetScheduledTask']._serialized_options = b'\202\323\344\223\002\'\022%/api/v1/schedules/{scheduled_task_id}'
  _CORESERVICE.methods_by_name['DeleteScheduledTask']._options = None
  _CORESERVICE.methods_by_name['DeleteScheduledTask']._serialized_options = b'\202\323\344\223\002\'*%/api/v1/schedules/{scheduled_task_id}'
  _CORESERVICE.methods_by_name['UpdateScheduledTask']._options = None
  _CORESERVICE.methods_by_name['UpdateScheduledTask']._serialized_options = b'\202\323\344\223\002*\032%/api/v1/schedules/{scheduled_task_id}:\001*'
  _CORESERVICE.methods_by_name['PauseScheduledTask']._options = None
  _CORESERVICE.methods_by_name['PauseScheduledTask']._serialized_options = b'\202\323\344\223\0020\032+/api/v1/schedules/{scheduled_task_id}/pause:\001*'
  _CORESERVICE.methods_by_name['ResumeScheduledTask']._options = None
  _CORESERVICE.methods_by_name['ResumeScheduledTask']._serialized_options = b'\202\323\344\223\0021\032,/api/v1/schedules/{scheduled_task_id}/resume:\001*'
  _CORESERVICE.methods_by_name['ScheduleLazyIngestTask']._options = None
  _CORESERVICE.methods_by_name['ScheduleLazyIngestTask']._serialized_options = b'\202\323\344\223\002%\" /api/v1/schedules/lazy/ingestion:\001*'
  _CORESERVICE.methods_by_name['StartLazyIngestTask']._options = None
  _CORESERVICE.methods_by_name['StartLazyIngestTask']._serialized_options = b'\202\323\344\223\002(\022&/api/v1/schedules/lazy/ingestion/start'
  _CORESERVICE.methods_by_name['GetLazyIngestTask']._options = None
  _CORESERVICE.methods_by_name['GetLazyIngestTask']._serialized_options = b'\202\323\344\223\002I\022G/api/v1/schedules/lazy/ingestion/{feature_set_id}/{feature_set_version}'
  _CORESERVICE.methods_by_name['ListScheduledTaskExecutionHistory']._options = None
  _CORESERVICE.methods_by_name['ListScheduledTaskExecutionHistory']._serialized_options = b'\202\323\344\223\002<\0227/api/v1/schedules/{scheduled_task_id}/execution-history:\001*'
  _CORESERVICE.methods_by_name['ListTransformationFunctions']._options = None
  _CORESERVICE.methods_by_name['ListTransformationFunctions']._serialized_options = b'\202\323\344\223\002\"\022 /api/v1/transformation_functions'
  _CORESERVICE.methods_by_name['GetTransformationFunction']._options = None
  _CORESERVICE.methods_by_name['GetTransformationFunction']._serialized_options = b'\202\323\344\223\002A\022?/api/v1/transformation_functions/{transformation_function_name}'
  _CORESERVICE.methods_by_name['GetBackfillJobOutput']._options = None
  _CORESERVICE.methods_by_name['GetBackfillJobOutput']._serialized_options = b'\202\323\344\223\002\'\022%/api/v1/jobs/{job_id}/output/backfill'
  _CORESERVICE.methods_by_name['CreateDraftFeatureSet']._options = None
  _CORESERVICE.methods_by_name['CreateDraftFeatureSet']._serialized_options = b'\202\323\344\223\002\037\"\032/api/v1/feature-sets/draft:\001*'
  _CORESERVICE.methods_by_name['CreateFeatureSetFromDraft']._options = None
  _CORESERVICE.methods_by_name['CreateFeatureSetFromDraft']._serialized_options = b'\202\323\344\223\002\'\"\"/api/v1/feature-sets/draft/publish:\001*'
  _CORESERVICE.methods_by_name['DeleteFeatureSetDraft']._options = None
  _CORESERVICE.methods_by_name['DeleteFeatureSetDraft']._serialized_options = b'\202\323\344\223\0023*1/api/v1/feature-sets/draft/{feature_set_draft_id}'
  _CORESERVICE.methods_by_name['ListFeatureSetDrafts']._options = None
  _CORESERVICE.methods_by_name['ListFeatureSetDrafts']._serialized_options = b'\202\323\344\223\002\034\022\032/api/v1/feature-sets/draft'
  _CORESERVICE.methods_by_name['GetFeatureSetDraft']._options = None
  _CORESERVICE.methods_by_name['GetFeatureSetDraft']._serialized_options = b'\202\323\344\223\0023\0221/api/v1/feature-sets/draft/{feature_set_draft_id}'
  _CORESERVICE.methods_by_name['StoreFileArtifact']._options = None
  _CORESERVICE.methods_by_name['StoreFileArtifact']._serialized_options = b'\202\323\344\223\002\034\"\027/api/v1/artifacts/files:\001*'
  _CORESERVICE.methods_by_name['RetrieveArtifact']._options = None
  _CORESERVICE.methods_by_name['RetrieveArtifact']._serialized_options = b'\202\323\344\223\002!\022\037/api/v1/artifacts/{artifact_id}'
  _CORESERVICE.methods_by_name['UpdateUploadStatus']._options = None
  _CORESERVICE.methods_by_name['UpdateUploadStatus']._serialized_options = b'\202\323\344\223\002+\032&/api/v1/artifacts/{artifact_id}/status:\001*'
  _CORESERVICE.methods_by_name['DeleteArtifact']._options = None
  _CORESERVICE.methods_by_name['DeleteArtifact']._serialized_options = b'\202\323\344\223\002!*\037/api/v1/artifacts/{artifact_id}'
  _CORESERVICE.methods_by_name['ListArtifacts']._options = None
  _CORESERVICE.methods_by_name['ListArtifacts']._serialized_options = b'\202\323\344\223\002@\022>/api/v1/artifacts/{feature_set_id}/{feature_set_major_version}'
  _CORESERVICE.methods_by_name['StoreLink']._options = None
  _CORESERVICE.methods_by_name['StoreLink']._serialized_options = b'\202\323\344\223\002\034\"\027/api/v1/artifacts/links:\001*'
  _CORESERVICE.methods_by_name['ListFeatureSetsToReview']._options = None
  _CORESERVICE.methods_by_name['ListFeatureSetsToReview']._serialized_options = b'\202\323\344\223\002\021\022\017/api/v1/reviews'
  _CORESERVICE.methods_by_name['ApproveReview']._options = None
  _CORESERVICE.methods_by_name['ApproveReview']._serialized_options = b'\202\323\344\223\002)\"$/api/v1/reviews/{review_id}/approval:\001*'
  _CORESERVICE.methods_by_name['RejectReview']._options = None
  _CORESERVICE.methods_by_name['RejectReview']._serialized_options = b'\202\323\344\223\002*\"%/api/v1/reviews/{review_id}/rejection:\001*'
  _CORESERVICE.methods_by_name['ListFeatureSetsReviewsPage']._options = None
  _CORESERVICE.methods_by_name['ListFeatureSetsReviewsPage']._serialized_options = b'\202\323\344\223\002\034\022\032/api/v1/reviews/my-reviews'
  _CORESERVICE.methods_by_name['GetListableFeatureSetToReview']._options = None
  _CORESERVICE.methods_by_name['GetListableFeatureSetToReview']._serialized_options = b'\202\323\344\223\0022\0220/api/v1/reviews/{review_id}/listable/feature-set'
  _CORESERVICE.methods_by_name['GetListableFeatureSetInReview']._options = None
  _CORESERVICE.methods_by_name['GetListableFeatureSetInReview']._serialized_options = b'\202\323\344\223\002=\022;/api/v1/reviews/my-reviews/{review_id}/listable/feature-set'
  _CORESERVICE.methods_by_name['DeleteFeatureSetVersionInReview']._options = None
  _CORESERVICE.methods_by_name['DeleteFeatureSetVersionInReview']._serialized_options = b'\202\323\344\223\0024\0222/api/v1/reviews/my-reviews/{review_id}/feature-set'
  _CORESERVICE.methods_by_name['ListFeaturesToReview']._options = None
  _CORESERVICE.methods_by_name['ListFeaturesToReview']._serialized_options = b'\202\323\344\223\002;\0229/api/v1/reviews/{review_id}/listable/feature-set/features'
  _CORESERVICE.methods_by_name['ListFeaturesInReview']._options = None
  _CORESERVICE.methods_by_name['ListFeaturesInReview']._serialized_options = b'\202\323\344\223\002F\022D/api/v1/reviews/my-reviews/{review_id}/listable/feature-set/features'
  _CORESERVICE.methods_by_name['GetFeatureSetPreviewToReview']._options = None
  _CORESERVICE.methods_by_name['GetFeatureSetPreviewToReview']._serialized_options = b'\202\323\344\223\0021\022//api/v1/reviews/{review_id}/feature-set/preview'
  _CORESERVICE.methods_by_name['GetFeatureSetPreviewInReview']._options = None
  _CORESERVICE.methods_by_name['GetFeatureSetPreviewInReview']._serialized_options = b'\202\323\344\223\002<\022:/api/v1/reviews/my-reviews/{review_id}/feature-set/preview'
  _CORESERVICE.methods_by_name['GetFeatureSetToReview']._options = None
  _CORESERVICE.methods_by_name['GetFeatureSetToReview']._serialized_options = b'\202\323\344\223\002)\022\'/api/v1/reviews/{review_id}/feature-set'
  _CORESERVICE.methods_by_name['GetFeatureSetInReview']._options = None
  _CORESERVICE.methods_by_name['GetFeatureSetInReview']._serialized_options = b'\202\323\344\223\0024\0222/api/v1/reviews/my-reviews/{review_id}/feature-set'
  _globals['_JOBTYPE']._serialized_start=46764
  _globals['_JOBTYPE']._serialized_end=47036
  _globals['_PERMISSIONTYPE']._serialized_start=47038
  _globals['_PERMISSIONTYPE']._serialized_end=47126
  _globals['_ACTIVEPERMISSION']._serialized_start=47129
  _globals['_ACTIVEPERMISSION']._serialized_end=47338
  _globals['_PROJECTACTION']._serialized_start=47340
  _globals['_PROJECTACTION']._serialized_end=47397
  _globals['_JOINTYPE']._serialized_start=47399
  _globals['_JOINTYPE']._serialized_end=47512
  _globals['_FEATUREFILTEROPERATOR']._serialized_start=47515
  _globals['_FEATUREFILTEROPERATOR']._serialized_end=47767
  _globals['_FEATUREFILTERLOGICOPERATOR']._serialized_start=47770
  _globals['_FEATUREFILTERLOGICOPERATOR']._serialized_end=47918
  _globals['_FEATUREQUERYJOINTYPE']._serialized_start=47920
  _globals['_FEATUREQUERYJOINTYPE']._serialized_end=48001
  _globals['_FEATUREDATATYPE']._serialized_start=48004
  _globals['_FEATUREDATATYPE']._serialized_end=48154
  _globals['_PROCESSINTERVALUNIT']._serialized_start=48156
  _globals['_PROCESSINTERVALUNIT']._serialized_end=48269
  _globals['_TRANSFORMATIONTYPE']._serialized_start=48271
  _globals['_TRANSFORMATIONTYPE']._serialized_end=48375
  _globals['_SORTDIRECTION']._serialized_start=48377
  _globals['_SORTDIRECTION']._serialized_end=48421
  _globals['_RESOURCETYPE']._serialized_start=48423
  _globals['_RESOURCETYPE']._serialized_end=48467
  _globals['_PERMISSIONSTATE']._serialized_start=48469
  _globals['_PERMISSIONSTATE']._serialized_end=48553
  _globals['_TASKTYPE']._serialized_start=48555
  _globals['_TASKTYPE']._serialized_end=48594
  _globals['_JOBSTATUS']._serialized_start=48597
  _globals['_JOBSTATUS']._serialized_end=48740
  _globals['_UPDATABLEPROJECTFIELD']._serialized_start=48743
  _globals['_UPDATABLEPROJECTFIELD']._serialized_end=48881
  _globals['_UPDATABLEFEATURESETFIELD']._serialized_start=48884
  _globals['_UPDATABLEFEATURESETFIELD']._serialized_end=49637
  _globals['_UPDATABLEFEATUREFIELD']._serialized_start=49640
  _globals['_UPDATABLEFEATUREFIELD']._serialized_end=49877
  _globals['_ARTIFACTTYPE']._serialized_start=49879
  _globals['_ARTIFACTTYPE']._serialized_end=49972
  _globals['_ARTIFACTUPLOADSTATUS']._serialized_start=49975
  _globals['_ARTIFACTUPLOADSTATUS']._serialized_end=50148
  _globals['_REVIEWSTATUS']._serialized_start=50151
  _globals['_REVIEWSTATUS']._serialized_end=50281
  _globals['_GETUSERPERMISSIONSREQUEST']._serialized_start=499
  _globals['_GETUSERPERMISSIONSREQUEST']._serialized_end=657
  _globals['_GETUSERPERMISSIONSRESPONSE']._serialized_start=659
  _globals['_GETUSERPERMISSIONSRESPONSE']._serialized_end=775
  _globals['_USERWITHPERMISSION']._serialized_start=778
  _globals['_USERWITHPERMISSION']._serialized_end=932
  _globals['_RESOURCEPERMISSION']._serialized_start=935
  _globals['_RESOURCEPERMISSION']._serialized_end=1084
  _globals['_LISTPERSONALACCESSTOKENSREQUEST']._serialized_start=1086
  _globals['_LISTPERSONALACCESSTOKENSREQUEST']._serialized_end=1158
  _globals['_LISTPERSONALACCESSTOKENSRESPONSE']._serialized_start=1161
  _globals['_LISTPERSONALACCESSTOKENSRESPONSE']._serialized_end=1301
  _globals['_IDENTITYPROVIDERDETAILS']._serialized_start=1303
  _globals['_IDENTITYPROVIDERDETAILS']._serialized_end=1385
  _globals['_GETWEBCONFIGRESPONSE']._serialized_start=1388
  _globals['_GETWEBCONFIGRESPONSE']._serialized_end=1524
  _globals['_GETFEATURESETSLASTMINORFORCURRENTMAJORREQUEST']._serialized_start=1526
  _globals['_GETFEATURESETSLASTMINORFORCURRENTMAJORREQUEST']._serialized_end=1626
  _globals['_FEATURESETEXISTSREQUEST']._serialized_start=1628
  _globals['_FEATURESETEXISTSREQUEST']._serialized_end=1737
  _globals['_GETINGESTHISTORYREQUEST']._serialized_start=1740
  _globals['_GETINGESTHISTORYREQUEST']._serialized_end=1883
  _globals['_PROJECTEXISTSREQUEST']._serialized_start=1885
  _globals['_PROJECTEXISTSREQUEST']._serialized_end=1952
  _globals['_FEATUREVIEWEXISTSREQUEST']._serialized_start=1954
  _globals['_FEATUREVIEWEXISTSREQUEST']._serialized_end=2030
  _globals['_MLDATASETEXISTSREQUEST']._serialized_start=2032
  _globals['_MLDATASETEXISTSREQUEST']._serialized_end=2104
  _globals['_EXISTSRESPONSE']._serialized_start=2106
  _globals['_EXISTSRESPONSE']._serialized_end=2138
  _globals['_PROJECTSDEFAULTRESPONSE']._serialized_start=2140
  _globals['_PROJECTSDEFAULTRESPONSE']._serialized_end=2181
  _globals['_HASPERMISSIONTORETRIEVEREQUEST']._serialized_start=2183
  _globals['_HASPERMISSIONTORETRIEVEREQUEST']._serialized_end=2263
  _globals['_HASPERMISSIONTORETRIEVERESPONSE']._serialized_start=2265
  _globals['_HASPERMISSIONTORETRIEVERESPONSE']._serialized_end=2331
  _globals['_STARTREVERTINGESTJOBREQUEST']._serialized_start=2334
  _globals['_STARTREVERTINGESTJOBREQUEST']._serialized_end=2500
  _globals['_ONLINERETRIEVEMETA']._serialized_start=2502
  _globals['_ONLINERETRIEVEMETA']._serialized_end=2603
  _globals['_REFRESHTOKENREQUEST']._serialized_start=2605
  _globals['_REFRESHTOKENREQUEST']._serialized_end=2649
  _globals['_GETUSERBYMAILREQUEST']._serialized_start=2651
  _globals['_GETUSERBYMAILREQUEST']._serialized_end=2688
  _globals['_GETUSERBYMAILRESPONSE']._serialized_start=2690
  _globals['_GETUSERBYMAILRESPONSE']._serialized_end=2770
  _globals['_TOKENREQUEST']._serialized_start=2772
  _globals['_TOKENREQUEST']._serialized_end=2804
  _globals['_GENERATETOKENREQUEST']._serialized_start=2806
  _globals['_GENERATETOKENREQUEST']._serialized_end=2912
  _globals['_TOKENRESPONSE']._serialized_start=2914
  _globals['_TOKENRESPONSE']._serialized_end=2993
  _globals['_LISTTOKENSRESPONSE']._serialized_start=2995
  _globals['_LISTTOKENSRESPONSE']._serialized_end=3080
  _globals['_RAWTOKENRESPONSE']._serialized_start=3082
  _globals['_RAWTOKENRESPONSE']._serialized_end=3115
  _globals['_LISTJOBSREQUEST']._serialized_start=3118
  _globals['_LISTJOBSREQUEST']._serialized_end=3295
  _globals['_LISTJOBSRESPONSE']._serialized_start=3297
  _globals['_LISTJOBSRESPONSE']._serialized_end=3362
  _globals['_FEATURESETSCHEMACOMPATIBILITYREQUEST']._serialized_start=3365
  _globals['_FEATURESETSCHEMACOMPATIBILITYREQUEST']._serialized_end=3562
  _globals['_FEATURESETSCHEMACOMPATIBILITYRESPONSE']._serialized_start=3564
  _globals['_FEATURESETSCHEMACOMPATIBILITYRESPONSE']._serialized_end=3626
  _globals['_FEATURESETSCHEMAPATCHREQUEST']._serialized_start=3629
  _globals['_FEATURESETSCHEMAPATCHREQUEST']._serialized_end=3818
  _globals['_FEATURESETSCHEMAPATCHRESPONSE']._serialized_start=3820
  _globals['_FEATURESETSCHEMAPATCHRESPONSE']._serialized_end=3910
  _globals['_JOBID']._serialized_start=3912
  _globals['_JOBID']._serialized_end=3935
  _globals['_GETRECOMMENDATIONREQUEST']._serialized_start=3937
  _globals['_GETRECOMMENDATIONREQUEST']._serialized_end=4052
  _globals['_GETRECOMMENDATIONRESPONSE']._serialized_start=4055
  _globals['_GETRECOMMENDATIONRESPONSE']._serialized_end=4358
  _globals['_GETRECOMMENDATIONRESPONSE_JOIN']._serialized_start=4162
  _globals['_GETRECOMMENDATIONRESPONSE_JOIN']._serialized_end=4205
  _globals['_GETRECOMMENDATIONRESPONSE_MATCH']._serialized_start=4208
  _globals['_GETRECOMMENDATIONRESPONSE_MATCH']._serialized_end=4358
  _globals['_JOB']._serialized_start=4361
  _globals['_JOB']._serialized_end=4661
  _globals['_JOBPROGRESSINPUT']._serialized_start=4663
  _globals['_JOBPROGRESSINPUT']._serialized_end=4717
  _globals['_JOBPROGRESSOUTPUT']._serialized_start=4720
  _globals['_JOBPROGRESSOUTPUT']._serialized_end=4918
  _globals['_JOBPROGRESSOUTPUT_PROGRESS']._serialized_start=4815
  _globals['_JOBPROGRESSOUTPUT_PROGRESS']._serialized_end=4918
  _globals['_FEATURESETPERMISSIONREQUEST']._serialized_start=4921
  _globals['_FEATURESETPERMISSIONREQUEST']._serialized_end=5124
  _globals['_PROJECTPERMISSIONREQUEST']._serialized_start=5127
  _globals['_PROJECTPERMISSIONREQUEST']._serialized_end=5316
  _globals['_STARTEXTRACTSCHEMAJOBREQUEST']._serialized_start=5319
  _globals['_STARTEXTRACTSCHEMAJOBREQUEST']._serialized_end=5551
  _globals['_EXTRACTSCHEMARESPONSE']._serialized_start=5554
  _globals['_EXTRACTSCHEMARESPONSE']._serialized_end=5706
  _globals['_LISTFEATURESETSVERSIONREQUEST']._serialized_start=5708
  _globals['_LISTFEATURESETSVERSIONREQUEST']._serialized_end=5828
  _globals['_FEATURESETRESPONSE']._serialized_start=5831
  _globals['_FEATURESETRESPONSE']._serialized_end=5960
  _globals['_UPDATEFEATURESETRESPONSE']._serialized_start=5962
  _globals['_UPDATEFEATURESETRESPONSE']._serialized_end=6057
  _globals['_UPDATEPROJECTRESPONSE']._serialized_start=6059
  _globals['_UPDATEPROJECTRESPONSE']._serialized_end=6144
  _globals['_UPDATEFEATURERESPONSE']._serialized_start=6147
  _globals['_UPDATEFEATURERESPONSE']._serialized_end=6301
  _globals['_PROJECTRESPONSE']._serialized_start=6303
  _globals['_PROJECTRESPONSE']._serialized_end=6374
  _globals['_LOGINRESPONSE']._serialized_start=6376
  _globals['_LOGINRESPONSE']._serialized_end=6449
  _globals['_GETACTIVEUSERRESPONSE']._serialized_start=6451
  _globals['_GETACTIVEUSERRESPONSE']._serialized_end=6531
  _globals['_GETPROJECTREQUEST']._serialized_start=6533
  _globals['_GETPROJECTREQUEST']._serialized_end=6574
  _globals['_DELETEFEATURESETREQUEST']._serialized_start=6576
  _globals['_DELETEFEATURESETREQUEST']._serialized_end=6690
  _globals['_DELETEFEATURESETVERSIONREQUEST']._serialized_start=6692
  _globals['_DELETEFEATURESETVERSIONREQUEST']._serialized_end=6783
  _globals['_LOGOUTREQUEST']._serialized_start=6785
  _globals['_LOGOUTREQUEST']._serialized_end=6823
  _globals['_USERBASICINFO']._serialized_start=6825
  _globals['_USERBASICINFO']._serialized_end=6881
  _globals['_USER']._serialized_start=6883
  _globals['_USER']._serialized_end=6972
  _globals['_ACCESSTOKENRESPONSE']._serialized_start=6974
  _globals['_ACCESSTOKENRESPONSE']._serialized_end=7095
  _globals['_DELETEPROJECTREQUEST']._serialized_start=7097
  _globals['_DELETEPROJECTREQUEST']._serialized_end=7197
  _globals['_CREATEPROJECTREQUEST']._serialized_start=7200
  _globals['_CREATEPROJECTREQUEST']._serialized_end=7343
  _globals['_CREATEPROJECTRESPONSE']._serialized_start=7345
  _globals['_CREATEPROJECTRESPONSE']._serialized_end=7446
  _globals['_LISTPROJECTSRESPONSE']._serialized_start=7448
  _globals['_LISTPROJECTSRESPONSE']._serialized_end=7525
  _globals['_LISTPROJECTHISTORYPAGEREQUEST']._serialized_start=7527
  _globals['_LISTPROJECTHISTORYPAGEREQUEST']._serialized_end=7617
  _globals['_PROJECTHISTORY']._serialized_start=7620
  _globals['_PROJECTHISTORY']._serialized_end=7814
  _globals['_LISTPROJECTHISTORYPAGERESPONSE']._serialized_start=7816
  _globals['_LISTPROJECTHISTORYPAGERESPONSE']._serialized_end=7934
  _globals['_GETINGESTHISTORYRESPONSE']._serialized_start=7936
  _globals['_GETINGESTHISTORYRESPONSE']._serialized_end=8032
  _globals['_LISTFEATURESETSPAGEREQUEST']._serialized_start=8034
  _globals['_LISTFEATURESETSPAGEREQUEST']._serialized_end=8124
  _globals['_LISTFEATURESETSPAGERESPONSE']._serialized_start=8126
  _globals['_LISTFEATURESETSPAGERESPONSE']._serialized_end=8242
  _globals['_AWSCREDENTIALS']._serialized_start=8245
  _globals['_AWSCREDENTIALS']._serialized_end=8382
  _globals['_AZURECREDENTIALS']._serialized_start=8385
  _globals['_AZURECREDENTIALS']._serialized_end=8551
  _globals['_SNOWFLAKECREDENTIALS']._serialized_start=8553
  _globals['_SNOWFLAKECREDENTIALS']._serialized_end=8607
  _globals['_JDBCCREDENTIALS']._serialized_start=8609
  _globals['_JDBCCREDENTIALS']._serialized_end=8658
  _globals['_MONGODBCREDENTIALS']._serialized_start=8660
  _globals['_MONGODBCREDENTIALS']._serialized_end=8712
  _globals['_CREDENTIALS']._serialized_start=8715
  _globals['_CREDENTIALS']._serialized_end=9055
  _globals['_LISTFEATURESETSRESPONSE']._serialized_start=9057
  _globals['_LISTFEATURESETSRESPONSE']._serialized_end=9144
  _globals['_LISTFEATURESETVERSIONSRESPONSE']._serialized_start=9146
  _globals['_LISTFEATURESETVERSIONSRESPONSE']._serialized_end=9254
  _globals['_FEATURESETVERSIONDESCRIPTION']._serialized_start=9256
  _globals['_FEATURESETVERSIONDESCRIPTION']._serialized_end=9382
  _globals['_GETFEATURESETREQUEST']._serialized_start=9385
  _globals['_GETFEATURESETREQUEST']._serialized_end=9528
  _globals['_STARTINGESTJOBREQUEST']._serialized_start=9531
  _globals['_STARTINGESTJOBREQUEST']._serialized_end=9805
  _globals['_INGESTRESPONSE']._serialized_start=9808
  _globals['_INGESTRESPONSE']._serialized_end=10228
  _globals['_INGESTRESPONSE_INGESTMETA']._serialized_start=10014
  _globals['_INGESTRESPONSE_INGESTMETA']._serialized_end=10228
  _globals['_RETRIEVEREQUEST']._serialized_start=10231
  _globals['_RETRIEVEREQUEST']._serialized_end=10453
  _globals['_RETRIEVEASLINKSRESPONSE']._serialized_start=10456
  _globals['_RETRIEVEASLINKSRESPONSE']._serialized_end=10595
  _globals['_RETRIEVEASSPARKRESPONSE']._serialized_start=10598
  _globals['_RETRIEVEASSPARKRESPONSE']._serialized_end=10876
  _globals['_RETRIEVEASSPARKRESPONSE_OPTIONSENTRY']._serialized_start=10830
  _globals['_RETRIEVEASSPARKRESPONSE_OPTIONSENTRY']._serialized_end=10876
  _globals['_STARTMATERIALIZATIONONLINEREQUEST']._serialized_start=10879
  _globals['_STARTMATERIALIZATIONONLINEREQUEST']._serialized_end=11032
  _globals['_MATERIALIZATIONONLINERESPONSE']._serialized_start=11034
  _globals['_MATERIALIZATIONONLINERESPONSE']._serialized_end=11152
  _globals['_INGESTWRITECREDENTIALREQUEST']._serialized_start=11154
  _globals['_INGESTWRITECREDENTIALREQUEST']._serialized_end=11204
  _globals['_INGESTWRITECREDENTIALRESPONSE']._serialized_start=11207
  _globals['_INGESTWRITECREDENTIALRESPONSE']._serialized_end=11409
  _globals['_INGESTWRITECREDENTIALRESPONSE_OPTIONSENTRY']._serialized_start=10830
  _globals['_INGESTWRITECREDENTIALRESPONSE_OPTIONSENTRY']._serialized_end=10876
  _globals['_RAWDATALOCATION']._serialized_start=11412
  _globals['_RAWDATALOCATION']._serialized_end=12232
  _globals['_ONLINESOURCESPEC']._serialized_start=12234
  _globals['_ONLINESOURCESPEC']._serialized_end=12287
  _globals['_CSVFILESPEC']._serialized_start=12289
  _globals['_CSVFILESPEC']._serialized_end=12335
  _globals['_JSONFILESPEC']._serialized_start=12337
  _globals['_JSONFILESPEC']._serialized_end=12384
  _globals['_PARQUETFILESPEC']._serialized_start=12386
  _globals['_PARQUETFILESPEC']._serialized_end=12417
  _globals['_TEMPPARQUETFILESPEC']._serialized_start=12419
  _globals['_TEMPPARQUETFILESPEC']._serialized_end=12454
  _globals['_PROXY']._serialized_start=12456
  _globals['_PROXY']._serialized_end=12523
  _globals['_SNOWFLAKETABLESPEC']._serialized_start=12526
  _globals['_SNOWFLAKETABLESPEC']._serialized_end=12741
  _globals['_JDBCTABLESPEC']._serialized_start=12744
  _globals['_JDBCTABLESPEC']._serialized_end=12925
  _globals['_DELTATABLESPEC']._serialized_start=12927
  _globals['_DELTATABLESPEC']._serialized_end=13045
  _globals['_CSVFOLDERSPEC']._serialized_start=13047
  _globals['_CSVFOLDERSPEC']._serialized_end=13126
  _globals['_PARQUETFOLDERSPEC']._serialized_start=13128
  _globals['_PARQUETFOLDERSPEC']._serialized_end=13192
  _globals['_JSONFOLDERSPEC']._serialized_start=13194
  _globals['_JSONFOLDERSPEC']._serialized_end=13274
  _globals['_MONGODBCOLLECTIONSPEC']._serialized_start=13276
  _globals['_MONGODBCOLLECTIONSPEC']._serialized_end=13361
  _globals['_MOJOTRANSFORMATION']._serialized_start=13363
  _globals['_MOJOTRANSFORMATION']._serialized_end=13401
  _globals['_SPARKPIPELINETRANSFORMATION']._serialized_start=13403
  _globals['_SPARKPIPELINETRANSFORMATION']._serialized_end=13450
  _globals['_JOINTRANSFORMATION']._serialized_start=13452
  _globals['_JOINTRANSFORMATION']._serialized_end=13566
  _globals['_VERSIONEDID']._serialized_start=13568
  _globals['_VERSIONEDID']._serialized_end=13616
  _globals['_TRANSFORMATION']._serialized_start=13619
  _globals['_TRANSFORMATION']._serialized_end=13855
  _globals['_DERIVEDINFORMATION']._serialized_start=13858
  _globals['_DERIVEDINFORMATION']._serialized_end=14012
  _globals['_SELECTEDFEATURE']._serialized_start=14014
  _globals['_SELECTEDFEATURE']._serialized_end=14088
  _globals['_FILTERCONDITIONUNION']._serialized_start=14091
  _globals['_FILTERCONDITIONUNION']._serialized_end=14252
  _globals['_FEATUREFILTER']._serialized_start=14255
  _globals['_FEATUREFILTER']._serialized_end=14416
  _globals['_FEATUREFILTERLOGIC']._serialized_start=14419
  _globals['_FEATUREFILTERLOGIC']._serialized_end=14648
  _globals['_FEATUREQUERY']._serialized_start=14651
  _globals['_FEATUREQUERY']._serialized_end=15363
  _globals['_FEATUREQUERY_FROM']._serialized_start=14938
  _globals['_FEATUREQUERY_FROM']._serialized_end=15021
  _globals['_FEATUREQUERY_JOIN']._serialized_start=15024
  _globals['_FEATUREQUERY_JOIN']._serialized_end=15363
  _globals['_FEATUREQUERY_JOIN_ON']._serialized_start=15240
  _globals['_FEATUREQUERY_JOIN_ON']._serialized_end=15363
  _globals['_FEATUREVIEW']._serialized_start=15366
  _globals['_FEATUREVIEW']._serialized_end=15520
  _globals['_CREATEFEATUREVIEWREQUEST']._serialized_start=15523
  _globals['_CREATEFEATUREVIEWREQUEST']._serialized_end=15661
  _globals['_UPDATEFEATUREVIEWREQUEST']._serialized_start=15663
  _globals['_UPDATEFEATUREVIEWREQUEST']._serialized_end=15765
  _globals['_CREATEFEATUREVIEWNEWVERSIONREQUEST']._serialized_start=15768
  _globals['_CREATEFEATUREVIEWNEWVERSIONREQUEST']._serialized_end=15916
  _globals['_GETFEATUREVIEWREQUEST']._serialized_start=15918
  _globals['_GETFEATUREVIEWREQUEST']._serialized_end=15992
  _globals['_FEATUREVIEWRESPONSE']._serialized_start=15994
  _globals['_FEATUREVIEWRESPONSE']._serialized_end=16078
  _globals['_LISTFEATUREVIEWSREQUEST']._serialized_start=16080
  _globals['_LISTFEATUREVIEWSREQUEST']._serialized_end=16125
  _globals['_LISTFEATUREVIEWSRESPONSE']._serialized_start=16127
  _globals['_LISTFEATUREVIEWSRESPONSE']._serialized_end=16217
  _globals['_RETRIEVEFEATUREVIEWASSPARKREQUEST']._serialized_start=16220
  _globals['_RETRIEVEFEATUREVIEWASSPARKREQUEST']._serialized_end=16420
  _globals['_RETRIEVEFEATUREVIEWASSPARKRESPONSE']._serialized_start=16423
  _globals['_RETRIEVEFEATUREVIEWASSPARKRESPONSE']._serialized_end=16635
  _globals['_RETRIEVEFEATUREVIEWASSPARKRESPONSE_OPTIONSENTRY']._serialized_start=10830
  _globals['_RETRIEVEFEATUREVIEWASSPARKRESPONSE_OPTIONSENTRY']._serialized_end=10876
  _globals['_RETRIEVEFEATUREVIEWASASLINKSREQUEST']._serialized_start=16638
  _globals['_RETRIEVEFEATUREVIEWASASLINKSREQUEST']._serialized_end=16820
  _globals['_RETRIEVEFEATUREVIEWASASLINKSRESPONSE']._serialized_start=16822
  _globals['_RETRIEVEFEATUREVIEWASASLINKSRESPONSE']._serialized_end=16884
  _globals['_DELETEFEATUREVIEWREQUEST']._serialized_start=16886
  _globals['_DELETEFEATUREVIEWREQUEST']._serialized_end=16937
  _globals['_MLDATASETFEATURE']._serialized_start=16940
  _globals['_MLDATASETFEATURE']._serialized_end=17339
  _globals['_MLDATASET']._serialized_start=17342
  _globals['_MLDATASET']._serialized_end=17844
  _globals['_MLDATASET_MLDATASETSTATE']._serialized_start=17736
  _globals['_MLDATASET_MLDATASETSTATE']._serialized_end=17844
  _globals['_CREATEMLDATASETREQUEST']._serialized_start=17847
  _globals['_CREATEMLDATASETREQUEST']._serialized_end=18065
  _globals['_UPDATEMLDATASETREQUEST']._serialized_start=18067
  _globals['_UPDATEMLDATASETREQUEST']._serialized_end=18135
  _globals['_DELETEMLDATASETREQUEST']._serialized_start=18137
  _globals['_DELETEMLDATASETREQUEST']._serialized_end=18184
  _globals['_CREATEMLDATASETRESPONSE']._serialized_start=18187
  _globals['_CREATEMLDATASETRESPONSE']._serialized_end=18319
  _globals['_GETMLDATASETREQUEST']._serialized_start=18321
  _globals['_GETMLDATASETREQUEST']._serialized_end=18422
  _globals['_LISTMLDATASETSREQUEST']._serialized_start=18424
  _globals['_LISTMLDATASETSREQUEST']._serialized_end=18502
  _globals['_LISTMLDATASETSRESPONSE']._serialized_start=18504
  _globals['_LISTMLDATASETSRESPONSE']._serialized_end=18588
  _globals['_RETRIEVEMLDATASETASSPARKREQUEST']._serialized_start=18590
  _globals['_RETRIEVEMLDATASETASSPARKREQUEST']._serialized_end=18666
  _globals['_RETRIEVEMLDATASETASSPARKRESPONSE']._serialized_start=18669
  _globals['_RETRIEVEMLDATASETASSPARKRESPONSE']._serialized_end=18877
  _globals['_RETRIEVEMLDATASETASSPARKRESPONSE_OPTIONSENTRY']._serialized_start=10830
  _globals['_RETRIEVEMLDATASETASSPARKRESPONSE_OPTIONSENTRY']._serialized_end=10876
  _globals['_RETRIEVEMLDATASETASASLINKSREQUEST']._serialized_start=18879
  _globals['_RETRIEVEMLDATASETASASLINKSREQUEST']._serialized_end=18937
  _globals['_RETRIEVEMLDATASETASASLINKSRESPONSE']._serialized_start=18939
  _globals['_RETRIEVEMLDATASETASASLINKSRESPONSE']._serialized_end=18999
  _globals['_RETRIEVEMLDATASETONLINEREQUEST']._serialized_start=19001
  _globals['_RETRIEVEMLDATASETONLINEREQUEST']._serialized_end=19070
  _globals['_FEATURESET']._serialized_start=19073
  _globals['_FEATURESET']._serialized_end=20975
  _globals['_FEATURESET_STATISTICS']._serialized_start=20575
  _globals['_FEATURESET_STATISTICS']._serialized_end=20632
  _globals['_FEATURESET_SPECIALDATA']._serialized_start=20635
  _globals['_FEATURESET_SPECIALDATA']._serialized_end=20893
  _globals['_FEATURESET_SPECIALDATA_LEGAL']._serialized_start=20802
  _globals['_FEATURESET_SPECIALDATA_LEGAL']._serialized_end=20893
  _globals['_FEATURESET_ONLINE']._serialized_start=20895
  _globals['_FEATURESET_ONLINE']._serialized_end=20969
  _globals['_GETFEATURESETPREVIEWREQUEST']._serialized_start=20977
  _globals['_GETFEATURESETPREVIEWREQUEST']._serialized_end=21059
  _globals['_GETFEATURESETPREVIEWRESPONSE']._serialized_start=21061
  _globals['_GETFEATURESETPREVIEWRESPONSE']._serialized_end=21134
  _globals['_SCOPE']._serialized_start=21136
  _globals['_SCOPE']._serialized_end=21247
  _globals['_REGISTERFEATURESETREQUEST']._serialized_start=21250
  _globals['_REGISTERFEATURESETREQUEST']._serialized_end=22225
  _globals['_CREATENEWFEATURESETVERSIONREQUEST']._serialized_start=22228
  _globals['_CREATENEWFEATURESETVERSIONREQUEST']._serialized_end=22807
  _globals['_FEATUREPROFILE']._serialized_start=22810
  _globals['_FEATUREPROFILE']._serialized_end=23065
  _globals['_FEATURESCHEMA']._serialized_start=23068
  _globals['_FEATURESCHEMA']._serialized_end=23612
  _globals['_FEATURESCHEMA_SPECIALDATA']._serialized_start=20635
  _globals['_FEATURESCHEMA_SPECIALDATA']._serialized_end=20727
  _globals['_FEATURESCHEMA_MONITORING']._serialized_start=23573
  _globals['_FEATURESCHEMA_MONITORING']._serialized_end=23612
  _globals['_FEATURE']._serialized_start=23615
  _globals['_FEATURE']._serialized_end=24272
  _globals['_FEATURE_MONITORING']._serialized_start=23573
  _globals['_FEATURE_MONITORING']._serialized_end=23612
  _globals['_FEATURE_SPECIALDATA']._serialized_start=20635
  _globals['_FEATURE_SPECIALDATA']._serialized_end=20727
  _globals['_FEATURESTATISTICS']._serialized_start=24275
  _globals['_FEATURESTATISTICS']._serialized_end=24447
  _globals['_CATEGORICALFEATURESTATISTICS']._serialized_start=24450
  _globals['_CATEGORICALFEATURESTATISTICS']._serialized_end=24621
  _globals['_CATEGORICALFEATURESTATISTICS_FEATURETOP']._serialized_start=24580
  _globals['_CATEGORICALFEATURESTATISTICS_FEATURETOP']._serialized_end=24621
  _globals['_GETVERSIONRESPONSE']._serialized_start=24623
  _globals['_GETVERSIONRESPONSE']._serialized_end=24660
  _globals['_PROJECT']._serialized_start=24663
  _globals['_PROJECT']._serialized_end=25072
  _globals['_LISTABLEPROJECT']._serialized_start=25075
  _globals['_LISTABLEPROJECT']._serialized_end=25367
  _globals['_FEATURESETINGEST']._serialized_start=25370
  _globals['_FEATURESETINGEST']._serialized_end=25744
  _globals['_PERSONALACCESSTOKEN']._serialized_start=25747
  _globals['_PERSONALACCESSTOKEN']._serialized_end=25962
  _globals['_GENERATETRANSFORMATIONUPLOADREQUEST']._serialized_start=25965
  _globals['_GENERATETRANSFORMATIONUPLOADREQUEST']._serialized_end=26101
  _globals['_GENERATETRANSFORMATIONUPLOADRESPONSE']._serialized_start=26104
  _globals['_GENERATETRANSFORMATIONUPLOADRESPONSE']._serialized_end=26317
  _globals['_GENERATETRANSFORMATIONUPLOADRESPONSE_HEADERSENTRY']._serialized_start=26271
  _globals['_GENERATETRANSFORMATIONUPLOADRESPONSE_HEADERSENTRY']._serialized_end=26317
  _globals['_LISTPROJECTSPAGEREQUEST']._serialized_start=26319
  _globals['_LISTPROJECTSPAGEREQUEST']._serialized_end=26383
  _globals['_LISTPROJECTSPAGERESPONSE']._serialized_start=26385
  _globals['_LISTPROJECTSPAGERESPONSE']._serialized_end=26491
  _globals['_PROJECTSEARCHREQUEST']._serialized_start=26494
  _globals['_PROJECTSEARCHREQUEST']._serialized_end=27038
  _globals['_PROJECTSEARCHREQUEST_PROJECTSORTFIELD']._serialized_start=26823
  _globals['_PROJECTSEARCHREQUEST_PROJECTSORTFIELD']._serialized_end=27038
  _globals['_FEATURESETSEARCHREQUEST']._serialized_start=27041
  _globals['_FEATURESETSEARCHREQUEST']._serialized_end=27572
  _globals['_FEATURESETSEARCHREQUEST_FEATURESETSORTFIELD']._serialized_start=27324
  _globals['_FEATURESETSEARCHREQUEST_FEATURESETSORTFIELD']._serialized_end=27572
  _globals['_FEATURESEARCHREQUEST']._serialized_start=27575
  _globals['_FEATURESEARCHREQUEST']._serialized_end=27965
  _globals['_FEATURESEARCHREQUEST_FEATURESORTFIELD']._serialized_start=27848
  _globals['_FEATURESEARCHREQUEST_FEATURESORTFIELD']._serialized_end=27965
  _globals['_PROJECTSEARCHRESULTS']._serialized_start=27967
  _globals['_PROJECTSEARCHRESULTS']._serialized_end=28085
  _globals['_LISTABLEFEATURESET']._serialized_start=28088
  _globals['_LISTABLEFEATURESET']._serialized_end=29207
  _globals['_FEATURESETSEARCHRESULTS']._serialized_start=29210
  _globals['_FEATURESETSEARCHRESULTS']._serialized_end=29338
  _globals['_LISTABLEFEATURE']._serialized_start=29341
  _globals['_LISTABLEFEATURE']._serialized_end=29563
  _globals['_FEATURESEARCHRESULTS']._serialized_start=29565
  _globals['_FEATURESEARCHRESULTS']._serialized_end=29683
  _globals['_FEATURESETREQUESTID']._serialized_start=29685
  _globals['_FEATURESETREQUESTID']._serialized_end=29759
  _globals['_GETFEATUREREQUEST']._serialized_start=29761
  _globals['_GETFEATUREREQUEST']._serialized_end=29853
  _globals['_LISTFEATURESPAGERESPONSE']._serialized_start=29855
  _globals['_LISTFEATURESPAGERESPONSE']._serialized_end=29961
  _globals['_FEATURERESPONSE']._serialized_start=29963
  _globals['_FEATURERESPONSE']._serialized_end=30034
  _globals['_LISTFEATURESREQUEST']._serialized_start=30036
  _globals['_LISTFEATURESREQUEST']._serialized_end=30135
  _globals['_LISTFEATURESRESPONSE']._serialized_start=30137
  _globals['_LISTFEATURESRESPONSE']._serialized_end=30239
  _globals['_LISTABLEFEATURESETREQUEST']._serialized_start=30241
  _globals['_LISTABLEFEATURESETREQUEST']._serialized_end=30321
  _globals['_LISTABLEFEATURESETRESPONSE']._serialized_start=30323
  _globals['_LISTABLEFEATURESETRESPONSE']._serialized_end=30429
  _globals['_SUBMITPENDINGPERMISSIONREQUEST']._serialized_start=30432
  _globals['_SUBMITPENDINGPERMISSIONREQUEST']._serialized_end=30565
  _globals['_SUBMITPENDINGPERMISSIONRESPONSE']._serialized_start=30567
  _globals['_SUBMITPENDINGPERMISSIONRESPONSE']._serialized_end=30623
  _globals['_LISTPERMISSIONSPAGEREQUEST']._serialized_start=30626
  _globals['_LISTPERMISSIONSPAGEREQUEST']._serialized_end=30755
  _globals['_LISTPROJECTSPERMISSIONSPAGERESPONSE']._serialized_start=30758
  _globals['_LISTPROJECTSPERMISSIONSPAGERESPONSE']._serialized_end=30894
  _globals['_LISTFEATURESETSPERMISSIONSPAGERESPONSE']._serialized_start=30897
  _globals['_LISTFEATURESETSPERMISSIONSPAGERESPONSE']._serialized_end=31039
  _globals['_LISTABLEPROJECTTOPERMISSION']._serialized_start=31042
  _globals['_LISTABLEPROJECTTOPERMISSION']._serialized_end=31193
  _globals['_LISTABLEFEATURESETTOPERMISSION']._serialized_start=31196
  _globals['_LISTABLEFEATURESETTOPERMISSION']._serialized_end=31357
  _globals['_PERMISSION']._serialized_start=31360
  _globals['_PERMISSION']._serialized_end=32492
  _globals['_PERMISSION_PROMOTEDUPDATE']._serialized_start=32032
  _globals['_PERMISSION_PROMOTEDUPDATE']._serialized_end=32204
  _globals['_PERMISSION_REVOKEDUPDATE']._serialized_start=32207
  _globals['_PERMISSION_REVOKEDUPDATE']._serialized_end=32343
  _globals['_PERMISSION_GRANTEDORREJECTEDUPDATE']._serialized_start=32346
  _globals['_PERMISSION_GRANTEDORREJECTEDUPDATE']._serialized_end=32492
  _globals['_REVOKEPERMISSIONREQUEST']._serialized_start=32494
  _globals['_REVOKEPERMISSIONREQUEST']._serialized_end=32558
  _globals['_APPROVEPENDINGPERMISSIONREQUEST']._serialized_start=32560
  _globals['_APPROVEPENDINGPERMISSIONREQUEST']._serialized_end=32632
  _globals['_REJECTPENDINGPERMISSIONREQUEST']._serialized_start=32634
  _globals['_REJECTPENDINGPERMISSIONREQUEST']._serialized_end=32705
  _globals['_GETACTIVEPERMISSIONREQUEST']._serialized_start=32707
  _globals['_GETACTIVEPERMISSIONREQUEST']._serialized_end=32756
  _globals['_GETACTIVEPERMISSIONRESPONSE']._serialized_start=32758
  _globals['_GETACTIVEPERMISSIONRESPONSE']._serialized_end=32853
  _globals['_SCHEDULEDTASK']._serialized_start=32856
  _globals['_SCHEDULEDTASK']._serialized_end=33447
  _globals['_SCHEDULETASKREQUEST']._serialized_start=33450
  _globals['_SCHEDULETASKREQUEST']._serialized_end=33763
  _globals['_LISTSCHEDULEDTASKSREQUEST']._serialized_start=33765
  _globals['_LISTSCHEDULEDTASKSREQUEST']._serialized_end=33855
  _globals['_LISTSCHEDULEDTASKSRESPONSE']._serialized_start=33857
  _globals['_LISTSCHEDULEDTASKSRESPONSE']._serialized_end=33968
  _globals['_SCHEDULEDTASKID']._serialized_start=33970
  _globals['_SCHEDULEDTASKID']._serialized_end=34014
  _globals['_SCHEDULEDTASKRESPONSE']._serialized_start=34016
  _globals['_SCHEDULEDTASKRESPONSE']._serialized_end=34096
  _globals['_SCHEDULEDTASKUPDATEREQUEST']._serialized_start=34098
  _globals['_SCHEDULEDTASKUPDATEREQUEST']._serialized_end=34216
  _globals['_PAUSESCHEDULEDTASKREQUEST']._serialized_start=34218
  _globals['_PAUSESCHEDULEDTASKREQUEST']._serialized_end=34272
  _globals['_RESUMESCHEDULEDTASKREQUEST']._serialized_start=34274
  _globals['_RESUMESCHEDULEDTASKREQUEST']._serialized_end=34379
  _globals['_LAZYINGESTREQUEST']._serialized_start=34381
  _globals['_LAZYINGESTREQUEST']._serialized_end=34453
  _globals['_LAZYINGESTRESPONSE']._serialized_start=34455
  _globals['_LAZYINGESTRESPONSE']._serialized_end=34526
  _globals['_GETLAZYINGESTTASKREQUEST']._serialized_start=34528
  _globals['_GETLAZYINGESTTASKREQUEST']._serialized_end=34607
  _globals['_LISTSCHEDULEDTASKEXECUTIONSREQUEST']._serialized_start=34609
  _globals['_LISTSCHEDULEDTASKEXECUTIONSREQUEST']._serialized_end=34711
  _globals['_SCHEDULEDTASKEXECUTION']._serialized_start=34714
  _globals['_SCHEDULEDTASKEXECUTION']._serialized_end=34947
  _globals['_LISTSCHEDULEDTASKEXECUTIONSRESPONSE']._serialized_start=34950
  _globals['_LISTSCHEDULEDTASKEXECUTIONSRESPONSE']._serialized_end=35091
  _globals['_TRANSFORMATIONFUNCTION']._serialized_start=35093
  _globals['_TRANSFORMATIONFUNCTION']._serialized_end=35192
  _globals['_LISTTRANSFORMATIONFUNCTIONSREQUEST']._serialized_start=35194
  _globals['_LISTTRANSFORMATIONFUNCTIONSREQUEST']._serialized_end=35230
  _globals['_LISTTRANSFORMATIONFUNCTIONSRESPONSE']._serialized_start=35232
  _globals['_LISTTRANSFORMATIONFUNCTIONSRESPONSE']._serialized_end=35355
  _globals['_GETTRANSFORMATIONFUNCTIONREQUEST']._serialized_start=35357
  _globals['_GETTRANSFORMATIONFUNCTIONREQUEST']._serialized_end=35429
  _globals['_GETTRANSFORMATIONFUNCTIONRESPONSE']._serialized_start=35431
  _globals['_GETTRANSFORMATIONFUNCTIONRESPONSE']._serialized_end=35551
  _globals['_UPDATEPROJECTREQUEST']._serialized_start=35554
  _globals['_UPDATEPROJECTREQUEST']._serialized_end=35772
  _globals['_UPDATEFEATURESETREQUEST']._serialized_start=35775
  _globals['_UPDATEFEATURESETREQUEST']._serialized_end=36731
  _globals['_UPDATEFEATUREREQUEST']._serialized_start=36734
  _globals['_UPDATEFEATUREREQUEST']._serialized_end=37129
  _globals['_GETOWNERSREQUEST']._serialized_start=37131
  _globals['_GETOWNERSREQUEST']._serialized_end=37170
  _globals['_GETOWNERSRESPONSE']._serialized_start=37172
  _globals['_GETOWNERSRESPONSE']._serialized_end=37250
  _globals['_BACKFILLOPTIONS']._serialized_start=37253
  _globals['_BACKFILLOPTIONS']._serialized_end=37610
  _globals['_BACKFILLOPTIONS_FEATUREMAPPINGENTRY']._serialized_start=37557
  _globals['_BACKFILLOPTIONS_FEATUREMAPPINGENTRY']._serialized_end=37610
  _globals['_BACKFILLRESPONSE']._serialized_start=37612
  _globals['_BACKFILLRESPONSE']._serialized_end=37699
  _globals['_FEATURESETDRAFTREQUEST']._serialized_start=37702
  _globals['_FEATURESETDRAFTREQUEST']._serialized_end=37927
  _globals['_DRAFTTOFEATURESETREQUEST']._serialized_start=37930
  _globals['_DRAFTTOFEATURESETREQUEST']._serialized_end=38333
  _globals['_DRAFTTOFEATURESETREQUEST_TIMETRAVELCOLUMN']._serialized_start=38218
  _globals['_DRAFTTOFEATURESETREQUEST_TIMETRAVELCOLUMN']._serialized_end=38333
  _globals['_DRAFTTOFEATURESETRESPONSE']._serialized_start=38335
  _globals['_DRAFTTOFEATURESETRESPONSE']._serialized_end=38386
  _globals['_FEATURESCHEMADRAFT']._serialized_start=38389
  _globals['_FEATURESCHEMADRAFT']._serialized_end=38846
  _globals['_FEATURESCHEMADRAFT_SPECIALDATA']._serialized_start=20635
  _globals['_FEATURESCHEMADRAFT_SPECIALDATA']._serialized_end=20727
  _globals['_FEATURESETDRAFTID']._serialized_start=38848
  _globals['_FEATURESETDRAFTID']._serialized_end=38897
  _globals['_LISTFEATURESETDRAFTSREQUEST']._serialized_start=38899
  _globals['_LISTFEATURESETDRAFTSREQUEST']._serialized_end=38967
  _globals['_LISTABLEFEATURESETDRAFT']._serialized_start=38970
  _globals['_LISTABLEFEATURESETDRAFT']._serialized_end=39456
  _globals['_LISTABLEFEATURESETDRAFT_FEATURESETDRAFTSTATUS']._serialized_start=39273
  _globals['_LISTABLEFEATURESETDRAFT_FEATURESETDRAFTSTATUS']._serialized_end=39456
  _globals['_FEATURESETDRAFT']._serialized_start=39459
  _globals['_FEATURESETDRAFT']._serialized_end=39655
  _globals['_LISTFEATURESETDRAFTSRESPONSE']._serialized_start=39657
  _globals['_LISTFEATURESETDRAFTSRESPONSE']._serialized_end=39781
  _globals['_FEATURESETDRAFTRESPONSE']._serialized_start=39783
  _globals['_FEATURESETDRAFTRESPONSE']._serialized_end=39880
  _globals['_ARTIFACT']._serialized_start=39883
  _globals['_ARTIFACT']._serialized_end=40119
  _globals['_STOREFILEARTIFACTREQUEST']._serialized_start=40122
  _globals['_STOREFILEARTIFACTREQUEST']._serialized_end=40297
  _globals['_STOREFILEARTIFACTRESPONSE']._serialized_start=40300
  _globals['_STOREFILEARTIFACTRESPONSE']._serialized_end=40512
  _globals['_STOREFILEARTIFACTRESPONSE_HEADERSENTRY']._serialized_start=26271
  _globals['_STOREFILEARTIFACTRESPONSE_HEADERSENTRY']._serialized_end=26317
  _globals['_RETRIEVEARTIFACTREQUEST']._serialized_start=40514
  _globals['_RETRIEVEARTIFACTREQUEST']._serialized_end=40560
  _globals['_RETRIEVEARTIFACTRESPONSE']._serialized_start=40562
  _globals['_RETRIEVEARTIFACTRESPONSE']._serialized_end=40644
  _globals['_UPDATEUPLOADSTATUSREQUEST']._serialized_start=40646
  _globals['_UPDATEUPLOADSTATUSREQUEST']._serialized_end=40767
  _globals['_DELETEARTIFACTREQUEST']._serialized_start=40769
  _globals['_DELETEARTIFACTREQUEST']._serialized_end=40813
  _globals['_LISTARTIFACTSREQUEST']._serialized_start=40815
  _globals['_LISTARTIFACTSREQUEST']._serialized_end=40935
  _globals['_LISTARTIFACTSRESPONSE']._serialized_start=40937
  _globals['_LISTARTIFACTSRESPONSE']._serialized_end=41042
  _globals['_STORELINKREQUEST']._serialized_start=41044
  _globals['_STORELINKREQUEST']._serialized_end=41170
  _globals['_FEATURESETPOPULARITY']._serialized_start=41173
  _globals['_FEATURESETPOPULARITY']._serialized_end=41374
  _globals['_FEATURESETSPOPULARITYRESPONSE']._serialized_start=41376
  _globals['_FEATURESETSPOPULARITYRESPONSE']._serialized_end=41479
  _globals['_LISTFEATURESETSTOREVIEWREQUEST']._serialized_start=41482
  _globals['_LISTFEATURESETSTOREVIEWREQUEST']._serialized_end=41612
  _globals['_LISTFEATURESETSTOREVIEWRESPONSE']._serialized_start=41614
  _globals['_LISTFEATURESETSTOREVIEWRESPONSE']._serialized_end=41737
  _globals['_FEATURESETTOREVIEW']._serialized_start=41740
  _globals['_FEATURESETTOREVIEW']._serialized_end=42050
  _globals['_APPROVEREVIEWREQUEST']._serialized_start=42052
  _globals['_APPROVEREVIEWREQUEST']._serialized_end=42109
  _globals['_REJECTREVIEWREQUEST']._serialized_start=42111
  _globals['_REJECTREVIEWREQUEST']._serialized_end=42167
  _globals['_LISTFEATURESETREVIEWSPAGEREQUEST']._serialized_start=42170
  _globals['_LISTFEATURESETREVIEWSPAGEREQUEST']._serialized_end=42302
  _globals['_FEATURESETREVIEW']._serialized_start=42305
  _globals['_FEATURESETREVIEW']._serialized_end=42681
  _globals['_LISTFEATURESETREVIEWSPAGERESPONSE']._serialized_start=42683
  _globals['_LISTFEATURESETREVIEWSPAGERESPONSE']._serialized_end=42806
  _globals['_GETLISTABLEFEATURESETTOREVIEWREQUEST']._serialized_start=42808
  _globals['_GETLISTABLEFEATURESETTOREVIEWREQUEST']._serialized_end=42865
  _globals['_GETLISTABLEFEATURESETTOREVIEWRESPONSE']._serialized_start=42867
  _globals['_GETLISTABLEFEATURESETTOREVIEWRESPONSE']._serialized_end=42984
  _globals['_GETLISTABLEFEATURESETINREVIEWREQUEST']._serialized_start=42986
  _globals['_GETLISTABLEFEATURESETINREVIEWREQUEST']._serialized_end=43043
  _globals['_GETLISTABLEFEATURESETINREVIEWRESPONSE']._serialized_start=43045
  _globals['_GETLISTABLEFEATURESETINREVIEWRESPONSE']._serialized_end=43162
  _globals['_DELETEREJECTEDFEATURESETREQUEST']._serialized_start=43164
  _globals['_DELETEREJECTEDFEATURESETREQUEST']._serialized_end=43216
  _globals['_LISTFEATURESTOREVIEWREQUEST']._serialized_start=43218
  _globals['_LISTFEATURESTOREVIEWREQUEST']._serialized_end=43320
  _globals['_LISTFEATURESTOREVIEWRESPONSE']._serialized_start=43322
  _globals['_LISTFEATURESTOREVIEWRESPONSE']._serialized_end=43432
  _globals['_LISTFEATURESINREVIEWREQUEST']._serialized_start=43434
  _globals['_LISTFEATURESINREVIEWREQUEST']._serialized_end=43536
  _globals['_LISTFEATURESINREVIEWRESPONSE']._serialized_start=43538
  _globals['_LISTFEATURESINREVIEWRESPONSE']._serialized_end=43648
  _globals['_GETFEATURESETPREVIEWTOREVIEWREQUEST']._serialized_start=43650
  _globals['_GETFEATURESETPREVIEWTOREVIEWREQUEST']._serialized_end=43706
  _globals['_GETFEATURESETPREVIEWTOREVIEWRESPONSE']._serialized_start=43708
  _globals['_GETFEATURESETPREVIEWTOREVIEWRESPONSE']._serialized_end=43789
  _globals['_GETFEATURESETPREVIEWINREVIEWREQUEST']._serialized_start=43791
  _globals['_GETFEATURESETPREVIEWINREVIEWREQUEST']._serialized_end=43847
  _globals['_GETFEATURESETPREVIEWINREVIEWRESPONSE']._serialized_start=43849
  _globals['_GETFEATURESETPREVIEWINREVIEWRESPONSE']._serialized_end=43930
  _globals['_GETFEATURESETTOREVIEWREQUEST']._serialized_start=43932
  _globals['_GETFEATURESETTOREVIEWREQUEST']._serialized_end=43981
  _globals['_GETFEATURESETTOREVIEWRESPONSE']._serialized_start=43983
  _globals['_GETFEATURESETTOREVIEWRESPONSE']._serialized_end=44075
  _globals['_GETFEATURESETINREVIEWREQUEST']._serialized_start=44077
  _globals['_GETFEATURESETINREVIEWREQUEST']._serialized_end=44126
  _globals['_GETFEATURESETINREVIEWRESPONSE']._serialized_start=44128
  _globals['_GETFEATURESETINREVIEWRESPONSE']._serialized_end=44220
  _globals['_RECENTLYUSEDPROJECT']._serialized_start=44223
  _globals['_RECENTLYUSEDPROJECT']._serialized_end=44415
  _globals['_RECENTLYUSEDPROJECTSRESPONSE']._serialized_start=44417
  _globals['_RECENTLYUSEDPROJECTSRESPONSE']._serialized_end=44514
  _globals['_RECENTLYUSEDFEATURESET']._serialized_start=44517
  _globals['_RECENTLYUSEDFEATURESET']._serialized_end=44724
  _globals['_RECENTLYUSEDFEATURESETSRESPONSE']._serialized_start=44726
  _globals['_RECENTLYUSEDFEATURESETSRESPONSE']._serialized_end=44833
  _globals['_TARGETFEATUREREQUEST']._serialized_start=44835
  _globals['_TARGETFEATUREREQUEST']._serialized_end=44930
  _globals['_LISTTARGETFEATURESREQUEST']._serialized_start=44932
  _globals['_LISTTARGETFEATURESREQUEST']._serialized_end=45012
  _globals['_TARGETFEATUREREFERENCE']._serialized_start=45014
  _globals['_TARGETFEATUREREFERENCE']._serialized_end=45080
  _globals['_LISTTARGETFEATURESRESPONSE']._serialized_start=45082
  _globals['_LISTTARGETFEATURESRESPONSE']._serialized_end=45180
  _globals['_LISTJOBSPAGEBYFEATURESETNAMEREQUEST']._serialized_start=45183
  _globals['_LISTJOBSPAGEBYFEATURESETNAMEREQUEST']._serialized_end=45376
  _globals['_LISTJOBSPAGEBYFEATURESETIDREQUEST']._serialized_start=45379
  _globals['_LISTJOBSPAGEBYFEATURESETIDREQUEST']._serialized_end=45562
  _globals['_FEATURESETJOBRELATEDINFO']._serialized_start=45564
  _globals['_FEATURESETJOBRELATEDINFO']._serialized_end=45673
  _globals['_LISTABLEJOB']._serialized_start=45676
  _globals['_LISTABLEJOB']._serialized_end=45900
  _globals['_LISTJOBSPAGERESPONSE']._serialized_start=45902
  _globals['_LISTJOBSPAGERESPONSE']._serialized_end=46007
  _globals['_GETJOBSWITHSTATUSCOUNTREQUEST']._serialized_start=46009
  _globals['_GETJOBSWITHSTATUSCOUNTREQUEST']._serialized_end=46102
  _globals['_GETJOBSWITHSTATUSCOUNTRESPONSE']._serialized_start=46104
  _globals['_GETJOBSWITHSTATUSCOUNTRESPONSE']._serialized_end=46156
  _globals['_PINFEATURESETREQUEST']._serialized_start=46158
  _globals['_PINFEATURESETREQUEST']._serialized_end=46204
  _globals['_UNPINFEATURESETREQUEST']._serialized_start=46206
  _globals['_UNPINFEATURESETREQUEST']._serialized_end=46254
  _globals['_PINNEDFEATURESETSREQUEST']._serialized_start=46256
  _globals['_PINNEDFEATURESETSREQUEST']._serialized_end=46321
  _globals['_PINNEDFEATURESET']._serialized_start=46324
  _globals['_PINNEDFEATURESET']._serialized_end=46540
  _globals['_PINNEDFEATURESETSRESPONSE']._serialized_start=46542
  _globals['_PINNEDFEATURESETSRESPONSE']._serialized_end=46662
  _globals['_ISFEATURESETPINNEDREQUEST']._serialized_start=46664
  _globals['_ISFEATURESETPINNEDREQUEST']._serialized_end=46715
  _globals['_ISFEATURESETPINNEDRESPONSE']._serialized_start=46717
  _globals['_ISFEATURESETPINNEDRESPONSE']._serialized_end=46761
  _globals['_CORESERVICE']._serialized_start=50285
  _globals['_CORESERVICE']._serialized_end=78190
# @@protoc_insertion_point(module_scope)
